@@ -33,7 +33,9 @@
 #include <vector>
 
 #include "modules/adminapi/cluster/cluster_impl.h"
+#include "modules/adminapi/common/async_topology.h"
 #include "modules/command_interface.h"
+#include "mysql/instance.h"
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 
@@ -41,18 +43,29 @@ namespace mysqlsh {
 namespace dba {
 namespace cluster {
 
-typedef std::map<std::string, std::pair<mysqlshdk::db::Row_by_name,
-                                        mysqlshdk::db::Row_by_name>>
-    Member_stats_map;
+class Status final : public Command_interface {
+ private:
+  struct Read_replica_info {
+    Instance_metadata md;
+    std::string current_source_server_uuid;
+    Managed_async_channel managed_channel_info;
+    mysqlshdk::mysql::Replication_channel repl_channel_info;
+  };
 
-struct Instance_metadata_info {
-  Instance_metadata md;
-  std::string actual_server_uuid;
-};
-
-class Status : public Command_interface {
  public:
-  Status(const Cluster_impl &cluster, std::optional<uint64_t> extended);
+  using Member_stats_map =
+      std::map<std::string, std::pair<mysqlshdk::db::Row_by_name,
+                                      mysqlshdk::db::Row_by_name>>;
+
+  struct Instance_metadata_info {
+    Instance_metadata md;
+    std::string actual_server_uuid;
+  };
+
+ public:
+  Status(const std::shared_ptr<Cluster_impl> &cluster,
+         const std::optional<uint64_t> extended);
+
   ~Status() override;
 
   /**
@@ -81,17 +94,18 @@ class Status : public Command_interface {
    *
    * NOTE: Not currently used (does nothing).
    */
-  void rollback() override;
+  void rollback() override {}
 
   /**
    * Finalize the command execution.
    * More specifically:
    * - Reset all auxiliary (temporary) data used for the operation execution.
    */
-  void finish() override;
+  void finish() override {}
 
  private:
-  const Cluster_impl &m_cluster;
+  std::shared_ptr<Cluster_impl> m_cluster;
+
   std::optional<uint64_t> m_extended;
 
   shcore::Value get_default_replicaset_status();
@@ -100,7 +114,7 @@ class Status : public Command_interface {
   std::unordered_map<std::string, std::shared_ptr<Instance>,
                      std::hash<std::string>,
                      mysqlshdk::utils::Endpoint_comparer>
-      m_member_sessions;
+      m_member_sessions, m_read_replica_sessions;
   std::unordered_map<std::string, std::string, std::hash<std::string>,
                      mysqlshdk::utils::Endpoint_comparer>
       m_member_connect_errors;
@@ -154,7 +168,8 @@ class Status : public Command_interface {
                         std::optional<bool> super_read_only,
                         const std::vector<std::string> &fence_sysvars,
                         mysqlshdk::gr::Member_state self_state,
-                        bool is_auto_rejoin_running);
+                        bool is_auto_rejoin_running,
+                        const shcore::Dictionary_t read_replicas);
 
   void feed_member_stats(shcore::Dictionary_t dict,
                          const mysqlshdk::db::Row_by_name &stats);
@@ -167,6 +182,19 @@ class Status : public Command_interface {
   shcore::Array_t validate_recovery_accounts_unused(
       const std::unordered_map<uint32_t, std::string>
           &mismatched_recovery_accounts) const;
+
+  bool validate_instances_repl_options();
+
+  shcore::Array_t read_replica_diagnostics(Instance *instance,
+                                           const Read_replica_info &rr_info,
+                                           bool is_primary) const;
+
+  shcore::Dictionary_t feed_read_replica_info(const Read_replica_info &rr,
+                                              bool is_primary);
+
+  shcore::Dictionary_t get_read_replicas_info(
+      const Instance_metadata_info &instance_md,
+      const std::vector<Read_replica_info> &read_replicas, bool is_primary);
 };
 
 }  // namespace cluster
