@@ -27,14 +27,13 @@
 #define MODULES_ADMINAPI_CLUSTER_SET_API_OPTIONS_H_
 
 #include <chrono>
+#include <optional>
 #include <string>
 
 #include "modules/adminapi/common/api_options.h"
 #include "mysqlshdk/include/scripting/types_cpp.h"
 
-namespace mysqlsh {
-namespace dba {
-namespace clusterset {
+namespace mysqlsh::dba::clusterset {
 
 struct Create_cluster_set_options {
   static const shcore::Option_pack_def<Create_cluster_set_options> &options();
@@ -45,27 +44,36 @@ struct Create_cluster_set_options {
   std::string replication_allowed_host;
 };
 
-struct Create_replica_cluster_options : public Interactive_option,
-                                        public Timeout_option,
+struct Create_replica_cluster_options : public Timeout_option,
                                         public Recovery_progress_option {
   static const shcore::Option_pack_def<Create_replica_cluster_options>
       &options();
 
-  void set_recovery_verbosity(int value);
+  void set_ssl_mode(const std::string &value);
   void set_cert_subject(const std::string &value);
+  void set_repl_connect_retry(int value);
+  void set_repl_retry_count(int value);
+  void set_repl_heartbeat_period(double value);
+  void set_repl_compression_algos(const std::string &value);
+  void set_repl_zstd_compression_level(int value);
+  void set_repl_bind(const std::string &value);
+  void set_repl_network_namespace(const std::string &value);
+
+  void merge_ar_options(Async_replication_options *target_options) const;
 
   Cluster_set_group_replication_options gr_options;
   Create_replica_cluster_clone_options clone_options;
   bool dry_run = false;
   std::string replication_allowed_host;
   std::string cert_subject;
+  Async_replication_options ar_options;
 };
 
 struct Remove_cluster_options : public Timeout_option {
   static const shcore::Option_pack_def<Remove_cluster_options> &options();
 
   bool dry_run = false;
-  mysqlshdk::null_bool force;
+  std::optional<bool> force;
 };
 
 struct Status_options {
@@ -110,8 +118,6 @@ struct Rejoin_cluster_options {
   bool dry_run = false;
 };
 
-}  // namespace clusterset
-}  // namespace dba
-}  // namespace mysqlsh
+}  // namespace mysqlsh::dba::clusterset
 
 #endif  // MODULES_ADMINAPI_CLUSTER_SET_API_OPTIONS_H_
