@@ -67,11 +67,6 @@ class Create_replica_cluster : public Command_interface {
   shcore::Option_pack_ref<mysqlsh::dba::Create_cluster_options>
   prepare_create_cluster_options();
 
-  void ensure_compatible_clone_donor(const std::string &instance_def);
-
-  void handle_clone(const Async_replication_options &ar_options,
-                    const std::string &repl_account_host, bool dry_run);
-
   std::shared_ptr<Cluster_impl> create_cluster_object(
       const mysqlshdk::mysql::Auth_options &repl_credentials,
       const std::string &repl_account_host);
@@ -95,6 +90,7 @@ class Create_replica_cluster : public Command_interface {
  private:
   Cluster_set_impl *m_cluster_set = nullptr;
   std::shared_ptr<mysqlsh::dba::Instance> m_target_instance;
+  std::shared_ptr<mysqlsh::dba::Instance> m_donor_instance;
   mysqlsh::dba::Instance *m_primary_instance = nullptr;
   std::string m_cluster_name;
   Recovery_progress_style m_progress_style;
