@@ -28,12 +28,14 @@
 
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/gtid_validations.h"
+#include "modules/errors.h"
 #include "mysqlshdk/include/scripting/shexcept.h"
 #include "mysqlshdk/include/shellcore/console.h"
 #include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/mysql/gtid_utils.h"
 #include "mysqlshdk/libs/mysql/replication.h"
-#include "mysqlshdk/libs/textui/textui.h"
+#include "mysqlshdk/libs/utils/debug.h"
+#include "mysqlshdk/libs/utils/version.h"
 
 namespace mysqlsh {
 namespace dba {
@@ -49,77 +51,77 @@ enum Prompt_type {
 
 void msg_recovery_possible_and_safe(
     Cluster_type cluster_type, Member_recovery_method recovery_method,
-    mysqlshdk::mysql::IInstance *target_instance, bool clone_only = false) {
-  auto console = current_console();
+    const mysqlshdk::mysql::IInstance &target_instance, bool clone_only,
+    bool clone_available) {
+  if (recovery_method != Member_recovery_method::AUTO) return;
 
-  if (recovery_method == Member_recovery_method::AUTO) {
-    console->print_info(
+  auto console = current_console();
+  if (clone_available)
+    console->print_info(shcore::str_format(
         "The safest and most convenient way to provision a new instance is "
         "through automatic clone provisioning, which will completely overwrite "
-        "the state of '" +
-        target_instance->descr() +
-        "' with a physical snapshot from an existing " + thing(cluster_type) +
-        " member. To use this method by default, set the 'recoveryMethod' "
-        "option to 'clone'.");
+        "the state of '%s' with a physical snapshot from an existing %s "
+        "member. To use this method by default, set the 'recoveryMethod' "
+        "option to 'clone'.",
+        target_instance.descr().c_str(), thing(cluster_type).c_str()));
 
-    if (!clone_only) {
-      console->print_info();
+  if (clone_only) return;
 
-      switch (cluster_type) {
-        case Cluster_type::GROUP_REPLICATION:
-          console->print_info(
-              "The incremental state recovery may be safely used if you are "
-              "sure all updates ever executed in the cluster were done with "
-              "GTIDs enabled, there are no purged transactions and the new "
-              "instance contains the same GTID set as the cluster or a subset "
-              "of it. To use this method by default, set the 'recoveryMethod' "
-              "option to 'incremental'.");
-          break;
+  console->print_info();
 
-        case Cluster_type::ASYNC_REPLICATION:
-          console->print_warning(
-              "It should be safe to rely on replication to incrementally "
-              "recover the state of the new instance if you are sure all "
-              "updates ever executed in the replicaset were done with GTIDs "
-              "enabled, there are no purged transactions and the new instance "
-              "contains the same GTID set as the replicaset or a subset of it. "
-              "To use this method by default, set the 'recoveryMethod' option "
-              "to 'incremental'.");
-          break;
+  switch (cluster_type) {
+    case Cluster_type::GROUP_REPLICATION:
+      console->print_info(
+          "The incremental state recovery may be safely used if you are sure "
+          "all updates ever executed in the cluster were done with GTIDs "
+          "enabled, there are no purged transactions and the new instance "
+          "contains the same GTID set as the cluster or a subset of it. To use "
+          "this method by default, set the 'recoveryMethod' option to "
+          "'incremental'.");
+      break;
 
-        case Cluster_type::REPLICATED_CLUSTER:
-          console->print_warning(
-              "It should be safe to rely on replication to incrementally "
-              "recover the state of the new Replica Cluster if you are sure "
-              "all updates ever executed in the ClusterSet were done with "
-              "GTIDs enabled, there are no purged transactions and the "
-              "instance used to create the new Replica Cluster contains the "
-              "same GTID set as the ClusterSet or a subset of it. To use this "
-              "method by default, set the 'recoveryMethod' option to "
-              "'incremental'.");
-          break;
+    case Cluster_type::ASYNC_REPLICATION:
+      console->print_warning(
+          "It should be safe to rely on replication to incrementally recover "
+          "the state of the new instance if you are sure all updates ever "
+          "executed in the replicaset were done with GTIDs enabled, there are "
+          "no purged transactions and the new instance contains the same GTID "
+          "set as the replicaset or a subset of it. To use this method by "
+          "default, set the 'recoveryMethod' option to 'incremental'.");
+      break;
 
-        default:
-          throw std::logic_error("Internal error");
-      }
-    }
+    case Cluster_type::REPLICATED_CLUSTER:
+      console->print_warning(
+          "It should be safe to rely on replication to incrementally recover "
+          "the state of the new Replica Cluster if you are sure all updates "
+          "ever executed in the ClusterSet were done with GTIDs enabled, there "
+          "are no purged transactions and the instance used to create the new "
+          "Replica Cluster contains the same GTID set as the ClusterSet or a "
+          "subset of it. To use this method by default, set the "
+          "'recoveryMethod' option to 'incremental'.");
+      break;
+
+    default:
+      throw std::logic_error("Internal error");
   }
 }
 
-void validate_clone_recovery(bool clone_disabled) {
-  auto console = current_console();
-  std::string error;
+void validate_clone_recovery(Clone_availability clone_availability) {
+  switch (clone_availability) {
+    case Clone_availability::Available:
+      return;
+    case Clone_availability::Unavailable:
+      throw shcore::Exception(
+          "Cannot use recoveryMethod=clone because the selected donor is "
+          "incompatible or no compatible donors are available due to "
+          "version/platform incompatibilities.",
+          SHERR_DBA_PROVISIONING_CLONE_NOT_POSSIBLE);
 
-  // User explicitly selected clone, so just do it.
-  // Check for whether clone is supported was already done in Clone_options
-  if (clone_disabled) {
-    error =
-        "Cannot use recoveryMethod=clone option because the disableClone "
-        "option was set for the cluster.";
-  }
-
-  if (!error.empty()) {
-    throw shcore::Exception(error, SHERR_DBA_PROVISIONING_CLONE_DISABLED);
+    case Clone_availability::Disabled:
+      throw shcore::Exception(
+          "Cannot use recoveryMethod=clone option because cloning has been "
+          "disabled for the Cluster with the 'disableClone' option.",
+          SHERR_DBA_PROVISIONING_CLONE_DISABLED);
   }
 }
 
@@ -140,18 +142,20 @@ void validate_incremental_recovery(Member_op_action op_action,
   }
 }
 
-Prompt_type validate_auto_recovery(Cluster_type cluster_type,
-                                   Member_op_action op_action,
-                                   bool recovery_possible, bool recovery_safe,
-                                   bool clone_supported, bool gtid_set_diverged,
-                                   bool interactive, bool clone_disabled) {
+Prompt_type validate_auto_recovery(
+    Cluster_type cluster_type, Member_op_action op_action,
+    bool recovery_possible, bool recovery_safe, bool clone_supported,
+    bool gtid_set_diverged, bool interactive, bool clone_disabled,
+    mysqlshdk::utils::Version target_instance_version) {
   auto console = current_console();
 
   Prompt_type prompt = None;
 
   std::string clone_available_since =
       "Built-in clone support is available starting with MySQL 8.0.17 and is "
-      "the recommended method for provisioning instances.";
+      "the recommended method for provisioning instances. Instance is running "
+      "MySQL " +
+      target_instance_version.get_full() + ".";
 
   std::string target_clone_or_provisioned_add =
       "The target instance must be either cloned or fully provisioned before "
@@ -247,14 +251,15 @@ Prompt_type validate_auto_recovery(Cluster_type cluster_type,
 
   return prompt;
 }
-}  // namespace
 
 void check_gtid_consistency_and_recoverability(
-    Cluster_type cluster_type, mysqlshdk::mysql::IInstance *donor_instance,
-    mysqlshdk::mysql::IInstance *target_instance,
-    const std::function<bool(mysqlshdk::mysql::IInstance *)> &check_recoverable,
+    Cluster_type cluster_type,
+    const mysqlshdk::mysql::IInstance &donor_instance,
+    const mysqlshdk::mysql::IInstance &target_instance,
+    const std::function<bool(const mysqlshdk::mysql::IInstance &)>
+        &check_recoverable,
     Member_recovery_method recovery_method, bool gtid_set_is_complete,
-    bool *out_recovery_possible, bool *out_recovery_safe,
+    bool clone_available, bool *out_recovery_possible, bool *out_recovery_safe,
     bool *gtid_set_diverged) {
   assert(out_recovery_possible);
   assert(out_recovery_safe);
@@ -262,49 +267,67 @@ void check_gtid_consistency_and_recoverability(
 
   auto console = current_console();
 
-  std::string errant_gtid_set, msg;
+  std::string errant_gtid_set;
   *gtid_set_diverged = false;
 
   // Get the gtid state in regards to the cluster_session
+  bool unsupported_gtid_tags{false};
   mysqlshdk::mysql::Replica_gtid_state state;
+  try {
+    if (cluster_type == Cluster_type::REPLICATED_CLUSTER)
+      state = check_replica_group_gtid_state(donor_instance, target_instance,
+                                             nullptr, &errant_gtid_set);
+    else
+      state = mysqlshdk::mysql::check_replica_gtid_state(
+          donor_instance, target_instance, nullptr, &errant_gtid_set);
+  } catch (const shcore::Exception &e) {
+    if (e.code() != SHERR_UNSUPPORTED_GTID_TAG) throw;
 
-  if (cluster_type == Cluster_type::REPLICATED_CLUSTER)
-    state = check_replica_group_gtid_state(*donor_instance, *target_instance,
-                                           nullptr, &errant_gtid_set);
-  else
-    state = mysqlshdk::mysql::check_replica_gtid_state(
-        *donor_instance, *target_instance, nullptr, &errant_gtid_set);
+    unsupported_gtid_tags = true;
+    state = mysqlshdk::mysql::Replica_gtid_state::DIVERGED;
+  }
 
   switch (state) {
     case mysqlshdk::mysql::Replica_gtid_state::NEW:
       console->print_info();
       if (gtid_set_is_complete) {
-        msg = "The target instance '" + target_instance->descr() +
-              "' has not been pre-provisioned (GTID set is empty), but the " +
-              thing(cluster_type) + " was configured to assume that ";
+        // Only print the message if recoveryMethod is AUTO
+        if (recovery_method == Member_recovery_method::AUTO) {
+          auto msg = shcore::str_format(
+              "The target instance '%s' has not been pre-provisioned (GTID set "
+              "is empty), but the %s was configured to assume that ",
+              target_instance.descr().c_str(), thing(cluster_type).c_str());
 
-        if (cluster_type == Cluster_type::GROUP_REPLICATION) {
-          msg +=
-              "incremental state recovery can correctly provision it in this "
-              "case.";
-        } else {
-          msg +=
-              "replication can completely recover the state of new instances.";
+          if (cluster_type == Cluster_type::GROUP_REPLICATION) {
+            msg +=
+                "incremental state recovery can correctly provision it in this "
+                "case.";
+          } else {
+            msg +=
+                "replication can completely recover the state of new "
+                "instances.";
+          }
+
+          console->print_note(msg);
         }
 
-        console->print_note(msg);
-
         *out_recovery_possible = true;
         *out_recovery_safe = true;
       } else {
-        msg = "The target instance '" + target_instance->descr() +
-              "' has not been pre-provisioned (GTID set is empty). The Shell "
-              "is unable to decide whether ";
+        auto msg = shcore::str_format(
+            "The target instance '%s' has not been pre-provisioned (GTID set "
+            "is empty).",
+            target_instance.descr().c_str());
 
-        if (cluster_type == Cluster_type::GROUP_REPLICATION) {
-          msg += "incremental state recovery can correctly provision it.";
-        } else {
-          msg += "replication can completely recover its state.";
+        // Only print the message if recoveryMethod is AUTO
+        if (recovery_method == Member_recovery_method::AUTO) {
+          msg += " The Shell is unable to decide whether ";
+
+          if (cluster_type == Cluster_type::GROUP_REPLICATION) {
+            msg += "incremental state recovery can correctly provision it.";
+          } else {
+            msg += "replication can completely recover its state.";
+          }
         }
 
         console->print_note(msg);
@@ -314,39 +337,56 @@ void check_gtid_consistency_and_recoverability(
       }
 
       msg_recovery_possible_and_safe(cluster_type, recovery_method,
-                                     target_instance);
+                                     target_instance, false, clone_available);
 
       console->print_info();
       break;
 
     case mysqlshdk::mysql::Replica_gtid_state::DIVERGED:
-      console->print_info();
-      console->print_warning(
-          "A GTID set check of the MySQL instance at '" +
-          target_instance->descr() +
-          "' determined that it contains transactions that do not originate "
-          "from the " +
-          thing(cluster_type) +
-          ", which must be discarded before it can join the " +
-          thing(cluster_type) + ".");
 
-      console->print_info();
-      console->print_info(target_instance->descr() +
-                          " has the following errant GTIDs that do not exist "
-                          "in the " +
-                          thing(cluster_type) + ":\n" + errant_gtid_set);
-      console->print_info();
+      if (unsupported_gtid_tags) {
+        console->print_info();
+        console->print_warning(shcore::str_format(
+            "A GTID set check found GTIDs with tags, which the donor instance "
+            "'%s' doesn't support. In order to use GTID tags, all members of "
+            "the %s must support them.",
+            donor_instance.descr().c_str(), api_class(cluster_type).c_str()));
+        console->print_info();
 
-      console->print_warning(
-          "Discarding these extra GTID events can either be done manually "
-          "or by completely overwriting the state of " +
-          target_instance->descr() +
-          " with a physical snapshot from an existing " + thing(cluster_type) +
-          " member. To use this method by default, set the 'recoveryMethod' "
-          "option to 'clone'.\n\n"
-          "Having extra GTID events is not expected, and it is recommended to "
-          "investigate this further and ensure that the data can be removed "
-          "prior to choosing the clone recovery method.");
+      } else {
+        console->print_info();
+        console->print_warning(shcore::str_format(
+            "A GTID set check of the MySQL instance at '%s' determined that it "
+            "contains transactions that do not originate from the %s, which "
+            "must be discarded before it can join the %s.",
+            target_instance.descr().c_str(), thing(cluster_type).c_str(),
+            thing(cluster_type).c_str()));
+
+        console->print_info();
+        console->print_info(shcore::str_format(
+            "Instance '%s' has the following errant GTIDs that do not exist in "
+            "the %s:\n %s",
+            target_instance.descr().c_str(), thing(cluster_type).c_str(),
+            errant_gtid_set.c_str()));
+        console->print_info();
+      }
+
+      if (!clone_available) {
+        console->print_warning(
+            "Discarding these extra GTID events can be done manually. Having "
+            "extra GTID events is not expected, and it is recommended to "
+            "investigate this further.");
+      } else {
+        console->print_warning(shcore::str_format(
+            "Discarding these extra GTID events can either be done manually or "
+            "by completely overwriting the state of '%s' with a physical "
+            "snapshot from an existing %s member. To use this method by "
+            "default, set the 'recoveryMethod' option to 'clone'.\n\nHaving "
+            "extra GTID events is not expected, and it is recommended to "
+            "investigate this further and ensure that the data can be removed "
+            "prior to choosing the clone recovery method.",
+            target_instance.descr().c_str(), thing(cluster_type).c_str()));
+      }
 
       *out_recovery_possible = false;
       *out_recovery_safe = false;
@@ -355,11 +395,10 @@ void check_gtid_consistency_and_recoverability(
 
     case mysqlshdk::mysql::Replica_gtid_state::IRRECOVERABLE:
       if (!check_recoverable(target_instance)) {
-        console->print_note("A GTID set check of the MySQL instance at '" +
-                            target_instance->descr() +
-                            "' determined that it is missing transactions that "
-                            "were purged from all " +
-                            thing(cluster_type) + " members.");
+        console->print_note(shcore::str_format(
+            "A GTID set check of the MySQL instance at '%s' determined that it "
+            "is missing transactions that were purged from all %s members.",
+            target_instance.descr().c_str(), thing(cluster_type).c_str()));
 
         *out_recovery_possible = false;
 
@@ -369,20 +408,20 @@ void check_gtid_consistency_and_recoverability(
         // cannot assume recovery is safe. BUG#30884590: ADDING AN INSTANCE WITH
         // COMPATIBLE GTID SET SHOULDN'T PROMPT FOR CLONE
         if (out_recovery_safe) {
-          auto slave_gtid_set = get_executed_gtid_set(*target_instance);
+          auto slave_gtid_set = get_executed_gtid_set(target_instance);
           if (slave_gtid_set.empty()) {
-            msg = "The target instance '" + target_instance->descr() +
-                  "' has not been pre-provisioned (GTID set is empty). The "
-                  "Shell is unable to determine whether the instance has "
-                  "pre-existing data that would be overwritten with clone "
-                  "based recovery.";
-
-            console->print_note(msg);
+            console->print_note(shcore::str_format(
+                "The target instance '%s' has not been pre-provisioned (GTID "
+                "set is empty). The Shell is unable to determine whether the "
+                "instance has pre-existing data that would be overwritten with "
+                "clone based recovery.",
+                target_instance.descr().c_str()));
 
             *out_recovery_safe = false;
 
             msg_recovery_possible_and_safe(cluster_type, recovery_method,
-                                           target_instance, true);
+                                           target_instance, true,
+                                           clone_available);
 
             console->print_info();
           } else {
@@ -404,7 +443,7 @@ void check_gtid_consistency_and_recoverability(
 
       // TODO(alfredo) - this doesn't seem necessary?
       msg_recovery_possible_and_safe(cluster_type, recovery_method,
-                                     target_instance);
+                                     target_instance, false, clone_available);
 
       console->print_info();
       break;
@@ -413,27 +452,30 @@ void check_gtid_consistency_and_recoverability(
       throw std::logic_error("Internal error");
   }
 }
+}  // namespace
 
 Member_recovery_method validate_instance_recovery(
     Cluster_type cluster_type, Member_op_action op_action,
-    mysqlshdk::mysql::IInstance *donor_instance,
-    mysqlshdk::mysql::IInstance *target_instance,
-    const std::function<bool(mysqlshdk::mysql::IInstance *)> &check_recoverable,
+    const mysqlshdk::mysql::IInstance &donor_instance,
+    const mysqlshdk::mysql::IInstance &target_instance,
+    const std::function<bool(const mysqlshdk::mysql::IInstance &)>
+        &check_recoverable,
     Member_recovery_method opt_recovery_method, bool gtid_set_is_complete,
-    bool interactive, bool clone_disabled) {
-  auto console = mysqlsh::current_console();
-
+    bool interactive, Clone_availability clone_availability) {
   bool recovery_possible;
   bool recovery_safe;
   bool gtid_set_diverged;
 
   check_gtid_consistency_and_recoverability(
       cluster_type, donor_instance, target_instance, check_recoverable,
-      opt_recovery_method, gtid_set_is_complete, &recovery_possible,
+      opt_recovery_method, gtid_set_is_complete,
+      clone_availability == Clone_availability::Available, &recovery_possible,
       &recovery_safe, &gtid_set_diverged);
 
+  auto console = mysqlsh::current_console();
+
   if (opt_recovery_method == Member_recovery_method::CLONE) {
-    validate_clone_recovery(clone_disabled);
+    validate_clone_recovery(clone_availability);
 
     console->print_info(
         "Clone based recovery selected through the recoveryMethod option");
@@ -446,17 +488,13 @@ Member_recovery_method validate_instance_recovery(
     validate_incremental_recovery(op_action, recovery_possible, recovery_safe);
 
     console->print_info(
-        "Incremental state recovery selected through the "
-        "recoveryMethod option");
+        "Incremental state recovery selected through the recoveryMethod "
+        "option");
     console->print_info();
 
     return Member_recovery_method::INCREMENTAL;
   }
 
-  Member_recovery_method recovery_method = Member_recovery_method::INCREMENTAL;
-
-  bool clone_supported = mysqlshdk::mysql::is_clone_available(*target_instance);
-
   // When recovery is safe we do not need to prompt. If possible,
   // incremental recovery should be used, otherwise clone. BUG#30884590:
   // ADDING AN INSTANCE WITH COMPATIBLE GTID SET SHOULDN'T PROMPT FOR
@@ -470,8 +508,8 @@ Member_recovery_method validate_instance_recovery(
       // group_replication_clone_threshold was set to 1 - in InnoDB
       // cluster only
       if (cluster_type == Cluster_type::GROUP_REPLICATION) {
-        current_threshold = target_instance->get_sysvar_int(
-            "group_replication_clone_threshold");
+        current_threshold =
+            target_instance.get_sysvar_int("group_replication_clone_threshold");
       }
 
       if ((cluster_type == Cluster_type::GROUP_REPLICATION) &&
@@ -486,83 +524,84 @@ Member_recovery_method validate_instance_recovery(
             "Incremental state recovery was selected because it seems to be "
             "safely usable.");
         console->print_info();
-        recovery_method = Member_recovery_method::INCREMENTAL;
+        return Member_recovery_method::INCREMENTAL;
       }
     } else {
-      if (!clone_disabled && clone_supported) {
+      auto clone_supported =
+          mysqlshdk::mysql::is_clone_available(target_instance);
+
+      if (clone_availability == Clone_availability::Available &&
+          clone_supported) {
         console->print_info(
             "Clone based recovery was selected because it seems to be safely "
             "usable.");
         console->print_info();
-        recovery_method = Member_recovery_method::CLONE;
+        return Member_recovery_method::CLONE;
       }
     }
-  } else {
-    Prompt_type prompt = validate_auto_recovery(
-        cluster_type, op_action, recovery_possible, recovery_safe,
-        clone_supported, gtid_set_diverged, interactive, clone_disabled);
 
-    console->print_info();
-
-    switch (prompt) {
-      case Clone_incremental_abort:
-        switch (console->confirm("Please select a recovery method",
-                                 mysqlsh::Prompt_answer::YES, "&Clone",
-                                 "&Incremental recovery", "&Abort")) {
-          case mysqlsh::Prompt_answer::YES:
-            recovery_method = Member_recovery_method::CLONE;
-            break;
-          case mysqlsh::Prompt_answer::NO:
-            recovery_method = Member_recovery_method::INCREMENTAL;
-            break;
-          case mysqlsh::Prompt_answer::ALT:
-          case mysqlsh::Prompt_answer::NONE:
-            throw shcore::cancelled("Cancelled");
-        }
-        break;
-
-      case Clone_abort:
-        switch (console->confirm("Please select a recovery method",
-                                 mysqlsh::Prompt_answer::YES, "&Clone",
-                                 "&Abort")) {
-          case mysqlsh::Prompt_answer::YES:
-            recovery_method = Member_recovery_method::CLONE;
-            break;
-          default:
-            throw shcore::cancelled("Cancelled");
-        }
-        break;
-
-      case Abort_clone:
-        switch (console->confirm("Please select a recovery method",
-                                 mysqlsh::Prompt_answer::NO, "&Clone",
-                                 "&Abort")) {
-          case mysqlsh::Prompt_answer::YES:
-            recovery_method = Member_recovery_method::CLONE;
-            break;
-          default:
-            throw shcore::cancelled("Cancelled");
-        }
-        break;
-
-      case Incremental_abort:
-        switch (console->confirm("Please select a recovery method",
-                                 mysqlsh::Prompt_answer::YES,
-                                 "&Incremental recovery", "&Abort")) {
-          case mysqlsh::Prompt_answer::YES:
-            recovery_method = Member_recovery_method::INCREMENTAL;
-            break;
-          default:
-            throw shcore::cancelled("Cancelled");
-        }
-        break;
-
-      case None:
-        break;
-    }
+    return Member_recovery_method::INCREMENTAL;
   }
 
-  return recovery_method;
+  // recovery is not safe so we need to prompt
+
+  auto clone_supported = mysqlshdk::mysql::is_clone_available(target_instance);
+
+  Prompt_type prompt = validate_auto_recovery(
+      cluster_type, op_action, recovery_possible, recovery_safe,
+      clone_supported, gtid_set_diverged, interactive,
+      clone_availability != Clone_availability::Available,
+      target_instance.get_version());
+
+  console->print_info();
+
+  switch (prompt) {
+    case Clone_incremental_abort:
+      switch (console->confirm("Please select a recovery method",
+                               mysqlsh::Prompt_answer::YES, "&Clone",
+                               "&Incremental recovery", "&Abort")) {
+        case mysqlsh::Prompt_answer::YES:
+          return Member_recovery_method::CLONE;
+
+        case mysqlsh::Prompt_answer::NO:
+          return Member_recovery_method::INCREMENTAL;
+
+        case mysqlsh::Prompt_answer::ALT:
+        case mysqlsh::Prompt_answer::NONE:
+          throw shcore::cancelled("Cancelled");
+      }
+      break;
+
+    case Clone_abort:
+      if (console->confirm("Please select a recovery method",
+                           mysqlsh::Prompt_answer::YES, "&Clone",
+                           "&Abort") == mysqlsh::Prompt_answer::YES)
+        return Member_recovery_method::CLONE;
+
+      throw shcore::cancelled("Cancelled");
+
+    case Abort_clone:
+      if (console->confirm("Please select a recovery method",
+                           mysqlsh::Prompt_answer::NO, "&Clone",
+                           "&Abort") == mysqlsh::Prompt_answer::YES)
+
+        return Member_recovery_method::CLONE;
+
+      throw shcore::cancelled("Cancelled");
+
+    case Incremental_abort:
+      if (console->confirm("Please select a recovery method",
+                           mysqlsh::Prompt_answer::YES, "&Incremental recovery",
+                           "&Abort") == mysqlsh::Prompt_answer::YES)
+        return Member_recovery_method::INCREMENTAL;
+
+      throw shcore::cancelled("Cancelled");
+
+    case None:
+      break;
+  }
+
+  return Member_recovery_method::INCREMENTAL;
 }
 
 std::string get_only_view_change_gtids(
