@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -53,6 +55,9 @@ constexpr const char *k_default_sql_mode =
 constexpr char k_lock[] = "AdminAPI_lock";
 constexpr char k_lock_name_instance[] = "AdminAPI_instance";
 
+// default wait_timeout
+constexpr uint64_t k_default_wait_timeout = 28800;
+
 int64_t default_adminapi_connect_timeout() {
   return mysqlsh::current_shell_options()->get().dba_connect_timeout * 1000;
 }
@@ -63,22 +68,17 @@ std::shared_ptr<mysqlshdk::db::ISession> connect_session(
     throw make_unsupported_protocol_error();
   }
 
-  try {
+  if (opts.has_connect_timeout())
     return establish_mysql_session(opts, interactive);
+
+  mysqlshdk::db::Connection_options op(opts);
+  op.set_connect_timeout(static_cast<int>(default_adminapi_connect_timeout()));
+
+  try {
+    return establish_mysql_session(op, interactive);
   } catch (const shcore::Exception &e) {
-    if (CR_VERSION_ERROR == e.code() ||
-        (CR_SERVER_LOST == e.code() &&
-         // TODO(alfredo) - when connection timeout is enabled, the error
-         // returned for a timeout seems to be this too. This error handling
-         // should probably be removed from here and the connect timeout setting
-         // should be moved from connect_raw to this function
-         0 == strcmp("Lost connection to MySQL server at 'waiting for initial "
-                     "communication packet', system error: 110",
-                     e.what()))) {
-      throw make_unsupported_protocol_error();
-    } else {
-      throw;
-    }
+    if (CR_VERSION_ERROR == e.code()) throw make_unsupported_protocol_error();
+    throw;
   }
 }
 
@@ -86,14 +86,7 @@ std::shared_ptr<mysqlshdk::db::ISession> connect_session(
 
 std::shared_ptr<Instance> Instance::connect_raw(
     const mysqlshdk::db::Connection_options &opts, bool interactive) {
-  mysqlshdk::db::Connection_options op(opts);
-
-  if (!op.has_value(mysqlshdk::db::kConnectTimeout)) {
-    op.set(mysqlshdk::db::kConnectTimeout,
-           std::to_string(default_adminapi_connect_timeout()));
-  }
-
-  return std::make_shared<Instance>(connect_session(op, interactive));
+  return std::make_shared<Instance>(connect_session(opts, interactive));
 }
 
 std::shared_ptr<Instance> Instance::connect(
@@ -145,6 +138,9 @@ void Instance::prepare_session() {
   // (i.e.: the server was configured with skip-character-set-client-handshake
   // options). This in turn would create problems like "Illegal mix of
   // collations". To prevent this, we explicitly set the session collation.
+  // NOTE: although AdminAPI doesn't support versions older than 8.0.0
+  // (e.g.: 5.7) we still need this here to establish a connection to the
+  // instance, and only after that, check its version.
   if (version >= mysqlshdk::utils::Version(8, 0, 0))
     set_sysvar("collation_connection", std::string("utf8mb4_0900_ai_ci"),
                mysqlshdk::mysql::Var_qualifier::SESSION);
@@ -158,6 +154,20 @@ void Instance::prepare_session() {
   set_sysvar("group_concat_max_len", static_cast<int64_t>(1024 * 1024 * 1024),
              mysqlshdk::mysql::Var_qualifier::SESSION);
 
+  // Ensure the default value for 'wait_timeout' is kept for the AdminAPI
+  // accounts, avoiding any possible timeouts in command execution due to
+  // user-configured low values.
+  // NOTE: set directly to 28800, instead of using DEFAULT, because the user
+  // might have configured directly on the configuration file the value for the
+  // timeout and that becomes the compiled DEFAULT value.
+  // Also, only set if the instance has a value set that is lower than 28800.
+  // This is important to ensure higher values set by the user are honored.
+  if (get_sysvar_int("wait_timeout", mysqlshdk::mysql::Var_qualifier::SESSION) <
+      k_default_wait_timeout) {
+    set_sysvar("wait_timeout", static_cast<int64_t>(k_default_wait_timeout),
+               mysqlshdk::mysql::Var_qualifier::SESSION);
+  }
+
   // Cache the hostname, port, and UUID to avoid errors accessing this data if
   // the instance fails during an operation.
   get_canonical_address();
