@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2019, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -29,6 +31,7 @@
 #include "mysqlshdk/include/shellcore/interrupt_handler.h"
 #include "mysqlshdk/libs/db/mysql/session.h"
 #include "mysqlshdk/libs/mysql/replication.h"
+#include "mysqlshdk/libs/utils/atomic_flag.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/strformat.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
@@ -240,13 +243,13 @@ mysqlshdk::gr::Group_member_recovery_status wait_recovery_start(
 
   Scoped_instance instance;
 
-  bool stop = false;
+  shcore::atomic_flag stop;
   shcore::Interrupt_handler intr([&stop]() {
-    stop = true;
+    stop.test_and_set();
     return true;
   });
 
-  while (timeout_sec > 0 && !stop) {
+  while (timeout_sec > 0 && !stop.test()) {
     if (reconnect) {
       try {
         instance = Scoped_instance(wait_server_startup(
@@ -284,7 +287,7 @@ mysqlshdk::gr::Group_member_recovery_status wait_recovery_start(
     timeout_sec--;
   }
 
-  if (stop) throw stop_monitoring();
+  if (stop.test()) throw stop_monitoring();
 
   return mysqlshdk::gr::Group_member_recovery_status::UNKNOWN;
 }
@@ -299,16 +302,16 @@ std::shared_ptr<mysqlsh::dba::Instance> wait_clone_start(
 
   bool reconnect = true;
 
-  bool stop = false;
+  shcore::atomic_flag stop;
   shcore::Interrupt_handler intr([&stop]() {
-    stop = true;
+    stop.test_and_set();
     return true;
   });
 
   auto poll_interval_ms = k_recovery_status_poll_interval_ms;
   DBUG_EXECUTE_IF("clone_rig_poll_interval", { poll_interval_ms = 10; });
 
-  while (timeout_sec > 0 && !stop) {
+  while (timeout_sec > 0 && !stop.test()) {
     if (reconnect) {
       try {
         out_instance = wait_server_startup(instance_def, timeout_sec,
@@ -348,7 +351,7 @@ std::shared_ptr<mysqlsh::dba::Instance> wait_clone_start(
     timeout_sec--;
   }
 
-  if (stop) throw stop_monitoring();
+  if (stop.test()) throw stop_monitoring();
 
   return out_instance;
 }
@@ -360,9 +363,9 @@ void monitor_distributed_recovery(const mysqlshdk::mysql::IInstance &instance,
   log_debug("Waiting for member_state of %s to become ONLINE...",
             instance.descr().c_str());
 
-  bool stop = false;
+  shcore::atomic_flag stop;
   shcore::Interrupt_handler intr([&stop]() {
-    stop = true;
+    stop.test_and_set();
     return true;
   });
 
@@ -370,7 +373,7 @@ void monitor_distributed_recovery(const mysqlshdk::mysql::IInstance &instance,
   bool first = true;
 
   std::string last_error_time;
-  while (!stop) {
+  while (!stop.test()) {
     mysqlshdk::gr::Member_state state =
         mysqlshdk::gr::get_member_state(instance);
 
@@ -405,7 +408,7 @@ void monitor_distributed_recovery(const mysqlshdk::mysql::IInstance &instance,
     shcore::sleep_ms(k_recovery_status_poll_interval_ms);
   }
 
-  if (stop) throw stop_monitoring();
+  if (stop.test()) throw stop_monitoring();
 
   console->print_info("* Distributed recovery has finished");
   console->print_info();
@@ -419,8 +422,8 @@ void monitor_standalone_clone_instance(
   auto console = current_console();
 
   console->print_info(
-      "Waiting for clone process of the new member to complete. "
-      "Press ^C to abort the operation.");
+      "Monitoring Clone based state recovery of the new member. Press ^C to "
+      "abort the operation.");
 
   log_info("Waiting for clone process to start at %s...",
            instance_def.uri_endpoint().c_str());
@@ -428,6 +431,17 @@ void monitor_standalone_clone_instance(
   Scoped_instance instance(
       wait_clone_start(instance_def, begin_time, startup_timeout_sec));
 
+  console->print_info(mysqlshdk::textui::bold(
+      "Clone based state recovery is now in progress."));
+  console->print_info();
+  console->print_note(mysqlshdk::textui::format_markup_text(
+      {"A server restart is expected to happen as part of the clone "
+       "process. If the server does not support the RESTART command or "
+       "does not come back after a while, you may need to manually start "
+       "it back."},
+      80));
+  console->print_info();
+
   monitor_clone_recovery(instance.get(), post_clone_coptions, begin_time,
                          progress_style, restart_timeout_sec, false);
 }
@@ -442,9 +456,9 @@ std::shared_ptr<mysqlsh::dba::Instance> monitor_clone_recovery(
   bool ignore_cancel = false;
   Clone_progress progress(progress_style);
 
-  bool stop = false;
+  shcore::atomic_flag stop;
   shcore::Interrupt_handler intr([&stop]() {
-    stop = true;
+    stop.test_and_set();
     return true;
   });
 
@@ -453,7 +467,7 @@ std::shared_ptr<mysqlsh::dba::Instance> monitor_clone_recovery(
 
   bool first = true;
   console->print_info("* Waiting for clone to finish...");
-  while (!stop) {
+  while (!stop.test()) {
     mysqlshdk::mysql::Clone_status status;
 
     try {
@@ -503,7 +517,7 @@ std::shared_ptr<mysqlsh::dba::Instance> monitor_clone_recovery(
 
     shcore::sleep_ms(poll_interval_ms);
   }
-  if (stop && !ignore_cancel) throw stop_monitoring();
+  if (stop.test() && !ignore_cancel) throw stop_monitoring();
 
   std::shared_ptr<mysqlsh::dba::Instance> new_instance;
 
@@ -540,7 +554,7 @@ std::shared_ptr<mysqlsh::dba::Instance> monitor_clone_recovery(
   }
 
   // Wait for clone recovery to finish
-  while (!stop) {
+  while (!stop.test()) {
     mysqlshdk::mysql::Clone_status status;
 
     status = mysqlshdk::mysql::check_clone_status(*new_instance, begin_time);
@@ -584,7 +598,7 @@ std::shared_ptr<mysqlsh::dba::Instance> monitor_clone_recovery(
     }
     shcore::sleep_ms(k_clone_status_poll_interval_ms);
   }
-  if (stop && !ignore_cancel) throw stop_monitoring();
+  if (stop.test() && !ignore_cancel) throw stop_monitoring();
 
   // TODO(miguel/alfredo): refactor this monitoring code to pass the less
   // possible pointers around
@@ -596,9 +610,9 @@ void monitor_post_clone_gr_recovery_status(
     const mysqlshdk::db::Connection_options &post_clone_coptions,
     const std::string &begin_time, Recovery_progress_style progress_style,
     int startup_timeout_sec) {
-  bool stop = false;
+  shcore::atomic_flag stop;
   shcore::Interrupt_handler intr([&stop]() {
-    stop = true;
+    stop.test_and_set();
     return true;
   });
 
@@ -610,7 +624,7 @@ void monitor_post_clone_gr_recovery_status(
   int startup_timeout_iters =
       adjust_timeout(startup_timeout_sec, k_recovery_status_poll_interval_ms);
 
-  while (startup_timeout_iters > 0 && !stop) {
+  while (startup_timeout_iters > 0 && !stop.test()) {
     try {
       rm = mysqlshdk::gr::detect_recovery_status(*instance, begin_time);
       if (rm != mysqlshdk::gr::Group_member_recovery_status::CLONE) {
@@ -627,7 +641,7 @@ void monitor_post_clone_gr_recovery_status(
     startup_timeout_iters--;
   }
 
-  if (stop) throw stop_monitoring();
+  if (stop.test()) throw stop_monitoring();
 }
 
 void monitor_gr_recovery_status(
@@ -655,6 +669,12 @@ void monitor_gr_recovery_status(
     log_info("Waiting for GR recovery to start for %s...",
              instance_def.uri_endpoint().c_str());
 
+    DBUG_EXECUTE_IF(
+        "sigint_wait_recovery",
+        {  // Simulate a SIGINT (ctrl-c) to exit the recovery monitoring
+          throw stop_monitoring();
+        });
+
     for (int attempt = 0; attempt < 2; ++attempt) {
       try {
         mysqlshdk::gr::Group_member_recovery_status method =
@@ -690,7 +710,7 @@ void monitor_gr_recovery_status(
               continue;
             }
 
-            // retries exausted or unkown error, so just rethrow and let the
+            // retries exhausted or unknown error, so just rethrow and let the
             // error propagate
             throw;
           }
