@@ -150,7 +150,7 @@ std::string &Constant::append_descr(std::string &s_out, int UNUSED(indent),
                                     int UNUSED(quote_strings)) const {
   s_out.append("<" + _group + "." + _id);
 
-  if (_data.type == shcore::String) {
+  if (_data.get_type() == shcore::String) {
     const std::string &data = _data.get_string();
     size_t pos = data.find("(");
     if (pos != std::string::npos) s_out.append(data.substr(pos));
