@@ -27,26 +27,15 @@
 #include <memory>
 #include <vector>
 
-#include "modules/adminapi/common/common.h"
-#include "modules/devapi/base_database_object.h"
 #include "modules/devapi/mod_mysqlx_schema.h"
 #include "modules/devapi/mod_mysqlx_session.h"
-#include "modules/mod_mysql_session.h"
 #include "modules/mod_utils.h"
-#include "modules/mysqlxtest_utils.h"
 #include "mysqlshdk/include/scripting/shexcept.h"
-#include "mysqlshdk/include/scripting/type_info/custom.h"
-#include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/shellcore/base_session.h"
-#include "mysqlshdk/include/shellcore/shell_notifications.h"
 #include "mysqlshdk/include/shellcore/shell_resultset_dumper.h"
 #include "mysqlshdk/include/shellcore/utils_help.h"
-#include "mysqlshdk/libs/db/utils_connection.h"
-#include "mysqlshdk/libs/ssh/ssh_common.h"
 #include "mysqlshdk/libs/utils/strformat.h"
-#include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
-#include "mysqlshdk/libs/utils/utils_path.h"
 #include "mysqlshdk/shellcore/credential_manager.h"
 
 using namespace std::placeholders;
@@ -582,6 +571,12 @@ connection timeout.
 PERFORMANCE_SCHEMA connection attributes tables.
 @li local-infile: Enable/disable LOAD DATA LOCAL INFILE.
 @li net-buffer-length: The buffer size for TCP/IP and socket communication.
+@li plugin-authentication-kerberos-client-mode: (Windows) Allows defining the kerberos
+client mode (SSPI, GSSAPI) when using kerberos authentication.
+@li oci-config-file: Allows defining the OCI configuration file for OCI authentication.
+@li authentication-oci-client-config-profile: Allows defining the OCI profile used from 
+the configuration for client side OCI authentication.
+@li client-interactive: Enable/disable interactive mode for the session.
 
 When these options are defined in a URI, their values must be URL encoded.
 
@@ -591,9 +586,7 @@ The following options are also valid when a dictionary is used:
 @li uri: a URI string.
 @li scheme: the protocol to be used on the connection.
 @li user: the MySQL user name to be used on the connection.
-@li dbUser: alias for user.
 @li password: the password to be used on the connection.
-@li dbPassword: same as password.
 @li host: the hostname or IP address to be used on the connection.
 @li port: the port to be used in a TCP connection.
 @li socket: the socket file name to be used on a connection through unix sockets.
@@ -606,8 +599,6 @@ The following options are also valid when a dictionary is used:
 @li ssh-identity-file-password: the SSH key file password.
 @li ssh-config-file: the SSH configuration file, default is the value of shell.options['ssh.configFile']
 
-@attention The dbUser and dbPassword options are will be removed in a future release.
-
 @attention The connection options have precedence over options specified in the connection options uri
 
 The connection options are case insensitive and can only be defined once.
@@ -974,7 +965,7 @@ std::shared_ptr<ShellBaseSession> Shell::open_session(
   if (connection_options_.has_data()) {
     auto connection_options = connection_options_;
     mysqlsh::set_password_from_string(&connection_options, password);
-    return _shell->connect(connection_options, false, false);
+    return _shell->connect(connection_options, false);
   } else {
     auto session = _shell_core->get_dev_session();
 
@@ -983,7 +974,7 @@ std::shared_ptr<ShellBaseSession> Shell::open_session(
           "An open session is required when duplicating sessions.");
     }
 
-    return _shell->connect(session->get_connection_options(), false, false);
+    return _shell->connect(session->get_connection_options(), false);
   }
 }
 
@@ -1205,7 +1196,7 @@ bool Shell::reconnect() {
       session->reconnect();
       ret_val = true;
     }
-  } catch (const shcore::Exception &e) {
+  } catch (const shcore::Exception &) {
   }
 
   return ret_val;
@@ -1347,20 +1338,19 @@ Undefined Shell::storeCredential(String url, String password) {}
 #elif DOXYGEN_PY
 None Shell::store_credential(str url, str password) {}
 #endif
-void Shell::store_credential(
-    const std::string &url,
-    const mysqlshdk::utils::nullable<std::string> &password) {
+void Shell::store_credential(const std::string &url,
+                             std::optional<std::string> password) {
   std::string pwd_to_store;
-  if (password.is_null()) {
-    const std::string prompt =
-        "Please provide the password for '" + url + "': ";
+  if (!password.has_value()) {
+    auto prompt = shcore::str_format("Please provide the password for '%s': ",
+                                     url.c_str());
     const auto result =
         current_console()->prompt_password(prompt, &pwd_to_store);
     if (result != shcore::Prompt_result::Ok) {
       throw shcore::cancelled("Cancelled");
     }
   } else {
-    pwd_to_store = *password;
+    pwd_to_store = std::move(*password);
   }
 
   shcore::Credential_manager::get().store_credential(url, pwd_to_store);
