@@ -25,7 +25,6 @@
 
 #include "modules/mod_utils.h"
 
-#include <map>
 #include <string>
 #include <utility>
 
@@ -38,6 +37,7 @@
 #include "mysqlshdk/include/shellcore/shell_options.h"
 #include "mysqlshdk/libs/db/mysql/session.h"
 #include "mysqlshdk/libs/db/mysqlx/session.h"
+#include "mysqlshdk/libs/utils/atomic_flag.h"
 #include "mysqlshdk/libs/utils/fault_injection.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_path.h"
@@ -58,7 +58,7 @@ namespace {
 Connection_options get_connection_options(const std::string &instance_def) {
   if (instance_def.empty()) throw std::invalid_argument("Invalid URI: empty.");
 
-  auto ret_val = shcore::get_connection_options(instance_def, false);
+  auto ret_val = Connection_options(instance_def);
   for (const auto &warning : ret_val.get_warnings())
     mysqlsh::current_console()->print_warning(warning);
   ret_val.clear_warnings();
@@ -66,6 +66,18 @@ Connection_options get_connection_options(const std::string &instance_def) {
   return ret_val;
 }
 
+void check_timeout_option(const char *timeout_option,
+                          const shcore::Argument_map &connection_map,
+                          const shcore::Value::Map_type::value_type &option,
+                          Connection_options &ret_val) {
+  if (connection_map.at(option.first).get_type() != shcore::Integer) {
+    mysqlshdk::db::Connection_options::throw_invalid_timeout(
+        timeout_option, connection_map.at(option.first).descr());
+  } else {
+    ret_val.set(option.first, connection_map.at(option.first).descr());
+  }
+}
+
 /**
  * Retrieves the connection data from a Dictionary
  *
@@ -90,7 +102,8 @@ Connection_options get_connection_options(
 
   Connection_options ret_val;
   const auto case_sensitive =
-      ret_val.get_mode() == mysqlshdk::db::Comparison_mode::CASE_SENSITIVE;
+      ret_val.get_mode() ==
+      mysqlshdk::utils::nullable_options::Comparison_mode::CASE_SENSITIVE;
 
   connection_map.ensure_keys(mandatory, mysqlshdk::db::connection_attributes(),
                              "connection options", case_sensitive);
@@ -134,24 +147,25 @@ Connection_options get_connection_options(
       ret_val.set_compression_level(connection_map.int_at(option.first));
     } else if (ret_val.compare(option.first, mysqlshdk::db::kConnectTimeout) ==
                0) {
-      // Additional connection options are internally stored as strings.
-      // Even so, when given in a dictionary, the connect-timeout option
-      // must be given as an integer value
-      if (connection_map.at(option.first).type != shcore::Integer) {
-        mysqlshdk::db::Connection_options::throw_invalid_connect_timeout(
-            connection_map.at(option.first).descr());
-      } else {
-        ret_val.set(option.first, connection_map.at(option.first).descr());
-      }
+      check_timeout_option(mysqlshdk::db::kConnectTimeout, connection_map,
+                           option, ret_val);
+    } else if (ret_val.compare(option.first, mysqlshdk::db::kNetReadTimeout) ==
+               0) {
+      check_timeout_option(mysqlshdk::db::kNetReadTimeout, connection_map,
+                           option, ret_val);
+    } else if (ret_val.compare(option.first, mysqlshdk::db::kNetWriteTimeout) ==
+               0) {
+      check_timeout_option(mysqlshdk::db::kNetWriteTimeout, connection_map,
+                           option, ret_val);
     } else if (ret_val.compare(option.first,
                                mysqlshdk::db::kConnectionAttributes) == 0) {
-      if (option.second.type == shcore::Map) {
+      if (option.second.get_type() == shcore::Map) {
         // Supports connection-attributes: {key:val, key:val, ...}
         auto map = option.second.as_map();
         for (const auto &entry : *map) {
           ret_val.set_connection_attribute(entry.first, entry.second.descr());
         }
-      } else if (option.second.type == shcore::Array) {
+      } else if (option.second.get_type() == shcore::Array) {
         // Supports connection-attributes: ["key=val", "key=val", ...]
         auto array = option.second.as_array();
         std::vector<std::string> values;
@@ -186,15 +200,15 @@ Connection_options get_connection_options(
 }  // namespace
 
 Connection_options get_connection_options(const shcore::Value &v) {
-  if (shcore::String == v.type) {
-    return get_connection_options(v.get_string());
-  } else if (shcore::Map == v.type) {
-    return get_connection_options(v.as_map());
-  } else {
-    throw shcore::Exception::type_error(
-        "Invalid connection options, expected either a URI or a Connection "
-        "Options Dictionary");
-  }
+  auto type = v.get_type();
+
+  if (shcore::String == type) return get_connection_options(v.get_string());
+
+  if (shcore::Map == type) return get_connection_options(v.as_map());
+
+  throw shcore::Exception::type_error(
+      "Invalid connection options, expected either a URI or a Connection "
+      "Options Dictionary");
 }
 
 mysqlshdk::ssh::Ssh_connection_options get_ssh_options(
@@ -310,15 +324,27 @@ shcore::Value::Map_type_ref get_connection_map(
     if (!option.second.has_value())
       (*map)[option.first] = shcore::Value();
     else {
-      if (shcore::str_caseeq(option.first, mysqlshdk::db::kConnectTimeout)) {
-        (*map)[option.first] =
-            shcore::Value(std::atoi((*option.second).c_str()));
-      } else {
-        (*map)[option.first] = shcore::Value(*option.second);
-      }
+      (*map)[option.first] = shcore::Value(*option.second);
     }
   }
 
+  if (connection_options.has_connect_timeout()) {
+    (*map)[mysqlshdk::db::kConnectTimeout] =
+        shcore::Value(connection_options.get_connect_timeout());
+  }
+  if (connection_options.has_net_read_timeout()) {
+    (*map)[mysqlshdk::db::kNetReadTimeout] =
+        shcore::Value(connection_options.get_net_read_timeout());
+  }
+  if (connection_options.has_net_write_timeout()) {
+    (*map)[mysqlshdk::db::kNetWriteTimeout] =
+        shcore::Value(connection_options.get_net_write_timeout());
+  }
+  if (connection_options.has_compression_level()) {
+    (*map)[mysqlshdk::db::kCompressionLevel] =
+        shcore::Value(connection_options.get_compression_level());
+  }
+
   if (connection_options.is_connection_attributes_enabled()) {
     auto conn_atts = connection_options.get_connection_attributes();
 
@@ -427,9 +453,9 @@ std::shared_ptr<mysqlshdk::db::ISession> create_and_connect(
 std::shared_ptr<mysqlshdk::db::ISession> create_session(
     const Connection_options &connection_options) {
   // allow SIGINT to interrupt the connect()
-  bool cancelled = false;
+  shcore::atomic_flag cancelled;
   shcore::Interrupt_handler intr([&cancelled]() {
-    cancelled = true;
+    cancelled.test_and_set();
     return true;
   });
 
@@ -437,7 +463,7 @@ std::shared_ptr<mysqlshdk::db::ISession> create_session(
 
   auto session = create_and_connect(connection_options);
 
-  if (cancelled) throw shcore::cancelled("Cancelled");
+  if (cancelled.test()) throw shcore::cancelled("Cancelled");
 
   return session;
 }
@@ -445,14 +471,19 @@ std::shared_ptr<mysqlshdk::db::ISession> create_session(
 void password_prompt(Connection_options *options) {
   const std::string uri =
       options->as_uri(mysqlshdk::db::uri::formats::user_transport());
-  const std::string prompt = "Please provide the password for '" + uri + "': ";
-  std::string answer;
-  const auto result = current_console()->prompt_password(prompt, &answer);
+  for (int factor = 0; factor < mysqlshdk::db::k_max_auth_factors; factor++) {
+    if (!options->should_prompt_password(factor)) continue;
+    const std::string prompt = "Please provide the password" +
+                               (factor == 0 ? "" : std::to_string(factor + 1)) +
+                               " for '" + uri + "': ";
+    std::string answer;
+    const auto result = current_console()->prompt_password(prompt, &answer);
 
-  if (result == shcore::Prompt_result::Ok) {
-    options->set_password(answer);
-  } else {
-    throw shcore::cancelled("Cancelled");
+    if (result == shcore::Prompt_result::Ok) {
+      options->set_mfa_password(factor, answer);
+    } else {
+      throw shcore::cancelled("Cancelled");
+    }
   }
 }
 
@@ -503,6 +534,7 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
       mysqlshdk::ssh::current_ssh_manager()->create_tunnel(&ssh);
     }
 
+    // TODO(alfredo) - password storage for MFA needs to be figured out
     if (!copy.has_password() && copy.has_user() && enable_stored_passwords) {
       if (shcore::Credential_manager::get().get_password(&copy)) {
         try {
@@ -511,7 +543,10 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
           if (e.code() != ER_ACCESS_DENIED_ERROR) {
             throw;
           } else {
-            copy.clear_password();
+            // we don't which password was wrong, so assume all of them were
+            for (int f = 0; f < mysqlshdk::db::k_max_auth_factors; f++)
+              copy.clear_mfa_password(f);
+
             shcore::Credential_manager::get().remove_password(copy);
             log_info(
                 "Connection to \"%s\" could not be established using the "
@@ -527,8 +562,17 @@ std::shared_ptr<mysqlshdk::db::ISession> establish_session(
     if (prompt_for_password) {
       do {
         bool prompted_for_password = false;
+        bool should_prompt = false;
+        for (int f = 0; f < mysqlshdk::db::k_max_auth_factors; f++) {
+          if (copy.should_prompt_password(f)) {
+            should_prompt = true;
+            break;
+          }
+        }
 
-        if (!copy.has_password() && copy.has_user() &&
+        // TODO(alfredo) - kerberos/oci should disable password prompt in
+        // shell_options
+        if (should_prompt && copy.has_user() &&
             !copy.is_auth_method(mysqlshdk::db::kAuthMethodKerberos) &&
             !copy.is_auth_method(mysqlshdk::db::kAuthMethodOci)) {
           password_prompt(&copy);
@@ -583,9 +627,11 @@ Connection_options get_classic_connection_options(
     const std::shared_ptr<mysqlshdk::db::ISession> &session) {
   // copy the connection options
   auto co = session->get_connection_options();
+  if (co.is_interactive()) {
+    co.set_interactive(false);
+  }
   // switch from X protocol to classic
   if (SessionType::Classic != co.get_session_type()) {
-    co.clear_scheme();
     co.set_scheme("mysql");
 
     if (co.has_port()) {
@@ -598,7 +644,6 @@ Connection_options get_classic_connection_options(
             "connection");
       }
 
-      co.clear_port();
       co.set_port(row->get_int(0));
 
       // if we're here, we clear up local port, so establish session will find
