@@ -34,12 +34,14 @@
 #include <utility>
 #include <vector>
 
+#include "mysqlshdk/libs/utils/version.h"
+
 namespace mysqlsh {
 namespace compatibility {
 
 extern const std::set<std::string> k_mysqlaas_allowed_privileges;
 
-extern const std::set<std::string> k_mysqlaas_allowed_authentication_plugins;
+extern const std::unordered_set<std::string> k_mds_users_with_system_user_priv;
 
 struct Deferred_statements {
   struct Index_info {
@@ -116,10 +118,8 @@ Deferred_statements check_create_table_for_indexes(
     const std::string &statement, const std::string &table_name,
     bool fulltext_only);
 
-std::string check_create_user_for_authentication_plugin(
-    const std::string &create_user,
-    const std::set<std::string> &plugins =
-        k_mysqlaas_allowed_authentication_plugins);
+std::set<std::string> check_create_user_for_authentication_plugins(
+    std::string_view create_user);
 
 bool check_create_user_for_empty_password(const std::string &create_user);
 
@@ -169,8 +169,24 @@ std::string strip_default_role(const std::string &create_user,
 bool contains_sensitive_information(const std::string &statement);
 
 /**
- * Replaces the values of all single and double quoted strings with the given
- * text.
+ * Hides all sensitive information in the given statement.
+ *
+ * Supported statements:
+ *  - SET PASSWORD FOR
+ *
+ * Supported clauses:
+ *  - PASSWORD.* = 'string'
+ *  - PASSWORD.*('string')
+ *  - .*PASSWORD = 'string'
+ *  - .*PASSWORD('string')
+ *  - IDENTIFIED BY 'string' [REPLACE 'string']
+ *  - IDENTIFIED BY PASSWORD 'string'
+ *  - IDENTIFIED BY RANDOM PASSWORD REPLACE 'string'
+ *  - IDENTIFIED WITH plugin BY 'string' [REPLACE 'string']
+ *  - IDENTIFIED WITH plugin BY RANDOM PASSWORD REPLACE 'string'
+ *  - IDENTIFIED WITH plugin AS 'string'
+ *  - IDENTIFIED {VIA|WITH} plugin {USING|AS} 'string' [OR ...]
+ *  - IDENTIFIED {VIA|WITH} plugin {USING|AS} PASSWORD('string') [OR ...]
  *
  * @param statement Statement to be processed.
  * @param replacement Text to be used as a replacement.
@@ -178,9 +194,9 @@ bool contains_sensitive_information(const std::string &statement);
  *
  * @returns modified statement
  */
-std::string replace_quoted_strings(const std::string &statement,
-                                   std::string_view replacement,
-                                   std::vector<std::string> *replaced);
+std::string hide_sensitive_information(const std::string &statement,
+                                       std::string_view replacement,
+                                       std::vector<std::string_view> *replaced);
 
 struct Privilege_level_info {
   enum class Level {
@@ -195,7 +211,9 @@ struct Privilege_level_info {
   Level level = Level::GLOBAL;
   std::string schema;
   std::string object;
-  std::unordered_set<std::string> privileges;
+  std::set<std::string> privileges;
+  std::string account;
+  bool with_grant = false;
 };
 
 /**
@@ -210,6 +228,42 @@ struct Privilege_level_info {
 bool parse_grant_statement(const std::string &statement,
                            Privilege_level_info *info);
 
+/**
+ * Constructs a grant/revoke statement using provided information about
+ * privileges.
+ *
+ * NOTE: Given that parse_grant_statement() does not extract all the
+ *       information, currently only schema-level privileges are supported.
+ *
+ * @param info Information about privileges.
+ *
+ * @returns Corresponding grant/revoke statement.
+ */
+std::string to_grant_statement(const Privilege_level_info &info);
+
+/**
+ * Checks if server with the given version supports SET_ANY_DEFINER privilege.
+ *
+ * @param v Version to be checked.
+ *
+ * @returns true If server supports this privilege.
+ */
+bool supports_set_any_definer_privilege(const mysqlshdk::utils::Version &v);
+
+/**
+ * Replaces first occurrence of a keyword (case insensitive comparison) with the
+ * given value.
+ *
+ * @param stmt Statement to be checked.
+ * @param keyword Keyword to be replaced (cannot contain spaces).
+ * @param value Value to be replaced with.
+ * @param[out] result Statement after replacement.
+ *
+ * @returns true If keyword was found and replaced.
+ */
+bool replace_keyword(std::string_view stmt, std::string_view keyword,
+                     std::string_view value, std::string *result = nullptr);
+
 }  // namespace compatibility
 }  // namespace mysqlsh
 
