@@ -40,6 +40,8 @@ constexpr auto k_strip_tablespaces = "strip_tablespaces";
 constexpr auto k_skip_invalid_accounts = "skip_invalid_accounts";
 constexpr auto k_strip_invalid_grants = "strip_invalid_grants";
 constexpr auto k_ignore_wildcard_grants = "ignore_wildcard_grants";
+constexpr auto k_unescape_wildcard_grants = "unescape_wildcard_grants";
+constexpr auto k_force_non_standard_fks = "force_non_standard_fks";
 }  // namespace
 
 Compatibility_option to_compatibility_option(const std::string &c) {
@@ -58,6 +60,10 @@ Compatibility_option to_compatibility_option(const std::string &c) {
     return Compatibility_option::STRIP_INVALID_GRANTS;
   if (c == k_ignore_wildcard_grants)
     return Compatibility_option::IGNORE_WILDCARD_GRANTS;
+  if (c == k_unescape_wildcard_grants)
+    return Compatibility_option::UNESCAPE_WILDCARD_GRANTS;
+  if (c == k_force_non_standard_fks)
+    return Compatibility_option::FORCE_NON_STANDARD_FKS;
 
   throw std::invalid_argument("Unknown compatibility option: " + c);
 }
@@ -108,6 +114,12 @@ std::string to_string(Compatibility_option c) {
 
     case Compatibility_option::IGNORE_WILDCARD_GRANTS:
       return k_ignore_wildcard_grants;
+
+    case Compatibility_option::UNESCAPE_WILDCARD_GRANTS:
+      return k_unescape_wildcard_grants;
+
+    case Compatibility_option::FORCE_NON_STANDARD_FKS:
+      return k_force_non_standard_fks;
   }
 
   throw std::logic_error("Shouldn't happen, but compiler complains");
