@@ -25,9 +25,11 @@
 
 #include "modules/util/dump/progress_thread.h"
 
+#include <cassert>
 #include <cinttypes>
-
+#include <exception>
 #include <limits>
+#include <utility>
 
 #include "mysqlshdk/libs/textui/progress.h"
 #include "mysqlshdk/libs/utils/strformat.h"
@@ -53,9 +55,8 @@ std::string format_seconds(double seconds) {
 
 class Spinner_progress : public Progress_thread::Stage {
  public:
-  Spinner_progress(const std::string &description, bool show_progress,
-                   bool use_json)
-      : Stage(description, show_progress), m_spinner(description, use_json) {}
+  Spinner_progress(Progress_thread::Stage_config stage_config, bool use_json)
+      : Stage(std::move(stage_config)), m_spinner(description(), use_json) {}
 
  protected:
   void draw() override { m_spinner.update(); }
@@ -67,9 +68,9 @@ class Spinner_progress : public Progress_thread::Stage {
 
 class Numeric_progress : public Spinner_progress {
  public:
-  Numeric_progress(const std::string &description, bool show_progress,
-                   bool use_json, Progress_thread::Progress_config &&config)
-      : Spinner_progress(description, show_progress, use_json),
+  Numeric_progress(Progress_thread::Stage_config stage_config, bool use_json,
+                   Progress_thread::Progress_config config)
+      : Spinner_progress(std::move(stage_config), use_json),
         m_config(std::move(config)) {
     assert(m_config.current);
     assert(m_config.total);
@@ -81,13 +82,17 @@ class Numeric_progress : public Spinner_progress {
     const auto total = m_config.total();
     const auto total_ready =
         m_config.is_total_known ? m_config.is_total_known() : true;
+    const auto right_label = m_config.right_label ? m_config.right_label() : "";
+    const auto max_size =
+        k_max_size + (right_label.empty() ? 0 : right_label.size() + 1);
 
-    m_label.resize(k_max_size);
+    m_label.resize(max_size);
     // space at the end is there to compensate for the optional tilde before the
     // total value
     const auto size = snprintf(
-        &m_label[0], k_max_size, "%" PRIu64 " / %s%" PRIu64 "%s", current,
-        total_ready ? "" : "~", total, total_ready ? " " : "");
+        m_label.data(), max_size, "%" PRIu64 " / %s%" PRIu64 "%s%s%s", current,
+        total_ready ? "" : "~", total, right_label.empty() ? "" : " ",
+        right_label.c_str(), total_ready ? " " : "");
     m_label.resize(size);
 
     m_spinner.set_right_label(m_label);
@@ -114,11 +119,11 @@ class Numeric_progress : public Spinner_progress {
 
 class Throughput_progress : public Progress_thread::Stage {
  public:
-  Throughput_progress(const std::string &description, bool show_progress,
-                      Progress_thread::Throughput_config &&config,
+  Throughput_progress(Progress_thread::Stage_config stage_config,
+                      Progress_thread::Throughput_config config,
                       mysqlshdk::textui::Base_progress *progress,
                       std::recursive_mutex *mutex)
-      : Stage(description, show_progress),
+      : Stage(std::move(stage_config)),
         m_config(std::move(config)),
         m_progress(progress),
         m_progress_mutex(mutex) {
@@ -241,21 +246,30 @@ void Progress_thread::Duration::validate() const {
   }
 }
 
-Progress_thread::Stage::Stage(const std::string &description,
-                              bool show_progress)
-    : m_description(description), m_show_progress(show_progress) {}
+Progress_thread::Stage::Stage(Stage_config config)
+    : m_config(std::move(config)) {
+  assert(m_config.show_progress.has_value());
+}
 
 void Progress_thread::Stage::start() {
-  log_debug("%s%s", description().c_str(), k_ellipsis);
+  if (m_config.log_progress) {
+    log_debug("%s%s", description().c_str(), k_ellipsis);
+  }
 
-  if (!m_show_progress) {
+  if (!*m_config.show_progress) {
     current_console()->print_status(description() + k_ellipsis);
   }
 
   m_duration.start();
+  m_started = true;
 }
 
 void Progress_thread::Stage::finish(bool wait) {
+  if (!m_terminated && std::uncaught_exceptions()) {
+    terminate();
+    return;
+  }
+
   bool has_finished = false;
 
   {
@@ -276,10 +290,12 @@ void Progress_thread::Stage::finish(bool wait) {
     }
 
     if (!m_terminated) {
-      log_info("%s %s, duration: %f seconds", description().c_str(), k_done,
-               duration().seconds());
+      if (m_config.log_progress) {
+        log_info("%s %s, duration: %f seconds", description().c_str(), k_done,
+                 duration().seconds());
+      }
 
-      if (!m_show_progress) {
+      if (!*m_config.show_progress) {
         current_console()->print_status(description() + " " + k_done);
       }
     }
@@ -292,14 +308,14 @@ void Progress_thread::Stage::display() {
   while (!m_finished) {
     on_update();
 
-    if (m_show_progress) {
+    if (*m_config.show_progress) {
       draw();
     }
 
     wait_for_finish();
   }
 
-  if (m_show_progress) {
+  if (*m_config.show_progress) {
     if (m_terminated) {
       on_display_terminated();
     } else {
@@ -327,31 +343,41 @@ void Progress_thread::Stage::wait_for_finish() {
   std::unique_lock<std::mutex> lock(m_finished_mutex);
 
   m_finished_cv.wait_for(lock, std::chrono::milliseconds(k_update_every_ms),
-                         [this]() { return m_finished; });
+                         [this]() { return m_finished.load(); });
 }
 
 void Progress_thread::Stage::wait_for_display_done() {
   std::unique_lock<std::mutex> lock(m_display_done_mutex);
 
-  m_display_done_cv.wait(lock, [this]() { return m_display_done; });
+  m_display_done_cv.wait(lock, [this]() { return m_display_done.load(); });
 }
 
 void Progress_thread::Stage::terminate() {
+  if (m_finished) {
+    return;
+  }
+
   m_terminated = true;
   finish(false);
 }
 
-Progress_thread::Progress_thread(const std::string &description,
-                                 bool show_progress)
-    : m_description(description), m_show_progress(show_progress) {
+void Progress_thread::Stage::toggle_visibility(bool show) {
+  m_config.show_progress = show;
+}
+
+Progress_thread::Progress_thread(std::string description, bool show_progress)
+    : m_description(std::move(description)), m_show_progress(show_progress) {
   m_json_output = "off" != mysqlsh::current_shell_options()->get().wrap_json;
 
-  if (m_show_progress) {
-    if (m_json_output) {
-      m_progress = std::make_unique<mysqlshdk::textui::Json_progress>();
-    } else {
-      m_progress = std::make_unique<mysqlshdk::textui::Text_progress>();
-    }
+  if (m_json_output) {
+    m_progress = std::make_unique<mysqlshdk::textui::Json_progress>();
+  } else {
+    m_progress = std::make_unique<mysqlshdk::textui::Text_progress>();
+  }
+
+  if (!m_show_progress) {
+    std::lock_guard lock{m_progress_mutex};
+    m_progress->hide(true);
   }
 
   m_console =
@@ -396,45 +422,86 @@ void Progress_thread::start() {
 }
 
 Progress_thread::Stage *Progress_thread::start_stage(
-    const std::string &description) {
-  return start_stage<Spinner_progress>(description, m_json_output);
+    Stage_config stage_config) {
+  return start_stage<Spinner_progress>(std::move(stage_config), m_json_output);
 }
 
-Progress_thread::Stage *Progress_thread::start_stage(
-    const std::string &description, Progress_config &&config) {
-  return start_stage<Numeric_progress>(description, m_json_output,
+Progress_thread::Stage *Progress_thread::start_stage(Stage_config stage_config,
+                                                     Progress_config config) {
+  return start_stage<Numeric_progress>(std::move(stage_config), m_json_output,
                                        std::move(config));
 }
 
-Progress_thread::Stage *Progress_thread::start_stage(
-    const std::string &description, Throughput_config &&config) {
-  return start_stage<Throughput_progress>(description, std::move(config),
-                                          m_progress.get(), &m_progress_mutex);
+Progress_thread::Stage *Progress_thread::start_stage(Stage_config stage_config,
+                                                     Throughput_config config) {
+  return start_stage<Throughput_progress>(std::move(stage_config),
+                                          std::move(config), m_progress.get(),
+                                          &m_progress_mutex);
+}
+
+Progress_thread::Stage *Progress_thread::push_stage(Stage_config stage_config) {
+  return push_stage<Spinner_progress>(std::move(stage_config), m_json_output);
+}
+
+Progress_thread::Stage *Progress_thread::push_stage(Stage_config stage_config,
+                                                    Progress_config config) {
+  return push_stage<Numeric_progress>(std::move(stage_config), m_json_output,
+                                      std::move(config));
+}
+
+Progress_thread::Stage *Progress_thread::push_stage(Stage_config stage_config,
+                                                    Throughput_config config) {
+  return push_stage<Throughput_progress>(std::move(stage_config),
+                                         std::move(config), m_progress.get(),
+                                         &m_progress_mutex);
 }
 
 void Progress_thread::finish() {
-  shutdown();
-  wait_for_thread();
-  m_total_duration.finish();
-  rethrow();
+  if (std::uncaught_exceptions()) {
+    terminate();
+  } else {
+    shutdown();
+    wait_for_thread();
+    m_total_duration.finish();
+    rethrow();
+  }
 }
 
-void Progress_thread::terminate() { emergency_shutdown(); }
+void Progress_thread::terminate() {
+  m_total_duration.finish();
+  kill_thread();
+}
+
+void Progress_thread::show() { toggle_visibility(true); }
+
+void Progress_thread::hide() { toggle_visibility(false); }
 
 template <class T, class... Args>
-Progress_thread::Stage *Progress_thread::start_stage(
-    const std::string &description, Args &&... args) {
+Progress_thread::Stage *Progress_thread::start_stage(Stage_config stage_config,
+                                                     Args &&...args) {
+  auto stage =
+      push_stage<T>(std::move(stage_config), std::forward<Args>(args)...);
+  stage->start();
+  return stage;
+}
+
+template <class T, class... Args>
+Progress_thread::Stage *Progress_thread::push_stage(Stage_config stage_config,
+                                                    Args &&...args) {
   if (!m_progress_thread) {
     start();
   }
 
-  std::unique_ptr<Stage> stage_ptr = std::make_unique<T>(
-      description, m_show_progress, std::forward<Args>(args)...);
+  if (!stage_config.show_progress.has_value()) {
+    stage_config.show_progress = m_show_progress;
+  }
+
+  std::unique_ptr<Stage> stage_ptr =
+      std::make_unique<T>(std::move(stage_config), std::forward<Args>(args)...);
   auto stage = stage_ptr.get();
 
   m_stages.emplace_back(std::move(stage_ptr));
 
-  stage->start();
   m_schedule.push(stage);
 
   return stage;
@@ -478,5 +545,20 @@ void Progress_thread::kill_thread() {
   wait_for_thread();
 }
 
+void Progress_thread::toggle_visibility(bool show) {
+  auto expected = !show;
+
+  if (m_show_progress.compare_exchange_strong(expected, show)) {
+    {
+      std::lock_guard lock{m_progress_mutex};
+      m_progress->hide(!show);
+    }
+
+    for (const auto &stage : m_stages) {
+      stage->toggle_visibility(show);
+    }
+  }
+}
+
 }  // namespace dump
 }  // namespace mysqlsh
