@@ -32,7 +32,10 @@
 #include <utility>
 
 #include "modules/mod_utils.h"
+#include "modules/util/common/dump/utils.h"
 #include "modules/util/import_table/helpers.h"
+#include "mysqlshdk/include/scripting/type_info/custom.h"
+#include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/include/shellcore/base_session.h"
 #include "mysqlshdk/include/shellcore/console.h"
@@ -42,6 +45,7 @@
 #include "mysqlshdk/libs/storage/ifile.h"
 #include "mysqlshdk/libs/utils/strformat.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
+#include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_path.h"
 
 namespace {
@@ -127,9 +131,9 @@ const shcore::Option_pack_def<Import_table_option_pack>
                     &Import_table_option_pack::set_bytes_per_chunk)
           .optional("maxBytesPerTransaction",
                     &Import_table_option_pack::set_max_transaction_size)
-          .optional("columns", &Import_table_option_pack::m_columns)
+          .optional("columns", &Import_table_option_pack::set_columns)
           .optional("replaceDuplicates",
-                    &Import_table_option_pack::m_replace_duplicates)
+                    &Import_table_option_pack::set_replace_duplicates)
           .optional("maxRate", &Import_table_option_pack::set_max_rate)
           .optional("showProgress", &Import_table_option_pack::m_show_progress)
           .optional("skipRows", &Import_table_option_pack::m_skip_rows_count)
@@ -151,6 +155,14 @@ void Import_table_option_pack::set_filenames(
     const std::vector<std::string> &filenames) {
   m_filelist_from_user = filenames;
 
+  // remove empty paths provided by user
+  m_filelist_from_user.erase(
+      std::remove_if(m_filelist_from_user.begin(), m_filelist_from_user.end(),
+                     [](const auto &s) { return s.empty(); }),
+      m_filelist_from_user.end());
+
+  m_is_multifile = check_if_multifile();
+
   if (!is_multifile()) {
     // If loading single file, chunk size defaults to 50M if not specified by
     // the user.
@@ -162,10 +174,16 @@ void Import_table_option_pack::set_filenames(
     // If loading single file, table name is taken from the file if not
     // specified by the user.
     if (m_table.empty()) {
-      m_table = std::get<0>(shcore::path::split_extension(
-          shcore::path::basename(m_filelist_from_user[0])));
+      m_table = std::get<0>(
+          shcore::path::split_extension(shcore::path::basename(single_file())));
     }
   }
+
+  if (!storage_config() && !m_filelist_from_user.empty()) {
+    // if this is a PAR, we want to use a retry strategy
+    m_storage_config =
+        mysqlsh::dump::common::get_par_config(m_filelist_from_user[0]);
+  }
 }
 
 void Import_table_option_pack::set_decode_columns(
@@ -175,7 +193,7 @@ void Import_table_option_pack::set_decode_columns(
   }
 
   for (const auto &it : *decode_columns) {
-    if (it.second.type != shcore::Null) {
+    if (it.second.get_type() != shcore::Null) {
       auto transformation = it.second.descr();
       if (shcore::str_caseeq(transformation, std::string{"UNHEX"}) ||
           shcore::str_caseeq(transformation, std::string{"FROM_BASE64"})) {
@@ -194,30 +212,68 @@ void Import_table_option_pack::set_decode_columns(
     }
   }
 
-  if (!m_decode_columns.empty()) {
-    if (!m_columns) {
-      throw std::runtime_error(
-          "The 'columns' option is required when 'decodeColumns' is set.");
-    }
-    if (m_columns->empty()) {
-      throw std::runtime_error(
-          "The 'columns' option must be a non-empty list.");
+  if (!m_decode_columns.empty() && m_columns.empty()) {
+    throw std::runtime_error(
+        "The 'columns' option is required when 'decodeColumns' is set.");
+  }
+}
+
+void Import_table_option_pack::set_columns(const shcore::Array_t &columns) {
+  if (!columns || columns->empty()) {
+    throw std::runtime_error("The 'columns' option must be a non-empty list.");
+  }
+
+  for (const auto &c : *columns) {
+    if (c.get_type() == shcore::Value_type::UInteger) {
+      m_columns.emplace_back(c.as_uint());
+    } else if (c.get_type() == shcore::Value_type::Integer) {
+      const auto v = c.as_int();
+
+      // We do not want user variable to be negative: `@-1`
+      if (v < 0) {
+        throw shcore::Exception::value_error(
+            "User variable binding in 'columns' option must be non-negative "
+            "integer value");
+      }
+
+      m_columns.emplace_back(static_cast<uint64_t>(v));
+    } else if (c.get_type() == shcore::Value_type::String) {
+      m_columns.emplace_back(c.as_string());
+    } else {
+      throw shcore::Exception::type_error(
+          "Option 'columns' " + type_name(shcore::Value_type::String) +
+          " (column name) or non-negative " +
+          type_name(shcore::Value_type::Integer) +
+          " (user variable binding) expected, but value is " +
+          type_name(c.get_type()));
     }
   }
 }
 
-bool Import_table_option_pack::is_multifile() const {
+bool Import_table_option_pack::check_if_multifile() {
   if (m_filelist_from_user.size() == 1) {
-    if (has_wildcard(m_filelist_from_user[0])) {
-      return true;
+    if (storage_config() ||
+        shcore::OperatingSystem::WINDOWS != shcore::get_os_type()) {
+      // local non-Windows and remote filesystems allow for * and ? characters
+      // in file names
+      // BUG#35895247: if all wildcard characters are escaped, load the file in
+      // chunks
+      if (auto path = shcore::unescape_glob(m_filelist_from_user[0]);
+          path.has_value()) {
+        m_filelist_from_user[0] = std::move(*path);
+        return false;
+      } else {
+        return true;
+      }
+    } else {
+      return has_wildcard(m_filelist_from_user[0]);
     }
-
-    return false;
   }
+
   return true;
 }
 
-bool Import_table_option_pack::is_compressed(const std::string &path) const {
+bool Import_table_option_pack::is_compressed(const std::string &path) {
   using mysqlshdk::storage::Compression;
   using mysqlshdk::storage::get_extension;
 
@@ -227,6 +283,14 @@ bool Import_table_option_pack::is_compressed(const std::string &path) const {
          extension == get_extension(Compression::ZSTD);
 }
 
+void Import_table_option_pack::set_replace_duplicates(bool flag) {
+  if (flag) {
+    set_duplicate_handling(Duplicate_handling::Replace);
+  } else {
+    set_duplicate_handling(Duplicate_handling::Ignore);
+  }
+}
+
 Import_table_options::Import_table_options(
     const Import_table_option_pack &pack) {
   // Copies the options defined in pack into this object
@@ -234,6 +298,13 @@ Import_table_options::Import_table_options(
   this_pack = pack;
 }
 
+Import_table_options Import_table_options::unpack(
+    const shcore::Dictionary_t &options) {
+  Import_table_options ret;
+  Import_table_options::options().unpack(options, &ret);
+  return ret;
+}
+
 void Import_table_options::validate() {
   if (m_table.empty()) {
     throw std::runtime_error(
@@ -241,12 +312,6 @@ void Import_table_options::validate() {
         "must be provided in the options.");
   }
 
-  // remove empty paths provided by user
-  m_filelist_from_user.erase(
-      std::remove_if(m_filelist_from_user.begin(), m_filelist_from_user.end(),
-                     [](const auto &s) { return s.empty(); }),
-      m_filelist_from_user.end());
-
   if (m_filelist_from_user.empty()) {
     throw std::runtime_error("File list cannot be empty.");
   }
@@ -283,13 +348,15 @@ void Import_table_options::validate() {
           "multiple files.");
     }
   } else {
-    if (!m_filelist_from_user[0].empty()) {
-      m_file_handle = create_file_handle(m_filelist_from_user[0]);
-      m_file_handle->open(mysqlshdk::storage::Mode::READ);
-      m_file_size = m_file_handle->file_size();
-      m_file_handle->close();
-    }
+    const auto handle = create_file_handle(single_file());
+    // open the file to check if it's readable
+    handle->open(mysqlshdk::storage::Mode::READ);
+    handle->close();
+    // cache some values
+    m_file_size = handle->file_size();
+    m_full_path = handle->full_path().masked();
   }
+
   m_threads_size = calc_thread_size();
 }
 
@@ -313,23 +380,23 @@ Import_table_option_pack::create_file_handle(
   return mysqlshdk::storage::make_file(std::move(file_handler), compr);
 }
 
-size_t Import_table_option_pack::calc_thread_size() {
+size_t Import_table_options::calc_thread_size() {
   // We need at least one thread
   int64_t threads_size = std::max(static_cast<int64_t>(1), m_threads_size);
 
   if (!is_multifile()) {
-    if (is_compressed(m_filelist_from_user[0])) {
-      // a single compressed file cannot be chunked, we're going to use a single
-      // thread
-      threads_size = 1;
-    } else {
-      // We do not need to spawn more threads than file chunks
-      const size_t calculated_threads = (m_file_size / bytes_per_chunk()) + 1;
-      if (calculated_threads <
-          static_cast<size_t>(std::numeric_limits<int64_t>::max())) {
-        threads_size =
-            std::min(threads_size, static_cast<int64_t>(calculated_threads));
+    if (dialect_supports_chunking()) {
+      if (!is_compressed(single_file())) {
+        // We do not need to spawn more threads than file chunks
+        const size_t calculated_threads = (m_file_size / bytes_per_chunk()) + 1;
+        if (calculated_threads <
+            static_cast<size_t>(std::numeric_limits<int64_t>::max())) {
+          threads_size =
+              std::min(threads_size, static_cast<int64_t>(calculated_threads));
+        }
       }
+    } else {
+      threads_size = 1;
     }
   }
   return threads_size;
@@ -371,13 +438,12 @@ Connection_options Import_table_options::connection_options() const {
   connection_options.set(mysqlshdk::db::kLocalInfile, "true");
 
   // Set long timeouts by default
-  const std::string timeout =
-      std::to_string(24 * 3600 * 1000);  // 1 day in milliseconds
-  if (!connection_options.has(mysqlshdk::db::kNetReadTimeout)) {
-    connection_options.set(mysqlshdk::db::kNetReadTimeout, timeout);
+  constexpr auto timeout = 24 * 3600 * 1000;  // 1 day in milliseconds
+  if (!connection_options.has_net_read_timeout()) {
+    connection_options.set_net_read_timeout(timeout);
   }
-  if (!connection_options.has(mysqlshdk::db::kNetWriteTimeout)) {
-    connection_options.set(mysqlshdk::db::kNetWriteTimeout, timeout);
+  if (!connection_options.has_net_write_timeout()) {
+    connection_options.set_net_write_timeout(timeout);
   }
 
   return connection_options;
@@ -428,26 +494,33 @@ size_t Import_table_option_pack::max_transaction_size() const {
 }
 
 std::string Import_table_options::target_import_info() const {
-  auto connection_options = m_base_session->get_connection_options();
+  const auto uri = m_base_session->get_connection_options().as_uri(
+      mysqlshdk::db::uri::formats::only_transport());
+  std::string info_msg = "Importing from ";
 
-  if (!is_multifile()) {
-    std::string info_msg = "Importing from file '" + full_path().masked() +
-                           "' to table `" + schema() + "`.`" + table() +
-                           "` in MySQL Server at " +
-                           connection_options.as_uri(
-                               mysqlshdk::db::uri::formats::only_transport()) +
-                           " using " + std::to_string(threads_size());
-    info_msg += threads_size() == 1 ? " thread" : " threads";
-    return info_msg;
+  if (is_multifile()) {
+    info_msg += "multiple files";
+  } else {
+    info_msg += "file '";
+    info_msg += masked_full_path();
+    info_msg += '\'';
   }
-  std::string info_msg =
-      "Importing from multiple files to table `" + schema() + "`.`" + table() +
-      "` in MySQL Server at " +
-      connection_options.as_uri(mysqlshdk::db::uri::formats::only_transport()) +
-      " using " + std::to_string(threads_size());
-  info_msg += threads_size() == 1 ? " thread" : " threads";
+
+  info_msg += " to table `" + schema() + "`.`" + table() +
+              "` in MySQL Server at " + uri + " using " +
+              std::to_string(threads_size()) + " thread";
+
+  if (1 != threads_size()) {
+    info_msg += 's';
+  }
+
   return info_msg;
 }
 
+bool Import_table_options::dialect_supports_chunking() const {
+  return !m_dialect.lines_terminated_by.empty() &&
+         m_dialect.lines_terminated_by != m_dialect.fields_terminated_by;
+}
+
 }  // namespace import_table
 }  // namespace mysqlsh
