@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -26,17 +28,18 @@
 #include <mysqld_error.h>
 
 #include <algorithm>
+#include <iterator>
 #include <regex>
 #include <utility>
 
 #include "modules/mod_utils.h"
 #include "modules/util/common/dump/constants.h"
 #include "modules/util/common/dump/utils.h"
-#include "modules/util/dump/dump_manifest_config.h"
 #include "modules/util/load/load_errors.h"
 #include "mysqlshdk/include/scripting/type_info/custom.h"
 #include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/shellcore/console.h"
+#include "mysqlshdk/libs/aws/s3_bucket_config.h"
 #include "mysqlshdk/libs/mysql/instance.h"
 #include "mysqlshdk/libs/oci/oci_par.h"
 #include "mysqlshdk/libs/storage/backend/oci_par_directory_config.h"
@@ -44,6 +47,7 @@
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/strformat.h"
 #include "mysqlshdk/libs/utils/utils_lexing.h"
+#include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlsh {
@@ -53,30 +57,17 @@ using Version = mysqlshdk::utils::Version;
 
 constexpr auto k_minimum_max_bytes_per_transaction = 4096;
 
-bool is_mds(const Version &version) {
-  return shcore::str_endswith(version.get_extra(), "cloud");
-}
+std::string bulk_load_s3_prefix(
+    const std::shared_ptr<mysqlshdk::aws::S3_bucket_config> &config) {
+  // 's3-region://bucket-name/file-name-or-prefix'
+  std::string prefix = "s3-";
 
-std::shared_ptr<mysqlshdk::oci::IPAR_config> par_config(
-    const std::string &url) {
-  mysqlshdk::oci::PAR_structure par;
+  prefix += config->region();
+  prefix += "://";
+  prefix += config->bucket_name();
+  prefix += '/';
 
-  switch (mysqlshdk::oci::parse_par(url, &par)) {
-    case mysqlshdk::oci::PAR_type::MANIFEST:
-      return std::make_shared<dump::Dump_manifest_read_config>(par);
-
-    case mysqlshdk::oci::PAR_type::PREFIX:
-      return std::make_shared<
-          mysqlshdk::storage::backend::oci::Oci_par_directory_config>(par);
-
-    case mysqlshdk::oci::PAR_type::GENERAL:
-      return std::make_shared<mysqlshdk::oci::General_par_config>(par);
-
-    case mysqlshdk::oci::PAR_type::NONE:
-      break;
-  }
-
-  return {};
+  return prefix;
 }
 
 }  // namespace
@@ -102,15 +93,15 @@ const shcore::Option_pack_def<Load_dump_options> &Load_dump_options::options() {
           .optional("resetProgress", &Load_dump_options::m_reset_progress)
           .optional("progressFile", &Load_dump_options::set_progress_file)
           .include(&Load_dump_options::m_filtering_options,
-                   &dump::common::Filtering_options::events)
+                   &Filtering_options::events)
           .include(&Load_dump_options::m_filtering_options,
-                   &dump::common::Filtering_options::routines)
+                   &Filtering_options::routines)
           .include(&Load_dump_options::m_filtering_options,
-                   &dump::common::Filtering_options::schemas)
+                   &Filtering_options::schemas)
           .include(&Load_dump_options::m_filtering_options,
-                   &dump::common::Filtering_options::tables)
+                   &Filtering_options::tables)
           .include(&Load_dump_options::m_filtering_options,
-                   &dump::common::Filtering_options::triggers)
+                   &Filtering_options::triggers)
           .optional("characterSet", &Load_dump_options::m_character_set)
           .optional("skipBinlog", &Load_dump_options::m_skip_binlog)
           .optional("ignoreExistingObjects",
@@ -128,12 +119,12 @@ const shcore::Option_pack_def<Load_dump_options> &Load_dump_options::options() {
           .optional("loadIndexes", &Load_dump_options::m_load_indexes)
           .optional("schema", &Load_dump_options::m_target_schema)
           .include(&Load_dump_options::m_filtering_options,
-                   &dump::common::Filtering_options::users)
+                   &Filtering_options::users)
           .optional("updateGtidSet", &Load_dump_options::m_update_gtid_set,
                     {{"append", Update_gtid_set::APPEND},
                      {"replace", Update_gtid_set::REPLACE},
                      {"off", Update_gtid_set::OFF}})
-          .optional("showMetadata", &Load_dump_options::m_show_metadata)
+          .optional("showMetadata", &Load_dump_options::set_show_metadata)
           .optional("createInvisiblePKs",
                     &Load_dump_options::m_create_invisible_pks)
           .optional("maxBytesPerTransaction",
@@ -141,6 +132,8 @@ const shcore::Option_pack_def<Load_dump_options> &Load_dump_options::options() {
           .optional("sessionInitSql", &Load_dump_options::m_session_init_sql)
           .optional("handleGrantErrors",
                     &Load_dump_options::set_handle_grant_errors)
+          .optional("checksum", &Load_dump_options::m_checksum)
+          .optional("disableBulkLoad", &Load_dump_options::m_disable_bulk_load)
           .include(&Load_dump_options::m_oci_bucket_options)
           .include(&Load_dump_options::m_s3_bucket_options)
           .include(&Load_dump_options::m_blob_storage_options)
@@ -179,13 +172,12 @@ void Load_dump_options::set_max_bytes_per_transaction(
 void Load_dump_options::set_progress_file(const std::string &value) {
   m_progress_file = value;
 
-  auto config = par_config(value);
+  auto config = dump::common::get_par_config(value);
 
   if (config && config->valid()) {
     if (mysqlshdk::oci::PAR_type::GENERAL != config->par().type()) {
       throw shcore::Exception::argument_error(
-          "Invalid PAR for progress file, use a PAR to a specific file "
-          "different than the manifest");
+          "Invalid PAR for progress file, use a PAR to a specific file");
     }
 
     m_progress_file_config = std::move(config);
@@ -193,10 +185,8 @@ void Load_dump_options::set_progress_file(const std::string &value) {
 }
 
 void Load_dump_options::set_session(
-    const std::shared_ptr<mysqlshdk::db::ISession> &session,
-    const std::string &current_schema) {
+    const std::shared_ptr<mysqlshdk::db::ISession> &session) {
   m_base_session = session;
-  m_current_schema = current_schema;
 
   m_target = get_classic_connection_options(m_base_session);
 
@@ -206,12 +196,12 @@ void Load_dump_options::set_session(
   m_target.set(mysqlshdk::db::kLocalInfile, "true");
 
   // Set long timeouts by default
-  std::string timeout = "86400000";  // 1 day in milliseconds
-  if (!m_target.has(mysqlshdk::db::kNetReadTimeout)) {
-    m_target.set(mysqlshdk::db::kNetReadTimeout, timeout);
+  constexpr auto timeout = 86400000;  // 1 day in milliseconds
+  if (!m_target.has_net_read_timeout()) {
+    m_target.set_net_read_timeout(timeout);
   }
-  if (!m_target.has(mysqlshdk::db::kNetWriteTimeout)) {
-    m_target.set(mysqlshdk::db::kNetWriteTimeout, timeout);
+  if (!m_target.has_net_write_timeout()) {
+    m_target.set_net_write_timeout(timeout);
   }
 
   // set size of max packet (~size of 1 row) we can send to server
@@ -224,8 +214,10 @@ void Load_dump_options::set_session(
 
   m_target_server_version =
       Version(query("SELECT @@version")->fetch_one()->get_string(0));
+  DBUG_EXECUTE_IF("dump_loader_bulk_unsupported_version",
+                  { m_target_server_version = Version(8, 3, 0); });
 
-  m_is_mds = ::mysqlsh::is_mds(m_target_server_version);
+  m_is_mds = m_target_server_version.is_mds();
   DBUG_EXECUTE_IF("dump_loader_force_mds", { m_is_mds = true; });
 
   m_sql_generate_invisible_primary_key =
@@ -308,28 +300,28 @@ void Load_dump_options::set_session(
 
 void Load_dump_options::validate() {
   if (!m_storage_config || !m_storage_config->valid()) {
-    auto config = par_config(m_url);
+    auto config = dump::common::get_par_config(m_url);
 
     if (config && config->valid()) {
-      if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type() ||
-          mysqlshdk::oci::PAR_type::PREFIX == config->par().type()) {
-        if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type()) {
-          current_console()->print_warning(
-              "Support for PAR Manifest is deprecated and will be removed in a "
-              "future release. Please use a prefix PAR instead.");
-        }
+      if (mysqlshdk::oci::PAR_type::PREFIX == config->par().type()) {
         if (!m_progress_file.has_value()) {
           throw shcore::Exception::argument_error(
               "When using a PAR to load a dump, the progressFile option must "
               "be defined");
         }
       } else {
-        current_console()->print_warning(
-            "The given URL is not a prefix PAR or a PAR to the @.manifest.json "
-            "file.");
+        current_console()->print_warning("The given URL is not a prefix PAR.");
       }
 
-      m_storage_config = std::move(config);
+      if (mysqlshdk::oci::PAR_type::PREFIX == config->par().type()) {
+        // prefix PAR is supported by the bulk loader
+        m_bulk_load_info.fs = Bulk_load_fs::URL;
+      }
+
+      set_storage_config(std::move(config));
+    } else {
+      // no configuration, we're loading from the local FS
+      m_bulk_load_info.fs = Bulk_load_fs::INFILE;
     }
   }
 
@@ -342,16 +334,19 @@ void Load_dump_options::validate() {
       mysqlsh::current_console()->print_error(
           "The 'local_infile' global system variable must be set to ON in "
           "the target server, after the server is verified to be trusted.");
-      THROW_ERROR0(SHERR_LOAD_LOCAL_INFILE_DISABLED);
+      THROW_ERROR(SHERR_LOAD_LOCAL_INFILE_DISABLED);
     }
   }
 
   if (!m_progress_file.has_value()) {
     m_default_progress_file = "load-progress." + m_server_uuid + ".json";
   }
+
+  configure_bulk_load();
 }
 
-std::string Load_dump_options::target_import_info() const {
+std::string Load_dump_options::target_import_info(
+    const char *operation, const std::string &extra) const {
   std::string action;
 
   std::vector<std::string> what_to_load;
@@ -370,41 +365,54 @@ std::string Load_dump_options::target_import_info() const {
 
   // this is validated earlier on
   assert(!what_to_load.empty() || m_analyze_tables != Analyze_table_mode::OFF ||
-         m_update_gtid_set != Update_gtid_set::OFF);
+         m_update_gtid_set != Update_gtid_set::OFF || m_checksum);
 
-  if (what_to_load.size() == 3) {
-    action = shcore::str_format(
-        "Loading %s, %s and %s from %s", what_to_load[0].c_str(),
-        what_to_load[1].c_str(), what_to_load[2].c_str(), where.c_str());
-  } else if (what_to_load.size() == 2) {
-    action =
-        shcore::str_format("Loading %s and %s from %s", what_to_load[0].c_str(),
-                           what_to_load[1].c_str(), where.c_str());
-  } else if (!what_to_load.empty()) {
-    action = shcore::str_format("Loading %s only from %s",
-                                what_to_load[0].c_str(), where.c_str());
+  const auto concat = [&what_to_load]() {
+    if (1 == what_to_load.size()) {
+      return what_to_load[0] + " only";
+    }
+
+    auto msg = shcore::str_join(what_to_load.begin(),
+                                std::prev(what_to_load.end()), ", ");
+    msg += " and ";
+    msg += what_to_load.back();
+
+    return msg;
+  };
+
+  if (!what_to_load.empty()) {
+    action = shcore::str_format("%s %s from %s", operation, concat().c_str(),
+                                where.c_str());
   } else {
-    if (m_analyze_tables == Analyze_table_mode::HISTOGRAM)
-      action = "Updating table histograms";
-    else if (m_analyze_tables == Analyze_table_mode::ON)
-      action = "Updating table histograms and key distribution statistics";
+    if (m_analyze_tables == Analyze_table_mode::HISTOGRAM) {
+      what_to_load.emplace_back("Updating table histograms");
+    } else if (m_analyze_tables == Analyze_table_mode::ON) {
+      what_to_load.emplace_back(
+          "Updating table histograms and key distribution statistics");
+    }
+
     if (m_update_gtid_set != Update_gtid_set::OFF) {
-      if (!action.empty())
-        action += ", and updating GTID_PURGED";
-      else
-        action = "Updating GTID_PURGED";
+      what_to_load.emplace_back("Updating GTID_PURGED");
+    }
+
+    if (m_checksum) {
+      what_to_load.emplace_back("Verifying checksum information");
+    }
+
+    action = concat();
+  }
+
+  std::string detail = extra;
+
+  if (detail.empty()) {
+    detail = " using " + std::to_string(threads_count()) + " thread";
+
+    if (threads_count() != 1) {
+      detail += 's';
     }
   }
 
-  std::string detail;
-
-  if (threads_count() == 1)
-    detail = " using 1 thread.";
-  else
-    detail = shcore::str_format(" using %s threads.",
-                                std::to_string(threads_count()).c_str());
-
-  return action + detail;
+  return action + detail + '.';
 }
 
 void Load_dump_options::on_unpacked_options() {
@@ -413,20 +421,28 @@ void Load_dump_options::on_unpacked_options() {
   m_blob_storage_options.throw_on_conflict(m_oci_bucket_options);
 
   if (m_oci_bucket_options) {
-    m_storage_config = m_oci_bucket_options.config();
+    set_storage_config(m_oci_bucket_options.config());
   }
 
   if (m_s3_bucket_options) {
-    m_storage_config = m_s3_bucket_options.config();
+    auto config = m_s3_bucket_options.s3_config();
+
+    if (config->valid() && m_s3_bucket_options.endpoint_override().empty()) {
+      // S3 is supported by the bulk loader
+      m_bulk_load_info.fs = Bulk_load_fs::S3;
+      m_bulk_load_info.file_prefix = bulk_load_s3_prefix(config);
+    }
+
+    set_storage_config(std::move(config));
   }
 
   if (m_blob_storage_options) {
-    m_storage_config = m_blob_storage_options.config();
+    set_storage_config(m_blob_storage_options.config());
   }
 
   if (!m_load_data && !m_load_ddl && !m_load_users &&
       m_analyze_tables == Analyze_table_mode::OFF &&
-      m_update_gtid_set == Update_gtid_set::OFF) {
+      m_update_gtid_set == Update_gtid_set::OFF && !m_checksum) {
     throw shcore::Exception::argument_error(
         "At least one of loadData, loadDdl or loadUsers options must be "
         "enabled");
@@ -533,4 +549,139 @@ void Load_dump_options::set_handle_grant_errors(const std::string &action) {
   }
 }
 
+void Load_dump_options::set_storage_config(
+    std::shared_ptr<mysqlshdk::storage::Config> storage_config) {
+  m_storage_config = std::move(storage_config);
+}
+
+void Load_dump_options::configure_bulk_load() {
+  if (m_disable_bulk_load) {
+    log_info("BULK LOAD is explicitly disabled");
+    return;
+  }
+
+  if (Bulk_load_fs::UNSUPPORTED == m_bulk_load_info.fs) {
+    log_info("BULK LOAD: unsupported FS");
+    return;
+  }
+
+  if (m_target_server_version < Version(8, 4, 0)) {
+    // minimum version which supports required syntax is 8.4.0
+    log_info("BULK LOAD: unsupported version");
+    return;
+  }
+
+  const auto instance = mysqlshdk::mysql::Instance(m_base_session);
+
+  // this is actually an unsigned integer, but allowed values are within int64_t
+  // range
+  m_bulk_load_info.threads =
+      instance.get_sysvar_int("bulk_loader.concurrency").value_or(0);
+
+  if (!m_bulk_load_info.threads) {
+    log_info("BULK LOAD: component is not loaded");
+    return;
+  }
+
+  if (!m_skip_binlog && instance.get_sysvar_bool("log_bin").value_or(false)) {
+    // BULK LOAD statement is not replicated
+    log_info("BULK LOAD: binlog is enabled and 'skipBinlog' option is false");
+    return;
+  }
+
+  const auto has_privilege = [&instance](const char *privilege) {
+    return !instance.get_current_user_privileges()
+                ->validate({privilege})
+                .has_missing_privileges();
+  };
+
+  switch (m_bulk_load_info.fs) {
+    case Bulk_load_fs::UNSUPPORTED:
+      log_info("BULK LOAD: unsupported FS");
+      return;
+
+    case Bulk_load_fs::INFILE:
+      // NOTE: this is for testing purposes only, validation is superficial
+      {
+        const auto &co = m_base_session->get_connection_options();
+
+        if (mysqlshdk::db::Transport_type::Tcp == co.get_transport_type() &&
+            !mysqlshdk::utils::Net::is_local_address(co.get_host())) {
+          // in order to use INFILE we need to be connected to the local host
+          log_info("BULK LOAD: local FS and a remote host");
+          return;
+        }  // else we're connected via socket, pipe or to a local TCP address
+      }
+
+      if (const auto path = instance.get_sysvar_string("secure_file_priv");
+          path.has_value()) {
+        if (!path->empty()) {
+          // path is not empty, only files in that directory can be loaded
+          if (!shcore::str_beginswith(
+                  mysqlshdk::storage::make_directory(m_url, storage_config())
+                      ->full_path()
+                      .real(),
+                  mysqlshdk::storage::make_directory(*path, storage_config())
+                      ->full_path()
+                      .real())) {
+            log_info(
+                "BULK LOAD: local FS and dump is not a subdirectory of "
+                "'secure_file_priv'");
+            return;
+          }
+        }  // else path is empty, files can be loaded from anywhere
+      } else {
+        // variable is set to NULL, LOAD DATA INFILE is disabled
+        log_info("BULK LOAD: local FS and 'secure_file_priv' is NULL");
+        return;
+      }
+
+      break;
+
+    case Bulk_load_fs::URL:
+      if (!has_privilege("LOAD_FROM_URL")) {
+        log_info(
+            "BULK LOAD: OCI prefix PAR and 'LOAD_FROM_URL' privilege is "
+            "missing");
+        return;
+      }
+
+      break;
+
+    case Bulk_load_fs::S3:
+      if (!has_privilege("LOAD_FROM_S3")) {
+        log_info("BULK LOAD: AWS S3 and 'LOAD_FROM_S3' privilege is missing");
+        return;
+      }
+
+      break;
+  }
+
+  // BULK LOAD is supported
+  log_info("BULK LOAD is supported");
+  m_bulk_load_info.enabled = true;
+
+  // check if monitoring is enabled
+  auto result = instance.query(
+      "SELECT 1 FROM performance_schema.setup_consumers WHERE ENABLED='YES' "
+      "AND NAME='events_stages_current'");
+
+  if (!result->fetch_one()) {
+    log_info("BULK LOAD monitoring: consumer is disabled");
+    return;
+  }
+
+  result = instance.query(
+      "SELECT 1 FROM performance_schema.setup_instruments WHERE ENABLED='YES' "
+      "AND NAME='stage/bulk_load_sorted/loading'");
+
+  if (!result->fetch_one()) {
+    log_info("BULK LOAD monitoring: instrumentation is disabled");
+    return;
+  }
+
+  log_info("BULK LOAD monitoring is enabled");
+  m_bulk_load_info.monitoring = true;
+}
+
 }  // namespace mysqlsh
