@@ -37,6 +37,7 @@
 #include "mysqlshdk/libs/aws/s3_bucket_options.h"
 #include "mysqlshdk/libs/azure/blob_storage_options.h"
 #include "mysqlshdk/libs/db/connection_options.h"
+#include "mysqlshdk/libs/db/filtering_options.h"
 #include "mysqlshdk/libs/oci/oci_bucket_options.h"
 #include "mysqlshdk/libs/storage/config.h"
 #include "mysqlshdk/libs/storage/idirectory.h"
@@ -47,7 +48,6 @@
 #include "mysqlshdk/libs/utils/version.h"
 
 #include "modules/mod_utils.h"
-#include "modules/util/common/dump/filtering_options.h"
 #include "modules/util/import_table/helpers.h"
 
 namespace mysqlsh {
@@ -84,6 +84,7 @@ inline std::string schema_table_object_key(std::string_view schema,
 
 class Load_dump_options {
  public:
+  using Filtering_options = mysqlshdk::db::Filtering_options;
   using Connection_options = mysqlshdk::db::Connection_options;
 
   enum class Analyze_table_mode { OFF, HISTOGRAM, ON };
@@ -94,6 +95,16 @@ class Load_dump_options {
 
   enum class Handle_grant_errors { ABORT, DROP_ACCOUNT, IGNORE };
 
+  enum class Bulk_load_fs { UNSUPPORTED, INFILE, URL, S3 };
+
+  struct Bulk_load_info {
+    bool enabled = false;
+    bool monitoring = false;
+    uint64_t threads = 0;
+    Bulk_load_fs fs = Bulk_load_fs::UNSUPPORTED;
+    std::string file_prefix;
+  };
+
   Load_dump_options();
 
   explicit Load_dump_options(const std::string &url);
@@ -114,8 +125,7 @@ class Load_dump_options {
 
   void on_log_options(const char *msg) const;
 
-  void set_session(const std::shared_ptr<mysqlshdk::db::ISession> &session,
-                   const std::string &current_schema);
+  void set_session(const std::shared_ptr<mysqlshdk::db::ISession> &session);
 
   std::shared_ptr<mysqlshdk::db::ISession> base_session() const {
     return m_base_session;
@@ -123,7 +133,8 @@ class Load_dump_options {
 
   const Connection_options &connection_options() const { return m_target; }
 
-  std::string target_import_info() const;
+  std::string target_import_info(const char *operation = "Loading",
+                                 const std::string &extra = {}) const;
 
   std::unique_ptr<mysqlshdk::storage::IDirectory> create_dump_handle() const;
 
@@ -134,6 +145,8 @@ class Load_dump_options {
     return m_progress_file;
   }
 
+  void set_progress_file(const std::string &file);
+
   const std::string &default_progress_file() const {
     return m_default_progress_file;
   }
@@ -142,24 +155,45 @@ class Load_dump_options {
     return m_storage_config;
   }
 
+  void set_storage_config(
+      std::shared_ptr<mysqlshdk::storage::Config> storage_config);
+
   bool show_progress() const { return m_show_progress; }
 
+  void set_show_progress(bool show) { m_show_progress = show; }
+
   uint64_t threads_count() const { return m_threads_count; }
 
   uint64_t background_threads_count(uint64_t def) const {
     return m_background_threads_count.value_or(def);
   }
 
+  void set_background_threads_count(uint64_t count) {
+    m_background_threads_count = count;
+  }
+
   uint64_t threads_per_add_index() const { return m_threads_per_add_index; }
 
   uint64_t dump_wait_timeout_ms() const { return m_wait_dump_timeout_ms; }
 
+  void set_dump_wait_timeout_ms(uint64_t timeout_ms) {
+    m_wait_dump_timeout_ms = timeout_ms;
+  }
+
   const std::string &character_set() const { return m_character_set; }
 
   bool load_data() const { return m_load_data; }
+
+  void set_load_data(bool load) { m_load_data = load; }
+
   bool load_ddl() const { return m_load_ddl; }
+
+  void set_load_ddl(bool load) { m_load_ddl = load; }
+
   bool load_users() const { return m_load_users; }
 
+  void set_load_users(bool load) { m_load_users = load; }
+
   bool dry_run() const { return m_dry_run; }
 
   bool reset_progress() const { return m_reset_progress; }
@@ -168,13 +202,9 @@ class Load_dump_options {
 
   bool force() const { return m_force; }
 
-  const dump::common::Filtering_options &filters() const {
-    return m_filtering_options;
-  }
+  const Filtering_options &filters() const { return m_filtering_options; }
 
-  inline dump::common::Filtering_options &filters() {
-    return m_filtering_options;
-  }
+  inline Filtering_options &filters() { return m_filtering_options; }
 
   bool ignore_existing_objects() const { return m_ignore_existing_objects; }
 
@@ -192,8 +222,6 @@ class Load_dump_options {
 
   const std::string &target_schema() const { return m_target_schema; }
 
-  const std::string &current_schema() const { return m_current_schema; }
-
   const mysqlshdk::utils::Version &target_server_version() const {
     return m_target_server_version;
   }
@@ -204,6 +232,8 @@ class Load_dump_options {
 
   bool show_metadata() const { return m_show_metadata; }
 
+  void set_show_metadata(bool show) { m_show_metadata = show; }
+
   bool should_create_pks(bool default_value) const {
     return m_create_invisible_pks.value_or(default_value);
   }
@@ -228,13 +258,21 @@ class Load_dump_options {
 
   bool partial_revokes() const { return m_partial_revokes; }
 
+  bool fast_sub_chunking() const { return m_use_fast_sub_chunking; }
+
+  void enable_fast_sub_chunking() { m_use_fast_sub_chunking = true; }
+
+  inline bool checksum() const noexcept { return m_checksum; }
+
+  inline const Bulk_load_info &bulk_load_info() const noexcept {
+    return m_bulk_load_info;
+  }
+
  private:
   void set_wait_timeout(const double &timeout_seconds);
 
   void set_max_bytes_per_transaction(const std::string &value);
 
-  void set_progress_file(const std::string &file);
-
   void set_handle_grant_errors(const std::string &action);
 
   inline std::shared_ptr<mysqlshdk::db::IResult> query(
@@ -246,9 +284,7 @@ class Load_dump_options {
                       const std::unordered_set<std::string> &included,
                       const std::unordered_set<std::string> &excluded) const;
 
-  bool include_object_ci(std::string_view schema, std::string_view object,
-                         const std::unordered_set<std::string> &included,
-                         const std::unordered_set<std::string> &excluded) const;
+  void configure_bulk_load();
 
   std::string m_url;
   uint64_t m_threads_count = 4;
@@ -263,7 +299,7 @@ class Load_dump_options {
   Connection_options m_target;
   std::shared_ptr<mysqlshdk::db::ISession> m_base_session;
 
-  dump::common::Filtering_options m_filtering_options;
+  Filtering_options m_filtering_options;
 
   uint64_t m_wait_dump_timeout_ms = 0;
   bool m_reset_progress = false;
@@ -283,7 +319,7 @@ class Load_dump_options {
   bool m_load_indexes = true;
   Update_gtid_set m_update_gtid_set = Update_gtid_set::OFF;
   std::string m_target_schema;
-  std::string m_current_schema;
+  bool m_disable_bulk_load = false;
 
   mysqlshdk::utils::Version m_target_server_version;
   bool m_is_mds = false;
@@ -302,8 +338,14 @@ class Load_dump_options {
   // how many threads are used by the server per one ALTER TABLE ... ADD INDEX
   uint64_t m_threads_per_add_index = 1;
 
+  bool m_checksum = false;
+
   // whether partial revokes are enabled
   bool m_partial_revokes = false;
+
+  bool m_use_fast_sub_chunking = false;
+
+  Bulk_load_info m_bulk_load_info;
 };
 
 }  // namespace mysqlsh
