@@ -33,8 +33,12 @@
 #include <map>
 #include <memory>
 #include <mutex>
+#include <optional>
 #include <string>
+#include <string_view>
 #include <tuple>
+#include <unordered_map>
+#include <unordered_set>
 #include <utility>
 #include <vector>
 
@@ -68,7 +72,7 @@ struct Parameter_context {
 
   struct Context_definition {
     std::string name;
-    mysqlshdk::utils::nullable<int> position;
+    std::optional<int> position;
   };
 
   std::vector<Context_definition> levels;
@@ -187,6 +191,15 @@ struct Parameter final {
 
   bool is_deprecated;
 
+  bool operator==(const Parameter &r) const {
+    return name == r.name && m_type == r.m_type && flag == r.flag &&
+           short_name == r.short_name &&
+           cmd_line_enabled == r.cmd_line_enabled &&
+           is_deprecated == r.is_deprecated;
+  }
+
+  bool operator!=(const Parameter &r) const { return !operator==(r); }
+
   void validate(const Value &data, Parameter_context *context) const;
 
   bool valid_type(Value_type type) const;
@@ -307,13 +320,10 @@ class Option_pack_def : public IOption_pack_def {
         [name, callback, extract_mode](const Option_pack_def<C> *self,
                                        shcore::Option_unpacker *unpacker,
                                        C *instance) {
-          mysqlshdk::utils::nullable<T> value;
-
+          std::optional<T> value;
           self->get_optional(unpacker, extract_mode, name, &value);
 
-          if (!value.is_null()) {
-            callback(instance, *value);
-          }
+          if (value.has_value()) callback(instance, *value);
         });
     return *this;
   }
@@ -365,11 +375,10 @@ class Option_pack_def : public IOption_pack_def {
                                            shcore::Option_unpacker *unpacker,
                                            C *instance) {
           // this is where the magic happens
-          mysqlshdk::null_string value;
-
+          std::optional<std::string> value;
           self->get_optional(unpacker, extract_mode, name, &value);
 
-          if (!value.is_null()) {
+          if (value.has_value()) {
             (*instance).*var = get_enum_value(name, *value, mapping);
           }
         });
@@ -386,7 +395,7 @@ class Option_pack_def : public IOption_pack_def {
    * @param sname: short name for the option (if applicable).
    * @param cmd_line: whether the option is valid for CLI integration
    *
-   * The callback must be a member function with the following sugnature:
+   * The callback must be a member function with the following signature:
    *
    * callback(const string &name, const T &value)
    *
@@ -406,13 +415,10 @@ class Option_pack_def : public IOption_pack_def {
         [name, callback, extract_mode](const Option_pack_def<C> *self,
                                        shcore::Option_unpacker *unpacker,
                                        C *instance) {
-          mysqlshdk::utils::nullable<T> value;
-
+          std::optional<T> value;
           self->get_optional(unpacker, extract_mode, name, &value);
 
-          if (!value.is_null()) {
-            ((*instance).*callback)(name, *value);
-          }
+          if (value.has_value()) ((*instance).*callback)(name, *value);
         });
 
     return *this;
@@ -431,14 +437,11 @@ class Option_pack_def : public IOption_pack_def {
         [name, callback, extract_mode](const Option_pack_def<C> *self,
                                        shcore::Option_unpacker *unpacker,
                                        C *instance) {
-          mysqlshdk::utils::nullable<T> value;
-
+          std::optional<T> value;
           self->get_optional(unpacker, extract_mode, name, &value);
 
           unpacker->optional(name.c_str(), &value);
-          if (!value.is_null()) {
-            ((*instance).*callback)(name, *value);
-          }
+          if (value.has_value()) ((*instance).*callback)(name, *value);
         });
 
     return *this;
@@ -473,13 +476,10 @@ class Option_pack_def : public IOption_pack_def {
         [name, callback, extract_mode](const Option_pack_def<C> *self,
                                        shcore::Option_unpacker *unpacker,
                                        C *instance) {
-          mysqlshdk::utils::nullable<T> value;
-
+          std::optional<T> value;
           self->get_optional(unpacker, extract_mode, name, &value);
 
-          if (!value.is_null()) {
-            ((*instance).*callback)(*value);
-          }
+          if (value.has_value()) ((*instance).*callback)(*value);
         });
 
     return *this;
@@ -497,13 +497,10 @@ class Option_pack_def : public IOption_pack_def {
         [name, callback, extract_mode](const Option_pack_def<C> *self,
                                        shcore::Option_unpacker *unpacker,
                                        C *instance) {
-          mysqlshdk::utils::nullable<T> value;
-
+          std::optional<T> value;
           self->get_optional(unpacker, extract_mode, name, &value);
 
-          if (!value.is_null()) {
-            ((*instance).*callback)(*value);
-          }
+          if (value.has_value()) ((*instance).*callback)(*value);
         });
 
     return *this;
@@ -541,10 +538,10 @@ class Option_pack_def : public IOption_pack_def {
         [name, var, mapping](const Option_pack_def<C> *,
                              shcore::Option_unpacker *unpacker, C *instance) {
           // this is where the magic happens
-          mysqlshdk::null_string value;
+          std::optional<std::string> value;
           unpacker->required(name.c_str(), &value);
 
-          if (!value.is_null()) {
+          if (value.has_value()) {
             (*instance).*var = get_enum_value(name, *value, mapping);
           }
         });
@@ -565,11 +562,10 @@ class Option_pack_def : public IOption_pack_def {
     m_unpack_callbacks.emplace_back(
         [name, callback](const Option_pack_def<C> *,
                          shcore::Option_unpacker *unpacker, C *instance) {
-          mysqlshdk::utils::nullable<T> value;
+          std::optional<T> value;
           unpacker->required(name.c_str(), &value);
-          if (!value.is_null()) {
-            ((*instance).*callback)(name, *value);
-          }
+
+          if (value.has_value()) ((*instance).*callback)(name, *value);
         });
 
     return *this;
@@ -588,11 +584,10 @@ class Option_pack_def : public IOption_pack_def {
     m_unpack_callbacks.emplace_back(
         [name, callback](const Option_pack_def<C> *,
                          shcore::Option_unpacker *unpacker, C *instance) {
-          mysqlshdk::utils::nullable<T> value;
+          std::optional<T> value;
           unpacker->required(name.c_str(), &value);
-          if (!value.is_null()) {
-            ((*instance).*callback)(*value);
-          }
+
+          if (value.has_value()) ((*instance).*callback)(*value);
         });
 
     return *this;
@@ -614,6 +609,8 @@ class Option_pack_def : public IOption_pack_def {
       T::options().unpack(unpacker, &((*instance).*var));
     });
 
+    ignore(T::options().ignored());
+
     return *this;
   }
 
@@ -648,9 +645,52 @@ class Option_pack_def : public IOption_pack_def {
         [](const Option_pack_def<C> *, shcore::Option_unpacker *unpacker,
            C *instance) { T::options().unpack(unpacker, instance); });
 
+    ignore(T::options().ignored());
+
     return *this;
   }
 
+  /**
+   * Ignores given options. Options in this list are treated as unknown.
+   *
+   * @params options Options to be ignored
+   */
+  Option_pack_def<C> &ignore(
+      const std::unordered_set<std::string_view> &ignored_options) {
+    if (!ignored_options.empty()) {
+      m_ignored.insert(ignored_options.begin(), ignored_options.end());
+
+      m_option_md.erase(std::remove_if(m_option_md.begin(), m_option_md.end(),
+                                       [this](const auto &param) {
+                                         return is_ignored(param->name);
+                                       }),
+                        m_option_md.end());
+    }
+
+    return *this;
+  }
+
+  /**
+   * Ignores all options from the given option pack type.
+   */
+  template <typename T>
+  Option_pack_def<C> &ignore() {
+    const auto &options = T::options().options();
+    std::unordered_set<std::string_view> ignored;
+
+    for (const auto &o : options) {
+      ignored.emplace(o->name);
+    }
+
+    ignore(ignored);
+
+    return *this;
+  }
+
+  const std::unordered_set<std::string_view> &ignored() const {
+    return m_ignored;
+  }
+
   /**
    * Allows defining a callback for when the unpacking starts.
    *
@@ -696,6 +736,7 @@ class Option_pack_def : public IOption_pack_def {
 
     Option_unpacker unpacker;
     unpacker.set_options(options);
+    unpacker.set_ignored(m_ignored);
 
     unpack(&unpacker, instance);
 
@@ -720,8 +761,9 @@ class Option_pack_def : public IOption_pack_def {
  private:
   template <typename T>
   void add_options() {
-    auto options = T::options().options();
-    m_option_md.insert(m_option_md.end(), options.begin(), options.end());
+    for (const auto &o : T::options().options()) {
+      add_option(o);
+    }
   }
 
   template <typename T>
@@ -743,15 +785,36 @@ class Option_pack_def : public IOption_pack_def {
   template <typename T>
   void add_option(const std::string &name, const std::string &sname,
                   Option_scope scope, shcore::Param_flag flag) {
-    m_option_md.push_back(std::make_shared<shcore::Parameter>(
-        name, shcore::Type_info<T>::vtype(), flag, sname,
-        scope != Option_scope::CLI_DISABLED,
-        scope == Option_scope::DEPRECATED));
+    if (is_ignored(name)) {
+      return;
+    }
 
-    auto validator = Type_info<T>::validator();
-    if (validator) {
+    const auto option = std::make_shared<shcore::Parameter>(
+        name, shcore::Type_info<T>::vtype(), flag, sname,
+        scope != Option_scope::CLI_DISABLED, scope == Option_scope::DEPRECATED);
+    if (auto validator = Type_info<T>::validator()) {
       validator->set_enabled(false);
-      m_option_md.back()->set_validator(std::move(validator));
+      option->set_validator(std::move(validator));
+    }
+
+    add_option(option);
+  }
+
+  void add_option(const std::shared_ptr<shcore::Parameter> &option) {
+    if (is_ignored(option->name)) {
+      return;
+    }
+
+    if (const auto o = m_all_options.find(option->name);
+        o != m_all_options.end()) {
+      if (*option != *m_option_md[o->second]) {
+        throw std::logic_error(
+            "Trying to overwrite an option which already exists: " +
+            option->name);
+      }
+    } else {
+      m_all_options.emplace(option->name, m_option_md.size());
+      m_option_md.emplace_back(option);
     }
   }
 
@@ -799,6 +862,10 @@ class Option_pack_def : public IOption_pack_def {
     }
   }
 
+  bool is_ignored(std::string_view option) const {
+    return m_ignored.count(option) > 0;
+  }
+
   std::vector<std::function<void(const Option_pack_def<C> *,
                                  shcore::Option_unpacker *, C *)>>
       m_unpack_callbacks;
@@ -806,6 +873,8 @@ class Option_pack_def : public IOption_pack_def {
   std::function<void(C *, const shcore::Dictionary_t &)> m_start_callback;
   std::function<void(C *)> m_done_callback;
   std::function<void(C *, const char *)> m_log_callback;
+  std::unordered_set<std::string_view> m_ignored;
+  std::unordered_map<std::string_view, std::size_t> m_all_options;
 };
 
 /**
@@ -860,13 +929,14 @@ class SHCORE_PUBLIC Cpp_function : public Function_base {
   struct Metadata {
     Metadata() = default;
     Metadata(const Metadata &) = delete;
+
     std::string name[2];
     Raw_signature signature;
-    mysqlshdk::null_bool cli_enabled;
+    std::optional<bool> cli_enabled;
 
     std::vector<std::pair<std::string, Value_type>> param_types;
     std::string param_codes;
-    Value_type return_type;
+    Value_type return_type{shcore::Undefined};
 
     void set_name(const std::string &name);
     void set(const std::string &name, Value_type rtype,
@@ -930,6 +1000,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
   bool is_indexed() const override;
   Value get_member(size_t index) const override;
   void set_member(size_t index, Value value) override;
+  size_t length() const override;
 
   bool has_method(const std::string &name) const override;
 
@@ -1493,18 +1564,17 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
 
   // Helper function that retrieves a qualified function name using the active
   // naming style Used mostly for errors in function validations
-  std::string get_function_name(const std::string &member,
+  std::string get_function_name(std::string_view member,
                                 bool fully_specified = true) const;
 
   std::vector<Cpp_property_name> _properties;
 
   // Returns named function which signature that matches the given argument list
   std::shared_ptr<Cpp_function> lookup_function_overload(
-      const std::string &method, const shcore::Argument_list &args,
+      std::string_view method, const shcore::Argument_list &args,
       const shcore::Dictionary_t &kwds = {}) const;
 
-  std::shared_ptr<Cpp_function> lookup_function(
-      const std::string &method) const;
+  std::shared_ptr<Cpp_function> lookup_function(std::string_view method) const;
 
  private:
   template <typename T>
@@ -1542,7 +1612,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
   template <typename R, typename C, typename... A>
   Cpp_function::Metadata *expose_(const std::string &name, R (C::*func)(A...),
                                   const std::vector<std::string> &docs,
-                                  Type_info_t<A> &&... defs) {
+                                  Type_info_t<A> &&...defs) {
     return expose__<R, std::function<R(A...)>, A...>(
         name,
         [this, func](A... args) -> R {
@@ -1555,7 +1625,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
   Cpp_function::Metadata *expose_(const std::string &name,
                                   R (C::*func)(A...) const,
                                   const std::vector<std::string> &docs,
-                                  Type_info_t<A> &&... defs) {
+                                  Type_info_t<A> &&...defs) {
     return expose__<R, std::function<R(A...)>, A...>(
         name,
         [this, func](A... args) -> R {
@@ -1567,7 +1637,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
   template <typename R, typename... A>
   Cpp_function::Metadata *expose_(const std::string &name, R (*func)(A...),
                                   const std::vector<std::string> &docs,
-                                  Type_info_t<A> &&... defs) {
+                                  Type_info_t<A> &&...defs) {
     return expose__<R, std::function<R(A...)>, A...>(name, func, docs,
                                                      std::move(defs)...);
   }
@@ -1576,7 +1646,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
   Cpp_function::Metadata *expose_(const std::string &name,
                                   std::function<R(A...)> &&func,
                                   const std::vector<std::string> &docs,
-                                  Type_info_t<A> &&... defs) {
+                                  Type_info_t<A> &&...defs) {
     return expose__<R, std::function<R(A...)>, A...>(name, std::move(func),
                                                      docs, std::move(defs)...);
   }
@@ -1605,7 +1675,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
   template <typename R, typename F, typename... A>
   Cpp_function::Metadata *expose__(const std::string &name, F &&func,
                                    const std::vector<std::string> &docs,
-                                   Type_info_t<A> &&... defs) {
+                                   Type_info_t<A> &&...defs) {
     assert(func != nullptr);
     assert(!name.empty());
     assert(docs.size() == sizeof...(A));
@@ -1679,7 +1749,7 @@ class SHCORE_PUBLIC Cpp_object_bridge : public Object_bridge {
                 const std::tuple<Type_info_t<A>...> &defs,
                 std::index_sequence<I...>) {
     const auto size = args.size();
-    return func((size <= I || args.at(I).type == Value_type::Undefined
+    return func((size <= I || args.at(I).get_type() == Value_type::Undefined
                      ? std::get<I>(defs)
                      : Arg_handler<A>::get(I, args))...);
   }
