@@ -35,9 +35,7 @@
 #include <vector>
 
 #include "mysqlshdk/include/mysqlshdk_export.h"
-#include "mysqlshdk/include/shellcore/ishell_core.h"
 #include "mysqlshdk/libs/db/ssl_options.h"
-#include "mysqlshdk/libs/db/uri_common.h"
 #include "mysqlshdk/libs/ssh/ssh_connection_options.h"
 #include "mysqlshdk/libs/utils/connection.h"
 #include "mysqlshdk/libs/utils/nullable_options.h"
@@ -48,22 +46,33 @@ enum class SessionType { Auto, X, Classic };
 
 namespace mysqlshdk {
 namespace db {
-using utils::Nullable_options;
-using utils::nullable_options::Comparison_mode;
-enum Transport_type { Tcp, Socket, Pipe };
+
+enum class Transport_type { Tcp, Socket, Pipe };
+
+inline constexpr Transport_type k_default_local_transport_type =
+#ifdef _WIN32
+    mysqlshdk::db::Transport_type::Pipe
+#else
+    mysqlshdk::db::Transport_type::Socket
+#endif
+    ;
+
 std::string to_string(Transport_type type);
 
-using Mfa_passwords = std::array<std::optional<std::string>, 3>;
-
-constexpr int k_default_mysql_port = 3306;
-constexpr int k_default_mysql_x_port = 33060;
+inline constexpr int k_default_mysql_port = 3306;
+inline constexpr int k_default_mysql_x_port = 33060;
 
+inline constexpr int k_max_auth_factors = 3;
 class SHCORE_PUBLIC Connection_options : public IConnection {
  public:
   explicit Connection_options(
-      Comparison_mode mode = Comparison_mode::CASE_INSENSITIVE);
-  Connection_options(const std::string &uri,
-                     Comparison_mode mode = Comparison_mode::CASE_INSENSITIVE);
+      utils::nullable_options::Comparison_mode mode =
+          utils::nullable_options::Comparison_mode::CASE_INSENSITIVE);
+  explicit Connection_options(
+      const std::string &uri,
+      utils::nullable_options::Comparison_mode mode =
+          utils::nullable_options::Comparison_mode::CASE_INSENSITIVE);
+
   Connection_options(const Connection_options &other) = default;
   Connection_options(Connection_options &&other) = default;
 
@@ -84,6 +93,8 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
   int get_target_port() const;
 
   const std::string &get_password() const override;
+  // password1/factor 0 is an alias for regular password
+  const std::string &get_mfa_password(int factor) const;
 
   void set_transport_type(Transport_type type);
   Transport_type get_transport_type() const;
@@ -94,7 +105,6 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
     return m_extra_options.get_value(kCompressionAlgorithms);
   }
   int64_t get_compression_level() const;
-  const Mfa_passwords &get_mfa_passwords() const;
 
   const Ssl_options &get_ssl_options() const { return m_ssl_options; }
   Ssl_options &get_ssl_options() { return m_ssl_options; }
@@ -106,11 +116,28 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
   ssh::Ssh_connection_options &get_ssh_options_handle(int fallback_port = 0);
 
   const std::vector<std::string> &get_warnings() const { return m_warnings; }
-  bool has_password() const override {
-    return has_value(kPassword) || m_mfa_passwords[0].has_value();
-  }
+  bool has_password() const override { return has_value(kPassword); }
+  bool has_mfa_password(int factor) const;
+  bool has_needs_password(int factor) const;
 
-  bool has_mfa_passwords() const;
+  bool needs_password(int factor) const;
+
+  /**
+   * This function returns a boolean indicating if the password should be
+   * prompted.
+   *
+   * By default the function will return true if the password is missing for
+   * factor 0. If mandatory is true or the factor is not 0, the function will
+   * only return true if the password is missing and one of the password options
+   * was used:
+   *
+   * -p
+   * -password
+   * -password1
+   * -password2
+   * -password3
+   */
+  bool should_prompt_password(int factor) const;
 
   bool has_data() const override;
   bool has_schema() const { return has_value(kSchema); }
@@ -147,7 +174,7 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
   }
   void set_password(const std::string &password) override;
   void set_mfa_password(int factor, const std::string &password);
-  void set_mfa_passwords(const Mfa_passwords &mfa_passwords);
+  void set_needs_password(int factor, bool flag);
 
   void set(const std::string &attribute, const std::string &value) override;
   void set(const std::string &attribute, int value) override;
@@ -159,11 +186,13 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
   void clear_host() override;
   void clear_port() override;
   void clear_password() override;
-  void clear_mfa_passwords();
+  void clear_mfa_password(int factor);
+  void clear_needs_password(int factor);
   void clear_schema() { clear_value(kSchema); }
   void clear_socket();
   void clear_pipe();
   void clear_compression_level() { m_compress_level.reset(); }
+  void clear_transport_type();
 
   void clear_warnings() { m_warnings.clear(); }
 
@@ -176,11 +205,13 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
     return as_uri(uri::formats::only_transport());
   }
 
-  const Nullable_options &get_extra_options() const { return m_extra_options; }
+  const utils::Nullable_options &get_extra_options() const {
+    return m_extra_options;
+  }
   bool is_connection_attributes_enabled() const {
     return m_enable_connection_attributes;
   }
-  const Nullable_options &get_connection_attributes() const {
+  const utils::Nullable_options &get_connection_attributes() const {
     return m_connection_attributes;
   }
 
@@ -203,27 +234,71 @@ class SHCORE_PUBLIC Connection_options : public IConnection {
     return m_options.compare(lhs, rhs);
   }
 
-  static void throw_invalid_connect_timeout(const std::string &value);
+  static void throw_invalid_timeout(const char *name, const std::string &value);
 
   bool is_auth_method(const std::string &method_id) const;
 
+  bool has_oci_config_file() const;
+  void set_oci_config_file(const std::string &path);
+  std::string get_oci_config_file() const;
+
+  bool has_oci_client_config_profile() const;
+  void set_oci_client_config_profile(const std::string &profile);
+  std::string get_oci_client_config_profile() const;
+
+#ifdef _WIN32
+  bool has_kerberos_auth_mode() const;
+  void set_kerberos_auth_mode(const std::string &mode);
+  std::string get_kerberos_auth_mode() const;
+#endif
+
+  bool has_connect_timeout() const;
+  void set_connect_timeout(int value);
+  int get_connect_timeout() const;
+  void clear_connect_timeout();
+
+  bool has_net_read_timeout() const;
+  void set_net_read_timeout(int value);
+  int get_net_read_timeout() const;
+  void clear_net_read_timeout();
+
+  bool has_net_write_timeout() const;
+  void set_net_write_timeout(int value);
+  int get_net_write_timeout() const;
+  void clear_net_write_timeout();
+
+  bool is_enabled(const std::string &option) const;
+  void set_interactive(bool value);
+  bool is_interactive() const;
+
  private:
   void _set_fixed(const std::string &key, const std::string &val);
-  std::string get_iname(const std::string &name) const;
   bool is_extra_option(const std::string &option);
   bool is_bool_value(const std::string &value);
+  bool uses_local_transport() const;
 
   void check_compression_conflicts();
 
+  std::optional<Transport_type> m_default_transport_type;
   std::optional<Transport_type> m_transport_type;
   std::optional<int64_t> m_compress_level;
+  std::optional<int> m_connect_timeout;
+  std::optional<int> m_net_read_timeout;
+  std::optional<int> m_net_write_timeout;
 
   Ssl_options m_ssl_options;
   ssh::Ssh_connection_options m_ssh_options;
-  Nullable_options m_extra_options;
+  utils::Nullable_options m_extra_options;
   bool m_enable_connection_attributes;
-  Nullable_options m_connection_attributes;
-  mutable Mfa_passwords m_mfa_passwords;
+  utils::Nullable_options m_connection_attributes;
+  // mfa_password1 is the regular password
+  std::optional<std::string> m_mfa_password_2;
+  std::optional<std::string> m_mfa_password_3;
+  bool m_interactive = false;
+
+  // whether a (mfa) password is needed even if not given
+  // regular password is assumed to be required for compatibility options
+  std::array<std::optional<bool>, k_max_auth_factors> m_needs_password;
 
   std::vector<std::string> m_warnings;
 };
