@@ -28,12 +28,14 @@
 
 #include <mysql.h>
 
+#include <string>
+
 namespace mysqlshdk {
 namespace db {
 namespace mysql {
 
 namespace fido {
-void register_print_callback(MYSQL *conn);
+void register_callbacks(MYSQL *conn, const std::string &plugin_name);
 void register_device(MYSQL *conn, const char *factor);
 }  // namespace fido
 
