@@ -34,11 +34,14 @@
 #include <deque>
 #include <list>
 #include <memory>
+#include <optional>
 #include <string>
 #include <vector>
 
 #include <mysql.h>
 
+#include "mysqlshdk/libs/utils/atomic_flag.h"
+
 namespace mysqlshdk {
 namespace db {
 namespace mysql {
@@ -68,6 +71,7 @@ class SHCORE_PUBLIC Result : public mysqlshdk::db::IResult,
   virtual std::string get_info() const { return _info; }
   virtual const std::vector<std::string> &get_gtids() const { return _gtids; }
   virtual const std::vector<Column> &get_metadata() const { return _metadata; }
+  virtual std::string get_statement_id() const;
 
   virtual void buffer();
   virtual void rewind();
@@ -83,7 +87,7 @@ class SHCORE_PUBLIC Result : public mysqlshdk::db::IResult,
   std::deque<mysqlshdk::db::Row_copy> _pre_fetched_rows;
   // size_t _fetched_row_count = 0;
   // size_t _fetched_warning_count = 0;
-  bool _stop_pre_fetch = false;
+  shcore::atomic_flag _stop_pre_fetch;
   bool _pre_fetched = false;
   bool _persistent_pre_fetch = false;
   bool _pre_fetched_clear_at_end = false;
@@ -93,6 +97,7 @@ class SHCORE_PUBLIC Result : public mysqlshdk::db::IResult,
   void stop_pre_fetch();
 
   void fetch_metadata();
+  void fetch_statement_id();
   Type map_data_type(int raw_type, int flags, int collation_id);
 
   virtual std::shared_ptr<Field_names> field_names() const;
@@ -111,6 +116,7 @@ class SHCORE_PUBLIC Result : public mysqlshdk::db::IResult,
   bool _has_resultset = false;
   bool _fetched_warnings = false;
   bool m_buffered = false;
+  std::optional<std::string> m_statement_id;
 };
 }  // namespace mysql
 }  // namespace db
