@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2015, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -1281,7 +1283,8 @@ std::string Expr_unparser::order_to_string(const Mysqlx::Crud::Order &c) {
 }
 
 std::string Expr_unparser::column_list_to_string(
-    google::protobuf::RepeatedPtrField<::Mysqlx::Crud::Projection> columns) {
+    const google::protobuf::RepeatedPtrField<::Mysqlx::Crud::Projection>
+        &columns) {
   std::string result("projection (");
   for (int i = 0; i < columns.size(); i++) {
     std::string strcol = Expr_unparser::column_to_string(columns.Get(i));
@@ -1293,7 +1296,7 @@ std::string Expr_unparser::column_list_to_string(
 }
 
 std::string Expr_unparser::order_list_to_string(
-    google::protobuf::RepeatedPtrField<::Mysqlx::Crud::Order> columns) {
+    const google::protobuf::RepeatedPtrField<::Mysqlx::Crud::Order> &columns) {
   std::string result("orderby (");
   for (int i = 0; i < columns.size(); i++) {
     std::string strcol = Expr_unparser::order_to_string(columns.Get(i));
