@@ -203,8 +203,10 @@ class SHCORE_PUBLIC Session : public ISession,
 
   void enable_protocol_trace(bool flag) { _impl->enable_trace(flag); }
 
-  std::shared_ptr<IResult> querys(const char *sql, size_t len,
-                                  bool buffered = false) override {
+  std::shared_ptr<IResult> querys(
+      const char *sql, size_t len, bool buffered = false,
+      [[maybe_unused]] const std::vector<Query_attribute> &query_attributes =
+          {}) override {
     return _impl->query(sql, len, buffered);
   }
 
