@@ -26,7 +26,6 @@
 #include <mysqlx_version.h>
 
 #include <memory>
-#include <sstream>
 #include <string>
 #include <utility>
 
@@ -56,6 +55,9 @@ FI_DEFINE(mysqlx, [](const mysqlshdk::utils::FI::Args &args) {
 });
 
 namespace {
+
+#ifdef USE_MYSQLX_FULL_PROTO
+
 template <typename Message_type>
 std::string message_to_text(const std::string &binary_message) {
   std::string result;
@@ -115,6 +117,16 @@ std::ostream &operator<<(std::ostream &os,
             << output << "}\n";
 }
 
+#else  // !USE_MYSQLX_FULL_PROTO
+
+std::ostream &operator<<(std::ostream &os,
+                         const xcl::XProtocol::Message &message) {
+  return os << message.GetTypeName() << " {\n  " << message.DebugString()
+            << "\n}\n";
+}
+
+#endif  // !USE_MYSQLX_FULL_PROTO
+
 std::pair<xcl::XProtocol::Handler_id, xcl::XProtocol::Handler_id>
 do_enable_trace(xcl::XSession *session) {
   xcl::XProtocol::Handler_id rh, sh;
@@ -155,6 +167,7 @@ void XSession_impl::connect(const mysqlshdk::db::Connection_options &data) {
   if (_enable_trace) _trace_handler = do_enable_trace(_mysql.get());
 
   _connection_options = data;
+  _connection_options.set_default_data();
 
   if (_connection_options.has(mysqlshdk::db::kGetServerPublicKey)) {
     _mysql.reset();
@@ -332,14 +345,14 @@ void XSession_impl::connect(const mysqlshdk::db::Connection_options &data) {
 
   // Sets the connection timeout
   int64_t connect_timeout = mysqlshdk::db::default_connect_timeout();
-  if (_connection_options.has(kConnectTimeout)) {
-    connect_timeout = std::stoi(_connection_options.get(kConnectTimeout));
+  if (_connection_options.has_connect_timeout()) {
+    connect_timeout = _connection_options.get_connect_timeout();
   }
   _mysql->set_mysql_option(xcl::XSession::Mysqlx_option::Connect_timeout,
                            connect_timeout);
   // Set read timeout
-  if (_connection_options.has(kNetReadTimeout)) {
-    int64_t read_timeout = std::stoi(_connection_options.get(kNetReadTimeout));
+  if (_connection_options.has_net_read_timeout()) {
+    int64_t read_timeout = _connection_options.get_net_read_timeout();
     _mysql->set_mysql_option(xcl::XSession::Mysqlx_option::Read_timeout,
                              read_timeout);
   }
@@ -399,7 +412,8 @@ void XSession_impl::connect(const mysqlshdk::db::Connection_options &data) {
   DBUG_LOG("sqlall", "CONNECT: " << data.uri_endpoint());
 
   if (!_connection_options.has_transport_type() ||
-      _connection_options.get_transport_type() != mysqlshdk::db::Tcp) {
+      _connection_options.get_transport_type() !=
+          mysqlshdk::db::Transport_type::Tcp) {
     err = _mysql->connect(
         data.has_socket()
             ? (data.get_socket().empty() ? MYSQLX_UNIX_ADDR
