@@ -278,7 +278,7 @@ double Mem_row::get_double(uint32_t index) const {
     case Type::Decimal:
       try {
         return std::stod(get<std::string>(index));
-      } catch (const std::exception &e) {
+      } catch (const std::exception &) {
         throw FIELD_ERROR(index, "double value out of the allowed range");
       }
     case Type::Float:
