@@ -25,8 +25,10 @@
 
 #include "mysqlshdk/libs/mysql/async_replication.h"
 
+#include <inttypes.h>
 #include <mysqld_error.h>
 #include <tuple>
+
 #include "mysqlshdk/libs/mysql/group_replication.h"
 #include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/logger.h"
@@ -35,71 +37,125 @@ namespace mysqlshdk {
 namespace mysql {
 
 namespace {
-std::string prepare_ssl_options(const mysqlshdk::db::Ssl_options &ssl_options,
-                                const std::string &source_term) {
+std::string prepare_options(const Replication_options &repl_options,
+                            const std::string &source_term) {
+  auto option_sql_format = [source_term](std::string_view name) {
+    return shcore::str_format(", %s%.*s=?", source_term.c_str(),
+                              static_cast<int>(name.size()), name.data());
+  };
+
   std::string options;
 
-  if (ssl_options.has_mode()) {
-    auto ssl_mode = ssl_options.get_mode();
+  if (repl_options.connect_retry.has_value())
+    options.append(shcore::sqlformat(option_sql_format("_CONNECT_RETRY"),
+                                     *repl_options.connect_retry));
 
-    if (ssl_mode != mysqlshdk::db::Ssl_mode::Disabled) {
-      options.append(", " + source_term + "_SSL=1");
+  if (repl_options.retry_count.has_value())
+    options.append(shcore::sqlformat(option_sql_format("_RETRY_COUNT"),
+                                     *repl_options.retry_count));
 
-      if (ssl_options.has_ca())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_CA=?",
-                                         ssl_options.get_ca()));
+  if (repl_options.auto_failover.has_value())
+    options.append(shcore::str_format(", SOURCE_CONNECTION_AUTO_FAILOVER=%d",
+                                      *repl_options.auto_failover ? 1 : 0));
 
-      if (ssl_options.has_capath())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_CAPATH=?",
-                                         ssl_options.get_capath()));
+  if (repl_options.delay.has_value())
+    options.append(
+        shcore::sqlformat(option_sql_format("_DELAY"), *repl_options.delay));
 
-      if (ssl_options.has_crl())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_CRL=?",
-                                         ssl_options.get_crl()));
+  if (repl_options.heartbeat_period.has_value())
+    options.append(shcore::sqlformat(option_sql_format("_HEARTBEAT_PERIOD"),
+                                     *repl_options.heartbeat_period));
 
-      if (ssl_options.has_crlpath())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_CRLPATH=?",
-                                         ssl_options.get_crlpath()));
+  if (repl_options.compression_algos.has_value())
+    options.append(
+        shcore::sqlformat(option_sql_format("_COMPRESSION_ALGORITHMS"),
+                          repl_options.compression_algos->c_str()));
 
-      if (ssl_options.has_cipher())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_CIPHER=?",
-                                         ssl_options.get_cipher()));
+  if (repl_options.zstd_compression_level.has_value())
+    options.append(
+        shcore::sqlformat(option_sql_format("_ZSTD_COMPRESSION_LEVEL"),
+                          *repl_options.zstd_compression_level));
 
-      if (ssl_options.has_cert())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_CERT=?",
-                                         ssl_options.get_cert()));
+  if (repl_options.bind.has_value())
+    options.append(
+        shcore::sqlformat(option_sql_format("_BIND"), *repl_options.bind));
 
-      if (ssl_options.has_key())
-        options.append(shcore::sqlformat(", " + source_term + "_SSL_KEY=?",
-                                         ssl_options.get_key()));
+  if (repl_options.network_namespace.has_value())
+    options.append(shcore::sqlformat(", NETWORK_NAMESPACE=?",
+                                     *repl_options.network_namespace));
 
-      if (ssl_options.has_tls_version())
-        options.append(shcore::sqlformat(", " + source_term + "_TLS_VERSION=?",
-                                         ssl_options.get_tls_version()));
+  if (repl_options.auto_position)
+    options.append(
+        shcore::str_format(", %s_AUTO_POSITION=1", source_term.c_str()));
 
-      if (ssl_options.has_tls_ciphersuites())
-        options.append(
-            shcore::sqlformat(", " + source_term + "_TLS_CIPHERSUITES=?",
-                              ssl_options.get_tls_ciphersuites()));
-
-      if (ssl_mode == mysqlshdk::db::Ssl_mode::VerifyIdentity)
-        options.append(", " + source_term + "_SSL_VERIFY_SERVER_CERT=1");
-    } else {
-      options.append(", " + source_term + "_SSL=0");
-    }
-  }
   return options;
 }
+
+std::string prepare_ssl_options(const mysqlshdk::db::Ssl_options &ssl_options,
+                                const std::string &source_term) {
+  if (!ssl_options.has_mode()) return {};
+
+  auto ssl_mode = ssl_options.get_mode();
+  if (ssl_mode == mysqlshdk::db::Ssl_mode::Disabled)
+    return shcore::str_format(", %s_SSL=0", source_term.c_str());
+
+  auto option_sql_format = [source_term](std::string_view name) {
+    return shcore::str_format(", %s%.*s=?", source_term.c_str(),
+                              static_cast<int>(name.size()), name.data());
+  };
+
+  auto options = shcore::str_format(", %s_SSL=1", source_term.c_str());
+
+  if (ssl_options.has_ca())
+    options.append(
+        shcore::sqlformat(option_sql_format("_SSL_CA"), ssl_options.get_ca()));
+
+  if (ssl_options.has_capath())
+    options.append(shcore::sqlformat(option_sql_format("_SSL_CAPATH"),
+                                     ssl_options.get_capath()));
+
+  if (ssl_options.has_crl())
+    options.append(shcore::sqlformat(option_sql_format("_SSL_CRL"),
+                                     ssl_options.get_crl()));
+
+  if (ssl_options.has_crlpath())
+    options.append(shcore::sqlformat(option_sql_format("_SSL_CRLPATH"),
+                                     ssl_options.get_crlpath()));
+
+  if (ssl_options.has_cipher())
+    options.append(shcore::sqlformat(option_sql_format("_SSL_CIPHER"),
+                                     ssl_options.get_cipher()));
+
+  if (ssl_options.has_cert())
+    options.append(shcore::sqlformat(option_sql_format("_SSL_CERT"),
+                                     ssl_options.get_cert()));
+
+  if (ssl_options.has_key())
+    options.append(shcore::sqlformat(option_sql_format("_SSL_KEY"),
+                                     ssl_options.get_key()));
+
+  if (ssl_options.has_tls_version())
+    options.append(shcore::sqlformat(option_sql_format("_TLS_VERSION"),
+                                     ssl_options.get_tls_version()));
+
+  if (ssl_options.has_tls_ciphersuites())
+    options.append(shcore::sqlformat(option_sql_format("_TLS_CIPHERSUITES"),
+                                     ssl_options.get_tls_ciphersuites()));
+
+  if (ssl_mode == mysqlshdk::db::Ssl_mode::VerifyIdentity)
+    options.append(shcore::str_format(", %s_SSL_VERIFY_SERVER_CERT=1",
+                                      source_term.c_str()));
+
+  return options;
+}
+
 }  // namespace
 
 void change_master(const mysqlshdk::mysql::IInstance &instance,
                    const std::string &master_host, int master_port,
                    const std::string &channel_name,
                    const Auth_options &credentials,
-                   std::optional<int> master_connect_retry,
-                   std::optional<int> master_retry_count,
-                   std::optional<bool> auto_failover,
-                   std::optional<int> master_delay, bool source_auto_position) {
+                   const Replication_options &repl_options) {
   assert(!master_host.empty());
   assert(credentials.ssl_options.has_mode() &&
          credentials.ssl_options.get_mode() !=
@@ -116,35 +172,26 @@ void change_master(const mysqlshdk::mysql::IInstance &instance,
         mysqlshdk::mysql::get_replication_source_keywords(
             instance.get_version());
 
-    std::string options;
+    auto options = prepare_options(repl_options, source_term);
+    if (auto ssl_options =
+            prepare_ssl_options(credentials.ssl_options, source_term);
+        !ssl_options.empty()) {
+      options.append(ssl_options);
+    }
 
-    if (master_retry_count.has_value())
-      options.append(shcore::str_format(
-          ", %s_RETRY_COUNT=%d", source_term.c_str(), *master_retry_count));
-
-    if (master_connect_retry.has_value())
-      options.append(shcore::str_format(
-          ", %s_CONNECT_RETRY=%d", source_term.c_str(), *master_connect_retry));
-
-    if (auto_failover.has_value())
-      options.append(shcore::str_format(", SOURCE_CONNECTION_AUTO_FAILOVER=%d",
-                                        *auto_failover ? 1 : 0));
-
-    if (master_delay.has_value())
-      options.append(shcore::str_format(", %s_DELAY=%d", source_term.c_str(),
-                                        *master_delay));
-
-    options.append(prepare_ssl_options(credentials.ssl_options, source_term));
-
-    auto ssl_mode = credentials.ssl_options.has_mode()
-                        ? credentials.ssl_options.get_mode()
-                        : mysqlshdk::db::Ssl_mode::Preferred;
-    if (ssl_mode == mysqlshdk::db::Ssl_mode::Disabled ||
-        ssl_mode == mysqlshdk::db::Ssl_mode::Preferred)
-      options.append("/*!80011 , get_master_public_key=1 */");
-
-    if (source_auto_position)
-      options.append(", " + source_term + "_AUTO_POSITION=1");
+    {
+      auto ssl_mode = credentials.ssl_options.has_mode()
+                          ? credentials.ssl_options.get_mode()
+                          : mysqlshdk::db::Ssl_mode::Preferred;
+      if (ssl_mode == mysqlshdk::db::Ssl_mode::Disabled ||
+          ssl_mode == mysqlshdk::db::Ssl_mode::Preferred) {
+        if (instance.get_version() < utils::Version(8, 4, 0)) {
+          options.append("/*!80011 , get_master_public_key=1 */");
+        } else {
+          options.append("/*!80011 , get_source_public_key=1 */");
+        }
+      }
+    }
 
     auto query = shcore::str_format(
         "CHANGE %s TO %s_HOST=/*(*/ ? /*)*/, %s_PORT=/*(*/ ? /*)*/, %s_USER=?, "
@@ -162,26 +209,60 @@ void change_master(const mysqlshdk::mysql::IInstance &instance,
 
 void change_master_host_port(const mysqlshdk::mysql::IInstance &instance,
                              const std::string &master_host, int master_port,
-                             const std::string &channel_name) {
+                             const std::string &channel_name,
+                             const Replication_options &repl_options) {
   log_info("Changing source address for channel '%s' of %s to %s:%i",
            channel_name.c_str(), instance.descr().c_str(), master_host.c_str(),
            master_port);
 
-  auto [source_term, source_term_cmd] =
-      mysqlshdk::mysql::get_replication_source_keywords(instance.get_version());
-
   try {
-    instance.executef("CHANGE " + source_term_cmd + " TO " + source_term +
-                          "_HOST=/*(*/ ? /*)*/, " + source_term +
-                          "_PORT=/*(*/ ? /*)*/ "
-                          "FOR CHANNEL ?",
-                      master_host, master_port, channel_name);
+    auto [source_term, source_term_cmd] =
+        mysqlshdk::mysql::get_replication_source_keywords(
+            instance.get_version());
+
+    auto options = prepare_options(repl_options, source_term);
+
+    auto query = shcore::str_format(
+        "CHANGE %s TO %s_HOST=/*(*/ ? /*)*/, %s_PORT=/*(*/ ? /*)*/%s FOR "
+        "CHANNEL ?",
+        source_term_cmd.c_str(), source_term.c_str(), source_term.c_str(),
+        options.c_str());
+
+    instance.executef(query, master_host, master_port, channel_name);
   } catch (const std::exception &e) {
     log_error("Error setting up async replication: %s", e.what());
     throw;
   }
 }
 
+void change_master_repl_options(const mysqlshdk::mysql::IInstance &instance,
+                                const std::string &channel_name,
+                                const Replication_options &repl_options) {
+  log_info("Changing replication options for channel '%s' of %s.",
+           channel_name.c_str(), instance.descr().c_str());
+
+  try {
+    auto [source_term, source_term_cmd] =
+        mysqlshdk::mysql::get_replication_source_keywords(
+            instance.get_version());
+
+    auto options = prepare_options(repl_options, source_term);
+    if (options.empty()) return;
+
+    assert(std::string_view{options}.substr(0, 2) == ", ");
+    options.erase(0, 2);  // removes ", " prefix
+
+    auto query = shcore::str_format("CHANGE %s TO %s FOR CHANNEL ?",
+                                    source_term_cmd.c_str(), options.c_str());
+
+    instance.executef(query, channel_name);
+
+  } catch (const std::exception &e) {
+    log_error("Error updating channel replication options: %s", e.what());
+    throw;
+  }
+}
+
 void reset_slave(const mysqlshdk::mysql::IInstance &instance,
                  const std::string &channel_name, bool reset_credentials) {
   log_debug("Resetting replica%s channel '%s' for %s...",
@@ -220,7 +301,7 @@ void stop_replication(const mysqlshdk::mysql::IInstance &instance,
 
 bool stop_replication_safe(const mysqlshdk::mysql::IInstance &instance,
                            const std::string &channel_name, int timeout_sec) {
-  log_debug("Stopping replica channel %s for %s...", channel_name.c_str(),
+  log_debug("Stopping replica channel '%s' for '%s'...", channel_name.c_str(),
             instance.descr().c_str());
   std::string replica_term =
       mysqlshdk::mysql::get_replica_keyword(instance.get_version());
@@ -236,7 +317,8 @@ bool stop_replication_safe(const mysqlshdk::mysql::IInstance &instance,
       if (n == "0") return true;
 
       log_warning(
-          "Slave_open_tables has unexpected value %s at %s (unsupported SBR in "
+          "Slave_open_tables has unexpected value '%s' at '%s' (unsupported "
+          "SBR in "
           "use?)",
           n.c_str(), instance.descr().c_str());
 
@@ -262,7 +344,7 @@ bool stop_replication_safe(const mysqlshdk::mysql::IInstance &instance,
 
 void start_replication_receiver(const mysqlshdk::mysql::IInstance &instance,
                                 const std::string &channel_name) {
-  log_debug("Starting replica io_thread %s for %s...", channel_name.c_str(),
+  log_debug("Starting replica io_thread '%s' for '%s'...", channel_name.c_str(),
             instance.descr().c_str());
   instance.executef(
       "START " + mysqlshdk::mysql::get_replica_keyword(instance.get_version()) +
@@ -272,7 +354,7 @@ void start_replication_receiver(const mysqlshdk::mysql::IInstance &instance,
 
 void stop_replication_receiver(const mysqlshdk::mysql::IInstance &instance,
                                const std::string &channel_name) {
-  log_debug("Stopping replica io_thread %s for %s...", channel_name.c_str(),
+  log_debug("Stopping replica io_thread '%s' for '%s'...", channel_name.c_str(),
             instance.descr().c_str());
   instance.executef(
       "STOP " + mysqlshdk::mysql::get_replica_keyword(instance.get_version()) +
@@ -282,8 +364,8 @@ void stop_replication_receiver(const mysqlshdk::mysql::IInstance &instance,
 
 void start_replication_applier(const mysqlshdk::mysql::IInstance &instance,
                                const std::string &channel_name) {
-  log_debug("Starting replica sql_thread %s for %s...", channel_name.c_str(),
-            instance.descr().c_str());
+  log_debug("Starting replica sql_thread '%s' for '%s'...",
+            channel_name.c_str(), instance.descr().c_str());
   instance.executef(
       "START " + mysqlshdk::mysql::get_replica_keyword(instance.get_version()) +
           " SQL_THREAD FOR CHANNEL ?",
@@ -292,8 +374,8 @@ void start_replication_applier(const mysqlshdk::mysql::IInstance &instance,
 
 void stop_replication_applier(const mysqlshdk::mysql::IInstance &instance,
                               const std::string &channel_name) {
-  log_debug("Stopping replica sql_thread %s for %s...", channel_name.c_str(),
-            instance.descr().c_str());
+  log_debug("Stopping replica sql_thread '%s' for '%s'...",
+            channel_name.c_str(), instance.descr().c_str());
   instance.executef(
       "STOP " + mysqlshdk::mysql::get_replica_keyword(instance.get_version()) +
           " SQL_THREAD FOR CHANNEL ?",
@@ -338,5 +420,50 @@ void change_replication_credentials(
   }
 }
 
+std::string to_string(Read_replica_status status) {
+  switch (status) {
+    case Read_replica_status::ONLINE:
+      return "ONLINE";
+    case Read_replica_status::CONNECTING:
+      return "CONNECTING";
+    case Read_replica_status::OFFLINE:
+      return "OFFLINE";
+    case Read_replica_status::ERROR:
+      return "ERROR";
+    case Read_replica_status::UNREACHABLE:
+      return "UNREACHABLE";
+  }
+  throw std::logic_error("internal error");
+}
+
+Read_replica_status get_read_replica_status(
+    const mysqlshdk::mysql::IInstance &read_replica_instance) {
+  if (mysqlshdk::mysql::Replication_channel channel;
+      mysqlshdk::mysql::get_channel_status(
+          read_replica_instance,
+          mysqlsh::dba::k_read_replica_async_channel_name, &channel)) {
+    switch (channel.status()) {
+      case mysqlshdk::mysql::Replication_channel::ON:
+        return Read_replica_status::ONLINE;
+        break;
+      case mysqlshdk::mysql::Replication_channel::CONNECTING:
+        return Read_replica_status::CONNECTING;
+        break;
+      case mysqlshdk::mysql::Replication_channel::OFF:
+      case mysqlshdk::mysql::Replication_channel::APPLIER_OFF:
+      case mysqlshdk::mysql::Replication_channel::RECEIVER_OFF:
+        return Read_replica_status::OFFLINE;
+        break;
+      case mysqlshdk::mysql::Replication_channel::CONNECTION_ERROR:
+      case mysqlshdk::mysql::Replication_channel::APPLIER_ERROR:
+        return Read_replica_status::ERROR;
+        break;
+    }
+  }
+
+  // The channel does not exist
+  return Read_replica_status::OFFLINE;
+}
+
 }  // namespace mysql
 }  // namespace mysqlshdk
