@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -37,17 +39,13 @@
 #include <mysqld_error.h>
 
 #include "mysqlshdk/libs/config/config.h"
-#include "mysqlshdk/libs/mysql/clone.h"
 #include "mysqlshdk/libs/mysql/plugin.h"
-#include "mysqlshdk/libs/mysql/replication.h"
 #include "mysqlshdk/libs/mysql/utils.h"
 #include "mysqlshdk/libs/utils/logger.h"
-#include "mysqlshdk/libs/utils/trandom.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_net.h"
 #include "mysqlshdk/libs/utils/utils_sqlstring.h"
 #include "mysqlshdk/libs/utils/utils_string.h"
-#include "mysqlshdk/libs/utils/uuid_gen.h"
 
 namespace mysqlshdk {
 namespace gr {
@@ -156,24 +154,32 @@ Topology_mode to_topology_mode(const std::string &mode) {
  */
 bool is_primary(const mysqlshdk::mysql::IInstance &instance) {
   try {
-    std::shared_ptr<db::IResult> resultset = instance.query(
-        "SELECT NOT @@group_replication_single_primary_mode OR "
-        "    (select variable_value"
-        "       from performance_schema.global_status"
-        "       where variable_name = 'group_replication_primary_member')"
-        "    = @@server_uuid");
-    auto row = resultset->fetch_one();
+    std::string query;
+    if (instance.get_version() >= utils::Version(8, 0, 2)) {
+      query =
+          "SELECT NOT @@group_replication_single_primary_mode OR "
+          "    (select member_id from "
+          "performance_schema.replication_group_members where (member_role = "
+          "'PRIMARY')) = @@server_uuid";
+    } else {
+      query =
+          "SELECT NOT @@group_replication_single_primary_mode OR "
+          "    (select variable_value"
+          "       from performance_schema.global_status"
+          "       where variable_name = 'group_replication_primary_member')"
+          "    = @@server_uuid";
+    }
+    auto res = instance.query(query);
+    auto row = res->fetch_one();
     return (row && row->get_int(0)) != 0;
   } catch (const mysqlshdk::db::Error &e) {
     log_warning("Error checking if member is primary: %s (%i)", e.what(),
                 e.code());
-    if (e.code() == ER_UNKNOWN_SYSTEM_VARIABLE) {
-      throw std::runtime_error(
-          std::string("Group replication not started (MySQL error ") +
-          std::to_string(e.code()) + ": " + e.what() + ")");
-    } else {
-      throw;
-    }
+    if (e.code() != ER_UNKNOWN_SYSTEM_VARIABLE) throw;
+
+    throw std::runtime_error(
+        shcore::str_format("Group replication not started (MySQL error %d: %s)",
+                           e.code(), e.what()));
   }
 }
 
@@ -232,24 +238,22 @@ bool has_quorum(const mysqlshdk::mysql::IInstance &instance,
  *         an additional state MISSING indicating that GR monitory information
  *         was not found for the instance (e.g., if GR is not enabled).
  *         For more information, see:
- *         https://dev.mysql.com/doc/refman/5.7/en/group-replication-server-states.html
+ *         https://dev.mysql.com/doc/refman/en/group-replication-server-states.html
  */
 Member_state get_member_state(const mysqlshdk::mysql::IInstance &instance) {
   // replication_group_members will have a single row with member_id = '' and
   // member_state = OFFLINE in 5.7 if the server is started and GR doesn't
   // auto-start.
-  static const char *member_state_stmt =
+  const char *member_state_stmt =
       "SELECT member_state "
       "FROM performance_schema.replication_group_members "
       "WHERE member_id = @@server_uuid OR"
       " (member_id = '' AND member_state = 'OFFLINE')";
   auto resultset = instance.query(member_state_stmt);
   auto row = resultset->fetch_one();
-  if (row) {
-    return to_member_state(row->get_string(0));
-  } else {
-    return Member_state::MISSING;
-  }
+
+  if (row) return to_member_state(row->get_string(0));
+  return Member_state::MISSING;
 }
 
 /**
@@ -357,9 +361,7 @@ std::vector<Member> get_members(const mysqlshdk::mysql::IInstance &instance,
   }
 
   if (out_single_primary_mode) {
-    // Single primary mode if group_replication_primary_member is not empty.
-    *out_single_primary_mode =
-        !mysqlshdk::gr::get_group_primary_uuid(instance, nullptr).empty();
+    mysqlshdk::gr::get_group_primary_uuid(instance, out_single_primary_mode);
   }
 
   assert(
@@ -396,7 +398,7 @@ bool get_group_information(const mysqlshdk::mysql::IInstance &instance,
                            bool *out_single_primary_mode, bool *out_has_quorum,
                            bool *out_is_primary) {
   try {
-    std::shared_ptr<db::IResult> result(instance.query(
+    std::string query =
         "SELECT @@group_replication_group_name group_name, "
         "NULLIF(CONCAT(''/*!80026, @@group_replication_view_change_uuid*/), "
         "'') group_view_change_uuid, "
@@ -415,93 +417,109 @@ bool get_group_information(const mysqlshdk::mysql::IInstance &instance,
         "       where variable_name = 'group_replication_primary_member')"
         " ) is_primary"
         " FROM performance_schema.replication_group_members"
-        " WHERE member_id = @@server_uuid"));
+        " WHERE member_id = @@server_uuid";
+
+    auto result = instance.query(query);
     const db::IRow *row = result->fetch_one();
-    if (row && !row->is_null(0)) {
-      if (out_group_name) *out_group_name = row->get_string(0);
-      if (!row->is_null(1) && out_group_view_change_uuid)
-        *out_group_view_change_uuid = row->get_string(1);
-      if (!row->is_null(2) && out_single_primary_mode)
-        *out_single_primary_mode = (row->get_int(2) != 0);
-      if (out_member_id) *out_member_id = row->get_string(3);
-      if (out_member_state)
-        *out_member_state = to_member_state(row->get_string(4));
-      if (out_has_quorum)
-        *out_has_quorum = row->is_null(5) ? false : row->get_int(5) != 0;
-      if (out_is_primary) *out_is_primary = row->get_int(6, 0);
-      return true;
-    }
-    return false;
+    if (!row || row->is_null(0)) return false;
+
+    if (out_group_name) *out_group_name = row->get_string(0);
+    if (out_group_view_change_uuid && !row->is_null(1))
+      *out_group_view_change_uuid = row->get_string(1);
+    if (out_single_primary_mode && !row->is_null(2))
+      *out_single_primary_mode = (row->get_int(2) != 0);
+    if (out_member_id) *out_member_id = row->get_string(3);
+    if (out_member_state)
+      *out_member_state = to_member_state(row->get_string(4));
+    if (out_has_quorum)
+      *out_has_quorum = row->is_null(5) ? false : row->get_int(5) != 0;
+    if (out_is_primary) *out_is_primary = row->get_int(6, 0);
+
+    return true;
+
   } catch (const mysqlshdk::db::Error &e) {
     log_error("Error while querying for group_replication info: %s", e.what());
-    if (e.code() == ER_BAD_DB_ERROR || e.code() == ER_NO_SUCH_TABLE ||
-        e.code() == ER_UNKNOWN_SYSTEM_VARIABLE) {
-      // if GR plugin is not installed, we get unknown sysvar
-      // if server doesn't have pfs, we get BAD_DB
-      // if server has pfs but not the GR tables, we get NO_SUCH_TABLE
-      return false;
+    switch (e.code()) {
+      case ER_BAD_DB_ERROR:
+      case ER_NO_SUCH_TABLE:
+      case ER_UNKNOWN_SYSTEM_VARIABLE:
+        // if GR plugin is not installed, we get unknown sysvar
+        // if server doesn't have pfs, we get BAD_DB
+        // if server has pfs but not the GR tables, we get NO_SUCH_TABLE
+        return false;
+      default:
+        throw;
     }
-    throw;
   }
 }
 
 std::string get_group_primary_uuid(const mysqlshdk::mysql::IInstance &instance,
                                    bool *out_single_primary_mode) {
-  auto res = instance.query(
-      "SELECT @@group_replication_single_primary_mode, "
-      "       variable_value AS primary_uuid"
-      "   FROM performance_schema.global_status"
-      "   WHERE variable_name = 'group_replication_primary_member'");
-  const db::IRow *row = res->fetch_one();
-  if (row) {
+  std::string query;
+  // the column "member_role" was only added in 8.0.2
+  if (instance.get_version() >= utils::Version(8, 0, 2)) {
+    query =
+        "SELECT @@group_replication_single_primary_mode, member_id AS "
+        "primary_uuid"
+        "   FROM performance_schema.replication_group_members"
+        "   WHERE (member_role = 'PRIMARY')";
+  } else {
+    query =
+        "SELECT @@group_replication_single_primary_mode, "
+        "       variable_value AS primary_uuid"
+        "   FROM performance_schema.global_status"
+        "   WHERE variable_name = 'group_replication_primary_member'";
+  }
+
+  auto res = instance.query(query);
+  if (auto row = res->fetch_one(); row) {
     if (out_single_primary_mode) *out_single_primary_mode = row->get_int(0);
     if (row->is_null(1)) return "";
     return row->get_string(1);
   }
+
   throw std::logic_error("GR status query returned no rows");
 }
 
 mysqlshdk::utils::Version get_group_protocol_version(
     const mysqlshdk::mysql::IInstance &instance) {
-  // MySQL versions in the domain [5.7.14, 8.0.15] map to GCS protocol version
-  // 1 (5.7.14) so we can return it immediately and avoid an error when
-  // executing the UDF to obtain the protocol version since the UDF is only
-  // available for versions >= 8.0.16
-  if (instance.get_version() < mysqlshdk::utils::Version(8, 0, 16)) {
-    return mysqlshdk::utils::Version(5, 7, 14);
-  } else {
-    try {
-      const char *get_gr_protocol_version =
-          "SELECT group_replication_get_communication_protocol()";
+  // MySQL versions in the domain <= 8.0.15 map to GCS protocol version 1 so
+  // we can return it immediately and avoid an error when executing the UDF to
+  // obtain the protocol version since the UDF is only available for versions
+  // >= 8.0.16
+  if (instance.get_version() < mysqlshdk::utils::Version(8, 0, 16))
+    return mysqlshdk::utils::Version(8, 0, 15);
 
-      log_debug("Executing UDF: %s",
-                get_gr_protocol_version + sizeof("SELECT"));  // hide "SELECT "
+  try {
+    const char *get_gr_protocol_version =
+        "SELECT group_replication_get_communication_protocol()";
 
-      auto resultset = instance.query_udf(get_gr_protocol_version);
-      auto row = resultset->fetch_one();
+    log_debug("Executing UDF: %s",
+              get_gr_protocol_version + sizeof("SELECT "));  // hide "SELECT "
 
-      if (row) {
-        return (mysqlshdk::utils::Version(row->get_string(0)));
-      } else {
-        throw std::logic_error(
-            "No rows returned when querying the version of Group Replication "
-            "communication protocol.");
-      }
-    } catch (const mysqlshdk::db::Error &error) {
-      throw shcore::Exception::mysql_error_with_code_and_state(
-          error.what(), error.code(), error.sqlstate());
-    }
+    auto resultset = instance.query_udf(get_gr_protocol_version);
+    auto row = resultset->fetch_one();
+    if (!row)
+      throw std::logic_error(
+          "No rows returned when querying the version of Group Replication "
+          "communication protocol.");
+
+    return (mysqlshdk::utils::Version(row->get_string(0)));
+
+  } catch (const mysqlshdk::db::Error &error) {
+    throw shcore::Exception::mysql_error_with_code_and_state(
+        error.what(), error.code(), error.sqlstate());
   }
 }
 
 mysqlshdk::utils::Version get_max_supported_group_protocol_version(
     const mysqlshdk::utils::Version &server_version) {
-  if (server_version < mysqlshdk::utils::Version(8, 0, 16)) {
-    return mysqlshdk::utils::Version(5, 7, 14);
-  } else if (server_version < mysqlshdk::utils::Version(8, 0, 27)) {
-    // Protocol version for any server >= 8.0.16 && < 8.0.27 is 8.0.16
+  if (server_version < mysqlshdk::utils::Version(8, 0, 16))
+    return mysqlshdk::utils::Version(8, 0, 15);
+
+  // Protocol version for any server >= 8.0.16 && < 8.0.27 is 8.0.16
+  if (server_version < mysqlshdk::utils::Version(8, 0, 27))
     return mysqlshdk::utils::Version(8, 0, 16);
-  }
 
   // we have to assume protocol version for any server >= 8.0.27 is 8.0.27
   return mysqlshdk::utils::Version(8, 0, 27);
@@ -510,16 +528,18 @@ mysqlshdk::utils::Version get_max_supported_group_protocol_version(
 void set_group_protocol_version(const mysqlshdk::mysql::IInstance &instance,
                                 mysqlshdk::utils::Version version) {
   std::string query;
+  {
+    auto query_fmt =
+        "SELECT group_replication_set_communication_protocol(?)"_sql
+        << version.get_full();
+    query_fmt.done();
 
-  shcore::sqlstring query_fmt(
-      "SELECT group_replication_set_communication_protocol(?)", 0);
-  query_fmt << version.get_full();
-  query_fmt.done();
-  query = query_fmt.str();
+    query = query_fmt.str();
+  }
 
   try {
     log_debug("Executing UDF: %s",
-              query.c_str() + sizeof("SELECT"));  // hide "SELECT "
+              query.c_str() + sizeof("SELECT "));  // hide "SELECT "
 
     instance.query_udf(query);
   } catch (const mysqlshdk::db::Error &error) {
@@ -641,7 +661,7 @@ void start_group_replication(const mysqlshdk::mysql::IInstance &instance,
                         mysqlshdk::mysql::Var_qualifier::GLOBAL);
   try {
     instance.execute("START GROUP_REPLICATION");
-  } catch (const std::exception &err) {
+  } catch (const std::exception &) {
     // Try to set the group_replication_bootstrap_group to OFF if the
     // statement to start GR failed and only then throw the error.
     try {
@@ -668,15 +688,6 @@ void stop_group_replication(const mysqlshdk::mysql::IInstance &instance) {
   instance.execute("STOP GROUP_REPLICATION");
 }
 
-std::string generate_uuid(const mysqlshdk::mysql::IInstance &instance) {
-  // Generate a UUID on the MySQL server.
-  std::string get_uuid_stmt = "SELECT UUID()";
-  auto resultset = instance.query(get_uuid_stmt);
-  auto row = resultset->fetch_one();
-
-  return row->get_string(0);
-}
-
 /**
  * Check the specified replication user, namely if it has the required
  * privileges to use for Group Replication.
@@ -720,13 +731,7 @@ mysqlshdk::mysql::Auth_options create_recovery_user(
   if (options.mysql_comm_stack_supported)
     user_options.grants.push_back({"GROUP_REPLICATION_STREAM", "*.*", false});
 
-  if (primary.get_version() >= utils::Version(8, 0, 0)) {
-    // Recovery accounts must have CONNECTION_ADMIN too, otherwise, if a group
-    // members has offline_mode enabled the member is evicted from the group
-    // since the recovery account connections are disconnected and blocked.
-    // This has greater impact when using "MySQL" communication stack
-    user_options.grants.push_back({"CONNECTION_ADMIN", "*.*", false});
-  }
+  user_options.grants.push_back({"CONNECTION_ADMIN", "*.*", false});
 
   mysqlshdk::mysql::Auth_options creds;
 
@@ -780,8 +785,7 @@ bool is_group_replication_delayed_starting(
     return instance
                .query(
                    "SELECT COUNT(*) FROM performance_schema.threads WHERE NAME "
-                   "= "
-                   "'thread/group_rpl/THD_delayed_initialization'")
+                   "= 'thread/group_rpl/THD_delayed_initialization'")
                ->fetch_one()
                ->get_uint(0) != 0;
   } catch (const std::exception &e) {
@@ -796,28 +800,23 @@ bool is_active_member(const mysqlshdk::mysql::IInstance &instance,
   shcore::sqlstring is_active_member_stmt;
 
   if (!host.empty() && port != 0) {
-    std::string is_active_member_stmt_fmt =
+    is_active_member_stmt =
         "SELECT count(*) "
         "FROM performance_schema.replication_group_members "
         "WHERE MEMBER_HOST = ? AND MEMBER_PORT = ? "
-        "AND MEMBER_STATE NOT IN ('OFFLINE', 'UNREACHABLE')";
-    is_active_member_stmt =
-        shcore::sqlstring(is_active_member_stmt_fmt.c_str(), 0);
-    is_active_member_stmt << host;
-    is_active_member_stmt << port;
-    is_active_member_stmt.done();
+        "AND MEMBER_STATE NOT IN ('OFFLINE', 'UNREACHABLE')"_sql;
+    is_active_member_stmt << host << port;
 
   } else {
-    std::string is_active_member_stmt_fmt =
+    is_active_member_stmt =
         "select count(*) "
         "FROM performance_schema.replication_group_members "
         "WHERE MEMBER_ID = @@server_uuid AND MEMBER_STATE NOT "
-        "IN ('OFFLINE', 'UNREACHABLE')";
-    is_active_member_stmt =
-        shcore::sqlstring(is_active_member_stmt_fmt.c_str(), 0);
-    is_active_member_stmt.done();
+        "IN ('OFFLINE', 'UNREACHABLE')"_sql;
   }
 
+  is_active_member_stmt.done();
+
   try {
     auto result = instance.query(is_active_member_stmt);
     auto row = result->fetch_one();
@@ -1003,14 +1002,16 @@ bool is_running_gr_auto_rejoin(const mysqlshdk::mysql::IInstance &instance) {
 void check_instance_version_compatibility(
     const mysqlshdk::mysql::IInstance &instance,
     mysqlshdk::utils::Version lowest_cluster_version) {
-  auto gr_allow_lower_version_join = instance.get_sysvar_bool(
-      "group_replication_allow_local_lower_version_join", false);
+  if (lowest_cluster_version < utils::Version(8, 4, 0)) {
+    auto gr_allow_lower_version_join = instance.get_sysvar_bool(
+        "group_replication_allow_local_lower_version_join", false);
 
-  // If gr_allow_lower_version_join is NULL then it means the variable is not
-  // available, e.g., if the GR plugin is not installed which happens by default
-  // on 5.7 servers. In that case, we apply the expected behaviour for the
-  // default variable value (false).
-  if (gr_allow_lower_version_join) return;
+    // If gr_allow_lower_version_join is NULL then it means the variable is not
+    // available, e.g., if the GR plugin is not installed which happens by
+    // default on 5.7 servers. In that case, we apply the expected behaviour for
+    // the default variable value (false).
+    if (gr_allow_lower_version_join) return;
+  }
 
   mysqlshdk::utils::Version target_version = instance.get_version();
 
@@ -1164,8 +1165,7 @@ bool is_endpoint_supported_by_gr(const std::string &endpoint,
   const bool supports_ipv6 = (version >= mysqlshdk::utils::Version(8, 0, 14));
   try {
     // split host from port, and make sure endpoint has both
-    mysqlshdk::db::Connection_options conn_opt =
-        shcore::get_connection_options(endpoint, false);
+    mysqlshdk::db::Connection_options conn_opt(endpoint);
 
     if (!conn_opt.has_host() || !conn_opt.has_port()) {
       throw shcore::Exception::argument_error(
@@ -1184,7 +1184,7 @@ bool is_endpoint_supported_by_gr(const std::string &endpoint,
     // no guarantee that name resolution is the same across cluster instances
     // and the instance where we are running the ngshell.
     return true;
-  } catch (const std::invalid_argument &error) {
+  } catch (const std::invalid_argument &) {
     throw shcore::Exception::argument_error(
         shcore::str_format("Invalid address format: '%s'", endpoint.c_str()));
   }
@@ -1218,7 +1218,7 @@ void execute_member_action_udf(const mysqlshdk::mysql::IInstance &instance,
   try {
     assert(shcore::str_ibeginswith(query, "select "));
     log_debug("Executing UDF: %s",
-              query.c_str() + sizeof("SELECT"));  // hide "SELECT "
+              query.c_str() + sizeof("SELECT "));  // hide "SELECT "
     instance.query_udf(query);
   } catch (const mysqlshdk::db::Error &error) {
     throw shcore::Exception::mysql_error_with_code_and_state(
