@@ -221,18 +221,6 @@ void start_group_replication(const mysqlshdk::mysql::IInstance &instance,
                              const bool bootstrap);
 void stop_group_replication(const mysqlshdk::mysql::IInstance &instance);
 
-/**
- * Generate a UUID to use for the group name / view change uuid
- *
- * The UUID is generated from the target instance (MySQL server) using the
- * UUID() SQL function.
- *
- * @param instance target instance used to generate the UUID.
- *
- * @return A string with a new UUID to be used,
- */
-std::string generate_uuid(const mysqlshdk::mysql::IInstance &instance);
-
 // Function to manage the replication (recovery) user for GR.
 mysql::User_privileges_result check_replication_user(
     const mysqlshdk::mysql::IInstance &instance, const std::string &user,
@@ -395,8 +383,7 @@ bool is_running_gr_auto_rejoin(const mysqlshdk::mysql::IInstance &instance);
 /**
  * Check the instance version compatibility to join Group Replication.
  *
- *  The compatibility of the instance version is determined based on the
- *  instance group_replication_allow_local_lower_version_join value and its
+ *  The compatibility of the instance version is determined using its
  *  version compared to the lowest version of the members in the cluster.
  *
  *  For more information see:
@@ -469,7 +456,7 @@ Group_member_recovery_status detect_recovery_status(
  * assume that name resolution is the same across all the cluster instances and
  * the machine where the ngshell is running.
  *
- * // Note cannot be used for ipWhitelist validation as ipWhitelist values
+ * // Note cannot be used for ipAllowlist validation as ipAllowlist values
  * // don't have a port, just IP/hostname and also accept netmasks.
  * @param endpoint The endpoint we want to check is supported by the instance to
  * be used as either localAddress or groupSeed.
