@@ -32,6 +32,7 @@
 
 #include "mysqlshdk/libs/storage/config.h"
 #include "mysqlshdk/libs/utils/masked_value.h"
+#include "mysqlshdk/libs/utils/utils_file.h"
 
 namespace mysqlshdk {
 namespace oci {
@@ -59,7 +60,7 @@ struct PAR {
   std::size_t size;
 };
 
-enum class PAR_type { MANIFEST, PREFIX, GENERAL, NONE };
+enum class PAR_type { PREFIX, GENERAL, NONE };
 
 struct PAR_structure {
   inline PAR_type type() const noexcept { return m_type; }
@@ -104,6 +105,8 @@ std::string to_string(PAR_type type);
 
 std::string hide_par_secret(const std::string &par, std::size_t start_at = 0);
 
+std::string mask_any_par(const std::string &input);
+
 template <typename T>
 Masked_string anonymize_par(T &&par) {
   return {std::forward<T>(par), hide_par_secret(par)};
@@ -124,10 +127,18 @@ class IPAR_config : public storage::Config {
   IPAR_config &operator=(const IPAR_config &) = delete;
   IPAR_config &operator=(IPAR_config &&) = default;
 
-  ~IPAR_config() override = default;
+  ~IPAR_config() override {
+    if (!m_temp_folder.empty()) {
+      shcore::remove_directory(m_temp_folder);
+    }
+  }
 
   const PAR_structure &par() const { return m_par; }
 
+  const std::string &temp_folder() const { return m_temp_folder; }
+
+  void set_temp_folder(const std::string &path) { m_temp_folder = path; }
+
  protected:
   PAR_structure m_par;
 
@@ -135,6 +146,8 @@ class IPAR_config : public storage::Config {
   std::string describe_self() const override;
 
   std::string describe_url(const std::string &url) const override;
+
+  std::string m_temp_folder;
 };
 
 template <PAR_type Type>
@@ -147,6 +160,9 @@ class PAR_config : public IPAR_config {
   explicit PAR_config(const PAR_structure &par) {
     if (Type == par.type()) {
       m_par = par;
+      if (Type == PAR_type::PREFIX) {
+        set_temp_folder(shcore::create_temporary_folder());
+      }
     }
   }
 
