@@ -131,15 +131,13 @@ static std::string dumpTree(RuleContext *context, const Vocabulary &vocabulary,
             ruleContext, vocabulary,
             indentation.size() < 100 ? indentation + " " : indentation);
       }
-    } else {
+    } else if (antlrcpp::is<TerminalNode *>(child)) {
       // A terminal node.
       stream << indentation;
 
-      TerminalNode *node = dynamic_cast<TerminalNode *>(child);
       if (antlrcpp::is<ErrorNode *>(child)) stream << "Syntax Error: ";
 
-      antlr4::Token *token = node->getSymbol();
-
+      antlr4::Token *token = dynamic_cast<TerminalNode *>(child)->getSymbol();
       std::size_t type = token->getType();
       std::string_view tokenName =
           type == Token::EOF ? "<EOF>"
