@@ -25,11 +25,12 @@
 
 #ifndef MYSQLSHDK_LIBS_SSH_SSH_CONNECTION_OPTIONS_H_
 #define MYSQLSHDK_LIBS_SSH_SSH_CONNECTION_OPTIONS_H_
+
 #include <optional>
 #include <set>
+#include <stdexcept>
 #include <string>
 
-#include "mysqlshdk/libs/db/utils_connection.h"
 #include "mysqlshdk/libs/utils/connection.h"
 #include "mysqlshdk/libs/utils/nullable_options.h"
 
