@@ -42,6 +42,7 @@
 
 #include "mysqlshdk/libs/storage/idirectory.h"
 #include "mysqlshdk/libs/storage/utils.h"
+#include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/logger.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
@@ -93,8 +94,9 @@ void File::open(Mode m) {
   bool do_chmod = true;
 
 #ifdef _WIN32
-  const wchar_t *mode =
-      m == Mode::READ ? L"rb" : m == Mode::WRITE ? L"wb" : L"ab";
+  const wchar_t *mode = m == Mode::READ    ? L"rb"
+                        : m == Mode::WRITE ? L"wb"
+                                           : L"ab";
   m_file = _wfsopen(wpath.c_str(), mode, _SH_DENYWR);
 
   if (m_use_mmap == Mmap_preference::REQUIRED)
@@ -198,15 +200,17 @@ off64_t File::seek(off64_t offset) {
   assert(is_open());
 
 #if defined(_WIN32)
-  return _fseeki64(m_file, offset, SEEK_SET);
+  _fseeki64(m_file, offset, SEEK_SET);
 #else
   if (m_mmap_ptr) {
     assert(offset < static_cast<off64_t>(m_mmap_used));
     m_mmap_offset = offset;
     return offset;
   }
-  return fseeko(m_file, offset, SEEK_SET);
+  fseeko(m_file, offset, SEEK_SET);
 #endif
+
+  return tell();
 }
 
 off64_t File::tell() const {
@@ -252,7 +256,7 @@ bool File::flush() {
 #endif
     return true;
   }
-  return fflush(m_file);
+  return 0 == fflush(m_file);
 }
 
 bool File::exists() const { return shcore::is_file(full_path().real()); }
@@ -338,8 +342,23 @@ char *File::mmap_will_write(size_t length, size_t *out_avail) {
 
     m_mmap_ptr = static_cast<char *>(
         ::mmap(0, m_mmap_available, PROT_WRITE | PROT_READ, flags, fd, 0));
+
+    DBUG_EXECUTE_IF(
+        "mmap_not_supported_by_fs",
+        if (m_mmap_ptr && MAP_FAILED != m_mmap_ptr) {
+          ::munmap(m_mmap_ptr, m_mmap_available);
+          m_mmap_ptr = nullptr;
+        });
+
     if (!m_mmap_ptr || m_mmap_ptr == MAP_FAILED) {
       m_mmap_ptr = nullptr;
+      if (::ftruncate(fd, m_mmap_used) < 0) {
+        if (m_use_mmap == Mmap_preference::REQUIRED) {
+          throw std::runtime_error("Could not restore size of mmapped file '" +
+                                   full_path().masked() +
+                                   "': " + shcore::errno_to_string(errno));
+        }
+      }
 
       if (m_use_mmap == Mmap_preference::REQUIRED)
         throw std::runtime_error("Could not mmap file '" +
