@@ -28,6 +28,7 @@
 #include <memory>
 #include <stdexcept>
 
+#include "mysqlshdk/libs/db/uri_encoder.h"
 #include "mysqlshdk/libs/storage/backend/oci_par_directory.h"
 
 namespace mysqlshdk {
@@ -36,8 +37,18 @@ namespace backend {
 namespace oci {
 
 std::unique_ptr<IFile> Oci_par_directory_config::file(
-    const std::string &) const {
-  throw std::logic_error("Oci_par_directory_config::file() - not supported");
+    const std::string &name) const {
+  const auto full = ::mysqlshdk::oci::anonymize_par(par().full_url());
+  auto real = full.real();
+  auto masked = full.masked();
+
+  Masked_string copy = {std::move(real), std::move(masked)};
+
+  auto file =
+      std::make_unique<Oci_par_file>(copy, db::uri::pctencode_path(name), true);
+  file->set_parent_config(shared_from_this());
+
+  return file;
 }
 
 std::unique_ptr<IDirectory> Oci_par_directory_config::directory(
