@@ -24,24 +24,35 @@
  */
 
 #include "mysqlshdk/libs/utils/nullable_options.h"
+
+#include <stdexcept>
+
 #include "mysqlshdk/libs/utils/utils_string.h"
 
 namespace mysqlshdk {
 namespace utils {
 
+namespace {
+bool opt_comp(const std::string &lhs, const std::string &rhs) noexcept {
+  return lhs.compare(rhs) < 0;
+}
+
+bool opt_icomp(const std::string &lhs, const std::string &rhs) noexcept {
+  return shcore::str_casecmp(lhs.c_str(), rhs.c_str()) < 0;
+}
+
+}  // namespace
+
 using nullable_options::Comparison_mode;
 using nullable_options::Set_mode;
 
-Nullable_options::Nullable_options(Comparison_mode mode,
-                                   const std::string &context)
-    : _ctx(context),
+Nullable_options::Nullable_options(Comparison_mode mode, std::string context)
+    : _ctx(std::move(context)),
       _mode(mode),
-      _options(_mode == Comparison_mode::CASE_SENSITIVE
-                   ? Nullable_options::comp
-                   : Nullable_options::icomp),
-      _defaults(_mode == Comparison_mode::CASE_SENSITIVE
-                    ? Nullable_options::comp
-                    : Nullable_options::icomp) {
+      m_options(_mode == Comparison_mode::CASE_SENSITIVE ? opt_comp
+                                                         : opt_icomp),
+      m_defaults(_mode == Comparison_mode::CASE_SENSITIVE ? opt_comp
+                                                          : opt_icomp) {
   if (!_ctx.empty() && _ctx[_ctx.size() - 1] != ' ') _ctx.append(" ");
 }
 
@@ -53,22 +64,14 @@ int Nullable_options::compare(const std::string &lhs,
     return shcore::str_casecmp(lhs.c_str(), rhs.c_str());
 }
 
-bool Nullable_options::comp(const std::string &lhs, const std::string &rhs) {
-  return lhs.compare(rhs) < 0;
-}
-
-bool Nullable_options::icomp(const std::string &lhs, const std::string &rhs) {
-  return shcore::str_casecmp(lhs.c_str(), rhs.c_str()) < 0;
-}
-
 bool Nullable_options::has(const std::string &name) const {
-  return _options.find(name) != _options.end();
+  return m_options.find(name) != m_options.end();
 }
 
 bool Nullable_options::has_value(const std::string &name) const {
   if (!has(name)) throw_invalid_option(name);
 
-  return _options.at(name).has_value();
+  return m_options.at(name).has_value();
 }
 
 void Nullable_options::set(const std::string &name, const std::string &value,
@@ -86,7 +89,7 @@ void Nullable_options::set(const std::string &name, const std::string &value,
     else if (has_value(name))
       throw_already_defined_option(name);
   }
-  _options[name] = value;
+  m_options[name] = value;
 }
 
 void Nullable_options::set(const std::string &name, const char *value,
@@ -99,65 +102,56 @@ void Nullable_options::set(const std::string &name, const char *value,
 
   // The option is meant to be updated if null (So must exist and be empty)
   if (mode == Set_mode::UPDATE_NULL) {
-    if (!has(name))
-      throw_invalid_option(name);
-    else if (has_value(name))
-      throw_already_defined_option(name);
+    if (!has(name)) throw_invalid_option(name);
+    if (has_value(name)) throw_already_defined_option(name);
   }
 
   if (value)
-    _options[name] = value;
+    m_options[name] = value;
   else
-    _options[name] = {};
+    m_options[name] = {};
 }
 
 void Nullable_options::set_default(const std::string &name, const char *value) {
   if (value)
-    _defaults[name] = value;
-  else {
-    if (_defaults.find(name) != _defaults.end()) {
-      _defaults.erase(name);
-    }
-  }
+    m_defaults[name] = value;
+  else
+    m_defaults.erase(name);
 }
 
 bool Nullable_options::has_default(const std::string &name) const {
-  auto pos = _defaults.find(name);
-  return pos != _defaults.end();
+  return m_defaults.find(name) != m_defaults.end();
 }
 
 std::string Nullable_options::get_default(const std::string &name) const {
-  if (has_default(name)) return *_defaults.at(name);
-
-  return "";
+  if (!has_default(name)) return {};
+  return *m_defaults.at(name);
 }
 
 const std::string &Nullable_options::get_value(const std::string &name) const {
   //  if (!has(name)) throw_invalid_option(name);
 
   if (!has_value(name)) throw_no_value(name);
-
-  return *_options.at(name);
+  return *m_options.at(name);
 }
 
 void Nullable_options::clear_value(const std::string &name, bool secure) {
   if (!has(name)) throw_invalid_option(name);
 
   if (secure && has_value(name)) {
-    shcore::clear_buffer(*_options.at(name));
+    shcore::clear_buffer(*m_options.at(name));
   }
-  _options.at(name).reset();
+  m_options.at(name).reset();
 }
 
 void Nullable_options::remove(const std::string &name) {
   if (!has(name)) throw_invalid_option(name);
-
-  _options.erase(name);
+  m_options.erase(name);
 }
 
 void Nullable_options::override_from(const Nullable_options &options,
                                      bool skip_null) {
-  for (auto &o : options._options) {
+  for (const auto &o : options.m_options) {
     if (o.second.has_value())
       set(o.first, *o.second, Set_mode::CREATE_AND_UPDATE);
     else if (!skip_null)
@@ -193,21 +187,19 @@ bool Nullable_options::operator==(const Nullable_options &other) const {
   // Tests for different number of options
   if (size() != other.size()) return false;
 
-  for (const auto &o : _options) {
+  for (const auto &o : m_options) {
     // Tests for options being contained on both
-    if (!other.has(o.first)) {
-      return false;
-    } else {
-      bool has_a_value = has_value(o.first);
-      // tests for options having or not value on both
-      if (has_a_value != other.has_value(o.first)) {
+    if (!other.has(o.first)) return false;
+
+    // tests for options having or not value on both
+    bool has_a_value = has_value(o.first);
+    if (has_a_value != other.has_value(o.first)) return false;
+
+    if (has_a_value) {
+      // tests for options having the same value on both
+      // NOTE(rennox): Value comparison is Case Sensitive in all cases
+      if (*o.second != other.get_value(o.first)) {
         return false;
-      } else if (has_a_value) {
-        // tests for options having the same value on both
-        // NOTE(rennox): Value comparison is Case Sensitive in all cases
-        if (*o.second != other.get_value(o.first)) {
-          return false;
-        }
       }
     }
   }
