@@ -83,7 +83,8 @@ bool SHCORE_PUBLIC is_folder(const std::string &filename);
 bool SHCORE_PUBLIC path_exists(const std::string &path);
 void SHCORE_PUBLIC ensure_dir_exists(const std::string &path);  // delme
 void SHCORE_PUBLIC create_directory(const std::string &path,
-                                    bool recursive = true, int mode = 0700);
+                                    bool recursive = true, int mode = 0700,
+                                    bool reuse_existing = true);
 void SHCORE_PUBLIC remove_directory(const std::string &path,
                                     bool recursive = true);
 std::string SHCORE_PUBLIC get_last_error();
@@ -105,6 +106,11 @@ std::vector<std::string> SHCORE_PUBLIC listdir(const std::string &path);
 bool SHCORE_PUBLIC iterdir(const std::string &path,
                            const std::function<bool(const std::string &)> &fun);
 
+// recursive iterdir()
+bool SHCORE_PUBLIC iterdir(
+    const std::string &path,
+    const std::function<bool(const std::string &, const std::string &)> &fun);
+
 void SHCORE_PUBLIC check_file_writable_or_throw(const std::string &filename);
 void SHCORE_PUBLIC check_file_readable_or_throw(const std::string &filename);
 int SHCORE_PUBLIC make_file_readonly(const std::string &path);
@@ -154,6 +160,9 @@ check_file_access_rights_to_open(const std::string &file_name);
  *        name).
  */
 std::string SHCORE_PUBLIC get_tempfile_path(const std::string &file_path);
+
+FILE *create_private_file(const std ::string &path);
+std::string create_temporary_folder(size_t max_attempts = 10);
 }  // namespace shcore
 
 #endif  // MYSQLSHDK_LIBS_UTILS_UTILS_FILE_H_
