@@ -28,7 +28,10 @@
 
 #include <cstdint>
 #include <optional>
+#include <ostream>
 #include <string>
+#include <string_view>
+#include <vector>
 
 namespace mysqlshdk {
 namespace utils {
@@ -39,7 +42,7 @@ namespace utils {
 class Version {
  public:
   constexpr Version() = default;
-  explicit Version(const std::string &version);
+  explicit Version(std::string_view version);
   explicit constexpr Version(int major, int minor) noexcept
       : _major(major), _minor(minor) {}
   explicit constexpr Version(int major, int minor, int patch) noexcept
@@ -86,6 +89,11 @@ class Version {
    */
   uint32_t numeric() const;
 
+  /**
+   * Returns true if this is an MDS server.
+   */
+  bool is_mds() const;
+
   /**
    * Returns the numeric major.minor version series (MMmm)
    */
@@ -99,17 +107,58 @@ class Version {
   bool operator!=(const Version &other) const;
   explicit operator bool() const;
 
+  // helpers used by gtest
+  friend std::ostream &operator<<(::std::ostream &os, const Version &v) {
+    return os << v.get_full();
+  }
+
+  friend void PrintTo(const Version &v, ::std::ostream *os) { *os << v; }
+
  private:
   int _major = 0;
   std::optional<int> _minor;
   std::optional<int> _patch;
   std::optional<std::string> _extra;
 
-  int parse_token(const std::string &data);
+  int parse_token(std::string_view data);
 };
 
 inline const Version k_shell_version = Version(MYSH_VERSION);
 
+/**
+ * Provides the difference between major versions of source and target. This
+ * difference is positive if target has greater version than source.
+ *
+ * NOTE: for sake of simplicity, the difference between 5.7 and 8.0 is one.
+ *
+ * @param source The source version.
+ * @param target The target version.
+ *
+ * @returns difference between major versions
+ */
+int major_version_difference(const Version &source, const Version &target);
+
+/**
+ * Returns all versions which were current when the given version was released,
+ * sorted in ascending order.
+ */
+std::vector<Version> corresponding_versions(Version version);
+
+/**
+ * Get first LTS version in the same major version as the given version
+ */
+Version get_first_lts_version(Version version);
+
+/**
+ * Get first innovation version in the same major version as the given version
+ */
+Version get_first_innovation_version(Version version);
+
+/**
+ * Checks if this is an LTS release.
+ */
+bool is_lts_release(const Version &v);
+
 }  // namespace utils
 }  // namespace mysqlshdk
 
