@@ -27,16 +27,10 @@
 
 #include "modules/devapi/mod_mysqlx_session.h"
 #include "modules/mod_mysql_session.h"
-#include "mysqlshdk/include/scripting/common.h"
-#include "mysqlshdk/include/scripting/lang_base.h"
-#include "mysqlshdk/include/scripting/object_factory.h"
-#include "mysqlshdk/include/scripting/proxy_object.h"
-#include "mysqlshdk/include/shellcore/interrupt_handler.h"
-#include "mysqlshdk/include/shellcore/shell_core.h"
-#include "mysqlshdk/include/shellcore/utils_help.h"
+#include "mysqlshdk/include/scripting/obj_date.h"
+#include "mysqlshdk/include/shellcore/scoped_contexts.h"
 #include "mysqlshdk/libs/ssh/ssh_manager.h"
 #include "mysqlshdk/libs/utils/debug.h"
-#include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_json.h"
 #include "mysqlshdk/libs/utils/utils_sqlstring.h"
@@ -47,6 +41,137 @@ using namespace shcore;
 
 DEBUG_OBJ_ENABLE(ShellBaseSession);
 
+bool Query_attribute_store::set(const std::string &name,
+                                const shcore::Value &value) {
+  constexpr size_t MAX_QUERY_ATTRIBUTES = 32;
+  constexpr size_t MAX_QUERY_ATTRIBUTE_LENGTH = 1024;
+
+  // Searches for the element first
+  const auto it = m_store.find(name);
+
+  // Validates name for any new attribute
+  if (it == m_store.end()) {
+    if (m_order.size() >= MAX_QUERY_ATTRIBUTES) {
+      m_exceeded.push_back(name);
+      return false;
+    }
+    if (name.size() > MAX_QUERY_ATTRIBUTE_LENGTH) {
+      m_invalid_names.push_back(name);
+      return false;
+    };
+  }
+
+  // Validates the value type
+  auto type = value.get_type();
+  if (type == shcore::Value_type::Undefined ||
+      type == shcore::Value_type::Array || type == shcore::Value_type::Map ||
+      type == shcore::Value_type::Function ||
+      type == shcore::Value_type::Binary ||
+      (type == shcore::Value_type::Object && !value.as_object<Date>())) {
+    m_unsupported_type.push_back(name);
+    return false;
+  }
+
+  // Validates the string value lengths
+  if (type == shcore::Value_type::String &&
+      value.get_string().size() > MAX_QUERY_ATTRIBUTE_LENGTH) {
+    m_invalid_value_length.push_back(name);
+    return false;
+  }
+
+  // Inserts or updates the value
+  m_store[name] = value;
+
+  // Adds the new value to the order
+  if (it == m_store.end()) {
+    m_order.emplace_back(m_store.find(name)->first);
+  }
+
+  return true;
+}
+
+bool Query_attribute_store::set(const shcore::Dictionary_t &attributes) {
+  bool ret_val = true;
+
+  clear();
+
+  for (auto it = attributes->begin(); it != attributes->end(); it++) {
+    if (!set(it->first, it->second)) {
+      ret_val = false;
+    }
+  }
+
+  return ret_val;
+}
+
+void Query_attribute_store::handle_errors(bool raise_error) {
+  std::vector<std::string> issues;
+  auto validate = [&issues](const std::vector<std::string> &data,
+                            const std::string &message) -> void {
+    if (!data.empty()) {
+      bool singular = data.size() == 1;
+      issues.push_back(
+          shcore::str_format(message.data(), (singular ? "" : "s"),
+                             shcore::str_join(data, ", ").c_str()));
+    }
+  };
+
+  validate(m_invalid_names,
+           "The following query attribute%s exceed the maximum name length "
+           "(1024): %s");
+
+  validate(m_invalid_value_length,
+           "The following query attribute%s exceed the maximum value length "
+           "(1024): %s");
+
+  validate(m_unsupported_type,
+           "The following query attribute%s have an unsupported data type: %s");
+
+  validate(m_exceeded,
+           "The following query attribute%s exceed the maximum limit (32): %s");
+
+  if (!issues.empty()) {
+    std::string error = "Invalid query attributes found";
+
+    if (!raise_error) error.append(", they will be ignored");
+
+    const auto message = shcore::str_format(
+        "%s: %s", error.c_str(), shcore::str_join(issues, "\n\t").c_str());
+
+    if (raise_error) {
+      clear();
+      throw std::invalid_argument(message);
+    } else {
+      mysqlsh::current_console()->print_warning(message);
+    }
+  }
+}
+
+void Query_attribute_store::clear() {
+  m_order.clear();
+  m_store.clear();
+  m_invalid_names.clear();
+  m_invalid_value_length.clear();
+  m_unsupported_type.clear();
+  m_exceeded.clear();
+}
+
+std::vector<mysqlshdk::db::Query_attribute>
+Query_attribute_store::get_query_attributes(
+    const std::function<std::unique_ptr<mysqlshdk::db::IQuery_attribute_value>(
+        const shcore::Value &)> &translator_cb) const {
+  assert(translator_cb);
+
+  std::vector<mysqlshdk::db::Query_attribute> attributes;
+  attributes.reserve(m_order.size());
+
+  for (const auto &name : m_order) {
+    attributes.emplace_back(name, translator_cb(m_store.at(std::string{name})));
+  }
+
+  return attributes;
+}
+
 ShellBaseSession::ShellBaseSession() : _tx_deep(0) {
   DEBUG_OBJ_ALLOC(ShellBaseSession);
 }
@@ -130,12 +255,13 @@ void ShellBaseSession::enable_sql_mode_tracking() {
 
     current_value = shcore::str_lower(row->get_string(0));
 
-  } catch (const mysqlshdk::db::Error &e) {
+  } catch (const mysqlshdk::db::Error &) {
     return;
   }
 
   m_is_sql_mode_tracking_enabled =
-      current_value.find("sql_mode") != std::string::npos;
+      current_value.find("sql_mode") != std::string::npos ||
+      current_value == "*";
 
   if (m_is_sql_mode_tracking_enabled) {
     log_info("Already tracking 'sql_mode'system variable.");
@@ -147,7 +273,7 @@ void ShellBaseSession::enable_sql_mode_tracking() {
   try {
     session->executef("SET SESSION session_track_system_variables = ?;",
                       current_value);
-  } catch (const mysqlshdk::db::Error &e) {
+  } catch (const mysqlshdk::db::Error &) {
     return;
   }
 
@@ -206,63 +332,53 @@ void ShellBaseSession::reconnect() {
 
 std::string ShellBaseSession::sub_query_placeholders(
     const std::string &query, const shcore::Array_t &args) {
-  if (args) {
-    shcore::sqlstring squery(query.c_str(), 0);
-    int i = 0;
-    for (const shcore::Value &value : *args) {
-      try {
-        switch (value.type) {
-          case shcore::Integer:
-            squery << value.as_int();
-            break;
-          case shcore::Bool:
-            squery << value.as_bool();
-            break;
-          case shcore::Float:
-            squery << value.as_double();
-            break;
-          case shcore::Binary:
-          case shcore::String:
-            squery << value.get_string();
-            break;
-          case shcore::Null:
-            squery << nullptr;
-            break;
-          default:
-            throw Exception::argument_error(shcore::str_format(
-                "Invalid type for placeholder value at index #%i", i));
-        }
-      } catch (Exception &e) {
-        throw;
-      } catch (const std::exception &e) {
-        throw Exception::argument_error(shcore::str_format(
-            "%s while substituting placeholder value at index #%i", e.what(),
-            i));
-      }
-      ++i;
-    }
+  if (!args) return query;
+
+  shcore::sqlstring squery(query.c_str(), 0);
+  int i = 0;
+  for (const shcore::Value &value : *args) {
     try {
-      return squery.str();
+      switch (value.get_type()) {
+        case shcore::Integer:
+          squery << value.as_int();
+          break;
+        case shcore::Bool:
+          squery << value.as_bool();
+          break;
+        case shcore::Float:
+          squery << value.as_double();
+          break;
+        case shcore::Binary:
+        case shcore::String:
+          squery << value.get_string();
+          break;
+        case shcore::Null:
+          squery << nullptr;
+          break;
+        default:
+          throw Exception::argument_error(shcore::str_format(
+              "Invalid type for placeholder value at index #%i", i));
+      }
+    } catch (const Exception &) {
+      throw;
     } catch (const std::exception &e) {
-      throw Exception::argument_error(
-          "Insufficient number of values for placeholders in query");
+      throw Exception::argument_error(shcore::str_format(
+          "%s while substituting placeholder value at index #%i", e.what(), i));
     }
+    ++i;
   }
+  try {
+    return squery.str();
+  } catch (const std::exception &) {
+    throw Exception::argument_error(
+        "Insufficient number of values for placeholders in query");
+  }
+
   return query;
 }
 
-void ShellBaseSession::begin_query() {
-  if (_guard_active++ == 0) {
-    // Install kill query as ^C handler
-    current_interrupt()->push_handler([this]() {
-      kill_query();
-      return true;
-    });
-  }
-}
-
-void ShellBaseSession::end_query() {
-  if (--_guard_active == 0) {
-    current_interrupt()->pop_handler();
+void ShellBaseSession::set_query_attributes(const shcore::Dictionary_t &args) {
+  if (!m_query_attributes.set(args)) {
+    m_query_attributes.handle_errors(true);
   }
 }
