@@ -22,15 +22,12 @@
  * along with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
-#include "unittest/gprod_clean.h"
-#include "unittest/gtest_clean.h"
+
 #include "unittest/test_utils/mocks/gmock_clean.h"
 
 #ifndef _WIN32
 #include <sys/stat.h>
 #endif
-#include "ext/linenoise-ng/include/linenoise.h"
-#include "mysqlshdk/libs/utils/strformat.h"
 #include "mysqlshdk/libs/utils/utils_file.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
 #include "mysqlshdk/libs/utils/utils_path.h"
@@ -50,13 +47,13 @@ TEST(Cmdline_shell, query_variable_classic) {
                     "version", mysqlsh::Prompt_manager::Mysql_system_variable));
 
   const char *pwd = getenv("MYSQL_PWD");
-  auto coptions = shcore::get_connection_options("mysql://root@localhost");
+  auto coptions = mysqlshdk::db::Connection_options("mysql://root@localhost");
   if (pwd)
     coptions.set_password(pwd);
   else
     coptions.set_password("");
   coptions.set_port(getenv("MYSQL_PORT") ? atoi(getenv("MYSQL_PORT")) : 3306);
-  shell.connect(coptions, false);
+  shell.connect(coptions);
   EXPECT_NE("", shell.query_variable(
                     "version", mysqlsh::Prompt_manager::Mysql_system_variable));
   EXPECT_NE("",
@@ -77,14 +74,14 @@ TEST(Cmdline_shell, query_variable_x) {
   shell.finish_init();
 
   const char *pwd = getenv("MYSQL_PWD");
-  auto coptions = shcore::get_connection_options("mysqlx://root@localhost");
+  auto coptions = mysqlshdk::db::Connection_options("mysqlx://root@localhost");
   if (pwd)
     coptions.set_password(pwd);
   else
     coptions.set_password("");
   coptions.set_port(getenv("MYSQLX_PORT") ? atoi(getenv("MYSQLX_PORT"))
                                           : 33060);
-  shell.connect(coptions, false);
+  shell.connect(coptions);
   EXPECT_NE("", shell.query_variable(
                     "version", mysqlsh::Prompt_manager::Mysql_system_variable));
   EXPECT_NE("",
@@ -100,7 +97,7 @@ TEST(Cmdline_shell, query_variable_x) {
                     "bogus", mysqlsh::Prompt_manager::Mysql_system_variable));
 }
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
 TEST(Cmdline_shell, prompt_js) {
   char *args[] = {const_cast<char *>("ut"), const_cast<char *>("--js"),
                   const_cast<char *>("--interactive"), nullptr};
@@ -231,6 +228,7 @@ TEST(Cmdline_shell, cmd_edit_with_history) {
     // execute \edit without arguments and an empty history
     capture.clear();
 
+    shell.process_line("\\js");
     shell.process_line("\\edit");
     shell.process_line("");
     EXPECT_THAT(capture,
