@@ -22,7 +22,6 @@
  * along with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
-#include "unittest/gprod_clean.h"
 #include "unittest/test_utils.h"
 
 #include "modules/adminapi/common/common.h"
@@ -32,7 +31,6 @@
 #include "mysqlshdk/libs/utils/version.h"
 #include "unittest/test_utils/mocks/modules/adminapi/common/mock_metadata_storage.h"
 #include "unittest/test_utils/mocks/modules/adminapi/common/mock_precondition_checker.h"
-#include "unittest/test_utils/mocks/mysqlshdk/libs/db/mock_result.h"
 #include "unittest/test_utils/mocks/mysqlshdk/libs/db/mock_session.h"
 
 namespace mysqlsh {
@@ -42,7 +40,7 @@ using testing::_;
 
 using testing::Return;
 
-class Preconditions : public Shell_core_test_wrapper {
+class Admin_api_preconditions : public Shell_core_test_wrapper {
  protected:
   void SetUp() {
     Shell_core_test_wrapper::SetUp();
@@ -57,12 +55,8 @@ class Preconditions : public Shell_core_test_wrapper {
          {mysqlshdk::db::Type::String, mysqlshdk::db::Type::Integer},
          {{"mock@localhost", "3306"}}});
 
-    // m_metadata =
-    // std::make_shared<mysqlsh::dba::MetadataStorage>(m_mock_instance);
     m_mock_metadata =
         std::make_shared<testing::Mock_metadata_storage>(m_mock_instance);
-    //    m_preconditions =
-    //        std::make_shared<mysqlsh::dba::Precondition_checker>(*m_metadata);
     m_preconditions = std::make_shared<mysqlsh::dba::Precondition_checker>(
         m_mock_metadata, m_mock_instance, m_primary_available);
   }
@@ -76,7 +70,7 @@ class Preconditions : public Shell_core_test_wrapper {
   std::shared_ptr<testing::Mock_metadata_storage> m_mock_metadata;
 };
 
-TEST_F(Preconditions, check_session) {
+TEST_F(Admin_api_preconditions, check_session) {
   // Test inexistent session
   try {
     EXPECT_CALL(*m_mock_metadata, get_md_server())
@@ -134,7 +128,7 @@ TEST_F(Preconditions, check_session) {
     } catch (const shcore::Exception &e) {
       EXPECT_STREQ(
           "Unsupported server version: AdminAPI operations in this version of "
-          "MySQL Shell are supported on MySQL Server 5.7 and above",
+          "MySQL Shell are supported on MySQL Server 8.0 and above",
           e.what());
     }
   }
@@ -163,7 +157,7 @@ TEST_F(Preconditions, check_session) {
     }
   }
 
-  std::vector<std::string> valid_versions = {"5.7", "5.7.22"};
+  std::vector<std::string> valid_versions;
 
   valid_versions.push_back(shcore::str_format(
       "%d.%d.%d", mysqlshdk::utils::k_shell_version.get_major(),
@@ -192,16 +186,9 @@ TEST_F(Preconditions, check_session) {
   for (const auto &version : valid_versions) {
     EXPECT_CALL(*m_mock_session, get_server_version())
         .WillOnce(Return(mysqlshdk::utils::Version(version)));
+
     try {
       m_preconditions->check_session();
-
-      if (version == "5.7" || version == "5.7.22") {
-        MY_EXPECT_STDOUT_CONTAINS(
-            "WARNING: Support for AdminAPI operations in MySQL version 5.7 is "
-            "deprecated and will be removed in a future release of MySQL "
-            "Shell");
-        output_handler.wipe_all();
-      }
     } catch (const shcore::Exception &e) {
       std::string error = "Unexpected failure calling validate_session: ";
       error += e.what();
@@ -212,7 +199,8 @@ TEST_F(Preconditions, check_session) {
   }
 }
 
-TEST_F(Preconditions, check_instance_configuration_preconditions_errors) {
+TEST_F(Admin_api_preconditions,
+       check_instance_configuration_preconditions_errors) {
   struct Invalid_types {
     mysqlsh::dba::TargetType::Type instance_type;
     int allowed_types;
@@ -293,7 +281,7 @@ TEST_F(Preconditions, check_instance_configuration_preconditions_errors) {
   }
 }
 
-TEST_F(Preconditions, check_managed_instance_status_preconditions) {
+TEST_F(Admin_api_preconditions, check_managed_instance_status_preconditions) {
   struct Invalid_states {
     mysqlsh::dba::TargetType::Type instance_type;
     mysqlsh::dba::ReplicationQuorum::State instance_quorum_state;
@@ -384,7 +372,7 @@ TEST_F(Preconditions, check_managed_instance_status_preconditions) {
   }
 }
 
-TEST_F(Preconditions, check_quorum_state_preconditions_errors) {
+TEST_F(Admin_api_preconditions, check_quorum_state_preconditions_errors) {
   struct Invalid_states {
     mysqlsh::dba::ReplicationQuorum::State instance_state;
     mysqlsh::dba::ReplicationQuorum::State allowed_states;
@@ -434,7 +422,7 @@ TEST_F(Preconditions, check_quorum_state_preconditions_errors) {
   }
 }
 
-TEST_F(Preconditions, check_quorum_state_preconditions) {
+TEST_F(Admin_api_preconditions, check_quorum_state_preconditions) {
   std::vector<mysqlsh::dba::ReplicationQuorum::State> quorum_states{
       mysqlsh::dba::ReplicationQuorum::State(
           mysqlsh::dba::ReplicationQuorum::States::Normal),
@@ -460,7 +448,7 @@ TEST_F(Preconditions, check_quorum_state_preconditions) {
   }
 }
 
-TEST_F(Preconditions, check_cluster_set_preconditions_errors) {
+TEST_F(Admin_api_preconditions, check_cluster_set_preconditions_errors) {
   struct Invalid_states {
     mysqlsh::dba::Cluster_global_status_mask allowed_states;
     std::string error;
@@ -513,7 +501,7 @@ TEST_F(Preconditions, check_cluster_set_preconditions_errors) {
       mysqlsh::dba::Precondition_checker::kClusterGlobalStateAny));
 }
 
-TEST_F(Preconditions, check_cluster_set_preconditions) {
+TEST_F(Admin_api_preconditions, check_cluster_set_preconditions) {
   std::vector<std::pair<mysqlsh::dba::Cluster_global_status,
                         mysqlsh::dba::Cluster_availability>>
       global_cluster_states{
@@ -537,36 +525,37 @@ TEST_F(Preconditions, check_cluster_set_preconditions) {
       "Cluster.unfenceWrites",        "ClusterSet.createReplicaCluster",
       "ClusterSet.listRouters",       "ClusterSet.options",
       "ClusterSet.removeCluster",     "ClusterSet.routingOptions",
-      "ClusterSet.setOption",         "ClusterSet.setRoutingOption",
-      "ClusterSet.setupAdminAccount", "ClusterSet.setupRouterAccount"};
+      "ClusterSet.routerOptions",     "ClusterSet.setOption",
+      "ClusterSet.setRoutingOption",  "ClusterSet.setupAdminAccount",
+      "ClusterSet.setupRouterAccount"};
 
   std::set<std::string> cset_offline_expected = {
-      "ClusterSet.describe",      "ClusterSet.forcePrimaryCluster",
-      "ClusterSet.rejoinCluster", "ClusterSet.setPrimaryCluster",
-      "ClusterSet.status",        "Dba.checkInstanceConfiguration",
-      "Dba.configureInstance",    "Dba.configureLocalInstance",
-      "Dba.getClusterSet",        "Dba.rebootClusterFromCompleteOutage"};
+      "ClusterSet.describe",
+      "ClusterSet.forcePrimaryCluster",
+      "ClusterSet.rejoinCluster",
+      "ClusterSet.setPrimaryCluster",
+      "ClusterSet.status",
+      "Dba.checkInstanceConfiguration",
+      "Dba.configureInstance",
+      "Dba.getClusterSet",
+      "Dba.rebootClusterFromCompleteOutage"};
 
   std::set<std::string> standalone_cluster_exclusive_expected = {
       "Cluster.createClusterSet", "Cluster.switchToMultiPrimaryMode",
       "Cluster.switchToSinglePrimaryMode"};
 
   std::set<std::string> cset_always_allowed_expected = {
-      "Cluster.checkInstanceState",
-      "Cluster.describe",
-      "Cluster.forceQuorumUsingPartitionOf",
-      "Cluster.listRouters",
-      "Cluster.setPrimaryInstance",
-      "Cluster.options",
-      "Cluster.status",
-      "Cluster.dissolve",
-      "Dba.getCluster",
-      "Dba.upgradeMetadata",
-      "Dba.dropMetadataSchema",
+      "Cluster.describe",       "Cluster.forceQuorumUsingPartitionOf",
+      "Cluster.listRouters",    "Cluster.setPrimaryInstance",
+      "Cluster.options",        "Cluster.routingOptions",
+      "Cluster.routerOptions",  "Cluster.status",
+      "Cluster.dissolve",       "Dba.getCluster",
+      "Dba.upgradeMetadata",    "Dba.dropMetadataSchema",
       "Cluster.fenceAllTraffic"};
 
   std::set<std::string> cset_sometimes_allowed_expected = {
       "Cluster.addInstance",
+      "Cluster.addReplicaInstance",
       "Cluster.rejoinInstance",
       "Cluster.removeInstance",
       "Cluster.removeRouterMetadata",
@@ -574,6 +563,7 @@ TEST_F(Preconditions, check_cluster_set_preconditions) {
       "Cluster.resetRecoveryAccountsPassword",
       "Cluster.setInstanceOption",
       "Cluster.setOption",
+      "Cluster.setRoutingOption",
       "Cluster.setupAdminAccount",
       "Cluster.setupRouterAccount"};
 
@@ -630,7 +620,7 @@ TEST_F(Preconditions, check_cluster_set_preconditions) {
       cset_sometimes_allowed.insert(precondition.first);
       for (const auto &global_state : global_cluster_states) {
         EXPECT_CALL(checker, get_cluster_global_state())
-            .WillOnce(Return(global_state));
+            .WillRepeatedly(Return(global_state));
         if (precondition.second.cluster_set_state.is_set(global_state.first)) {
           EXPECT_NO_THROW(checker.check_cluster_set_preconditions(
               precondition.second.cluster_set_state));
@@ -649,7 +639,7 @@ TEST_F(Preconditions, check_cluster_set_preconditions) {
   EXPECT_EQ(cset_sometimes_allowed_expected, cset_sometimes_allowed);
 }
 
-TEST_F(Preconditions, check_cluster_fenced_preconditions) {
+TEST_F(Admin_api_preconditions, check_cluster_fenced_preconditions) {
   struct Invalid_states {
     bool allowed_on_fenced;
     std::string error;
