@@ -33,6 +33,7 @@ namespace tests {
 
 class Api_connections : public Shell_js_script_tester {
  public:
+  using Version = mysqlshdk::utils::Version;
   virtual void SetUp() {
     if (_sb_port == 0) FAIL() << "No MySQL Server available for test.";
 
@@ -60,9 +61,14 @@ class Api_connections : public Shell_js_script_tester {
     execute("var __sandbox_dir = testutil.getSandboxPath();");
     execute("var __my_user = 'root';");
 
-    auto tls1_2 = mysqlshdk::utils::Version("1.2");
+    Version tls1_2(1, 2);
     if (_highest_tls_version > tls1_2) {
-      execute("var __default_cipher = 'TLS_AES_256_GCM_SHA384';");
+      if (_target_server_version >= Version(8, 3, 0) ||
+          (_target_server_version < Version(8, 1) &&
+           _target_server_version >= Version(8, 0, 27)))
+        execute("var __default_cipher = 'TLS_AES_128_GCM_SHA256';");
+      else
+        execute("var __default_cipher = 'TLS_AES_256_GCM_SHA384';");
     } else if (_highest_tls_version == tls1_2) {
       execute("var __default_cipher = 'DHE-RSA-AES128-GCM-SHA256';");
     } else {
@@ -106,8 +112,8 @@ class Api_connections : public Shell_js_script_tester {
   void disable_ssl_on_instance(int port, const std::string &unsecure_user) {
     auto session = mysqlshdk::db::mysql::Session::create();
 
-    auto connection_options = shcore::get_connection_options(
-        "root:root@localhost:" + std::to_string(port), false);
+    auto connection_options = mysqlshdk::db::Connection_options(
+        "root:root@localhost:" + std::to_string(port));
     session->connect(connection_options);
 
     session->query("create user " + unsecure_user +
@@ -158,6 +164,10 @@ TEST_F(Api_connections, ssl_enabled_require_secure_transport_on) {
 }
 
 TEST_F(Api_connections, ssl_disabled) {
+  if (!Shell_test_env::check_max_version_skip_test(
+          true, mysqlshdk::utils::Version(8, 3, 0)))
+    return;
+
   disable_ssl_on_instance(_sb_port, "unsecure");
 
   execute("var secure_transport='disabled';");
