@@ -23,6 +23,8 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#ifdef USE_MYSQLX_FULL_PROTO
+
 #include <gtest/gtest_prod.h>
 #include <cstdio>
 #include "src/mysqlsh/cmdline_shell.h"
@@ -34,7 +36,7 @@
 namespace tests {
 class Table_select : public Shell_core_test_wrapper {
  protected:
-#ifdef HAVE_V8
+#ifdef HAVE_JS
   const std::string start_txn_stmt = "session.startTransaction();";
   const std::string lock_shared_fn = "lockShared";
   const std::string lock_exclusive_fn = "lockExclusive";
@@ -60,7 +62,7 @@ class Table_select : public Shell_core_test_wrapper {
     // Connects the two shell instances to be used on these tests
     execute("\\connect --mx " + _uri);
 
-#ifdef HAVE_V8
+#ifdef HAVE_JS
     execute("var schema = session.getSchema('test_locking');");
     execute("var table = schema.getTable('test_table');");
 #else
@@ -83,23 +85,22 @@ class Table_select : public Shell_core_test_wrapper {
 
   static void SetUpTestCase() {
     tests::Shell_test_wrapper global_shell;
+    global_shell.execute("\\js");
     global_shell.execute("\\connect --mx " + shell_test_server_uri('x'));
 
     // preparation
     global_shell.execute(
         "session.sql('drop schema if exists test_locking').execute();");
-#ifdef HAVE_V8
+#ifdef HAVE_JS
     global_shell.execute("var schema = session.createSchema('test_locking');");
 #else
     global_shell.execute("schema = session.create_schema('test_locking');");
 #endif
 
-    // global_shell.execute("\\sql");
     global_shell.execute(
         "session.sql('create table test_locking.test_table (_id int "
         "primary key, name varchar(10))').execute();");
-    // global_shell.execute("\\js");
-#ifdef HAVE_V8
+#ifdef HAVE_JS
     global_shell.execute("var table = schema.getTable('test_table');");
 #else
     global_shell.execute("table = schema.get_table('test_table');");
@@ -116,8 +117,13 @@ class Table_select : public Shell_core_test_wrapper {
   static void TearDownTestCase() {
     tests::Shell_test_wrapper global_shell;
     global_shell.execute("\\connect --mx " + shell_test_server_uri('x'));
-
+#ifdef HAVE_JS
+    global_shell.execute("\\js");
     global_shell.execute("session.dropSchema('test_locking');");
+#else
+    global_shell.execute("\\py");
+    global_shell.execute("session.drop_schema('test_locking')");
+#endif
     global_shell.execute("session.close();");
   }
 
@@ -599,3 +605,5 @@ TEST_F(Table_select, lock_exclusive_skip_lock_constant) {
 }
 
 }  // namespace tests
+
+#endif
