@@ -23,7 +23,7 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-//#include <gtest/gtest.h>
+// #include <gtest/gtest.h>
 #include <memory>
 
 #include "mysqlshdk/include/scripting/types.h"
@@ -43,7 +43,7 @@ class Lock_service_test : public tests::Shell_base_test {
     tests::Shell_base_test::SetUp();
 
     // Create instance and Open the session for the tests.
-    _connection_options = shcore::get_connection_options(_mysql_uri);
+    _connection_options = mysqlshdk::db::Connection_options(_mysql_uri);
     _session->connect(_connection_options);
     instance = new mysqlshdk::mysql::Instance(_session);
 
@@ -75,6 +75,8 @@ class Lock_service_test : public tests::Shell_base_test {
 };
 
 TEST_F(Lock_service_test, install_udfs) {
+  if (!Shell_test_env::check_min_version_skip_test()) return;
+
   if (mysqlshdk::mysql::has_lock_service(*instance)) {
     // NOTE: Error issued when trying to install UDFs that already exist.
     SKIP_TEST("Lock service UDFs already installed on test server.");
@@ -103,6 +105,8 @@ TEST_F(Lock_service_test, install_udfs) {
 }
 
 TEST_F(Lock_service_test, lock_erros) {
+  if (!Shell_test_env::check_min_version_skip_test()) return;
+
   using mysqlshdk::mysql::Lock_mode;
 
   // Name space and lock name cannot be empty.
@@ -145,6 +149,8 @@ TEST_F(Lock_service_test, lock_erros) {
 }
 
 TEST_F(Lock_service_test, locks_usage) {
+  if (!Shell_test_env::check_min_version_skip_test()) return;
+
   using mysqlshdk::mysql::Lock_mode;
 
   // Enable metadata lock instruments to allow lock monitoring.
@@ -235,6 +241,8 @@ TEST_F(Lock_service_test, locks_usage) {
 }
 
 TEST_F(Lock_service_test, uninstall_udfs) {
+  if (!Shell_test_env::check_min_version_skip_test()) return;
+
   EXPECT_NO_THROW(mysqlshdk::mysql::uninstall_lock_service(instance));
   EXPECT_FALSE(mysqlshdk::mysql::has_lock_service(*instance));
 }
@@ -265,17 +273,16 @@ TEST_F(Lock_service_test, has_lock_service_udfs) {
 
     // Set the lib extension according to the OS.
     std::string instance_os = shcore::str_upper(os);
-    std::string ext =
-        (instance_os.find("WIN") != std::string::npos) ? ".dll" : ".so";
+    auto ext = (instance_os.find("WIN") != std::string::npos) ? "dll" : "so";
 
     // Query to verify existence of lock service UDFs.
-    std::string str_query =
-        "SELECT COUNT(*) FROM mysql.func "
-        "WHERE dl = /*(*/ 'locking_service" +
-        ext +
-        "' /*(*/ "
-        "AND name IN ('service_get_read_locks', 'service_get_write_locks', "
-        "'service_release_locks')";
+    auto str_query = shcore::str_format(
+        "SELECT count(*) FROM performance_schema.user_defined_functions WHERE "
+        "(udf_library = 'locking_service.%s') AND (udf_name IN "
+        "('service_get_read_locks', 'service_get_write_locks', "
+        "'service_release_locks'))",
+        ext);
+
     mock_session->expect_query(str_query).then_return(
         {{"",
           {"COUNT(*)"},
@@ -297,6 +304,33 @@ TEST_F(Lock_service_test, has_lock_service_udfs) {
   EXPECT_FALSE(test(2, "macOS"));
   EXPECT_TRUE(test(3, "macOS"));
   EXPECT_FALSE(test(4, "macOS"));
+
+  // 5.7 is no longer supported, so the locking_service checkers should not fail
+  // unexpectedly and compromise the precondition checkers
+  {
+    mock_session
+        ->expect_query(
+            "show GLOBAL variables where `variable_name` in "
+            "('version_compile_os')")
+        .then_return({{"",
+                       {"Variable_name", "Value"},
+                       {Type::String, Type::String},
+                       {{"version_compile_os", "Linux"}}}});
+
+    mock_session
+        ->expect_query(
+            "SELECT count(*) FROM performance_schema.user_defined_functions "
+            "WHERE (udf_library = 'locking_service.so') AND (udf_name IN "
+            "('service_get_read_locks', 'service_get_write_locks', "
+            "'service_release_locks'))")
+        .then_throw(
+            "Table 'performance_schema.user_defined_functions' doesn't exist",
+            1146, "42S02");
+
+    mysqlshdk::mysql::Instance mock_instance{mock_session};
+
+    EXPECT_FALSE(mysqlshdk::mysql::has_lock_service(mock_instance));
+  }
 }
 
 }  // namespace testing
