@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2015, 2022, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -36,6 +38,17 @@
 #include "my_config.h"
 
 namespace shcore {
+TEST(utils_general, compare_floating_point) {
+  EXPECT_TRUE(compare_floating_point(12.3, 12.3, 0.01));
+  EXPECT_TRUE(compare_floating_point(-12.3, -12.3, 0.01));
+  EXPECT_FALSE(compare_floating_point(12.3, -12.3, 0.01));
+  EXPECT_FALSE(compare_floating_point(-12.3, 12.3, 0.01));
+
+  EXPECT_TRUE(compare_floating_point(12.345, 12.346, 0.01));
+  EXPECT_TRUE(compare_floating_point(12.345, 12.346, 0.001));
+  EXPECT_FALSE(compare_floating_point(12.345, 12.346, 0.0009));
+}
+
 TEST(utils_general, split_account) {
   std::string a, b;
 
@@ -501,6 +514,7 @@ TEST(utils_general, match_glob) {
   EXPECT_TRUE(match_glob("\\", "\\"));
   EXPECT_FALSE(match_glob("\\", "x"));
   EXPECT_TRUE(match_glob("\\opti*", "\\option"));
+  EXPECT_TRUE(match_glob("\\\\opti*", "\\option"));
   EXPECT_FALSE(match_glob("\\opti\\*", "\\option"));
   EXPECT_TRUE(match_glob("*\\*", "abcdefgh*"));
 
@@ -544,6 +558,39 @@ TEST(utils_general, match_glob) {
   EXPECT_TRUE(match_glob("*x", "xxx"));
 }
 
+TEST(utils_general, unescape_glob) {
+  EXPECT_EQ("", unescape_glob(""));
+
+  EXPECT_EQ(std::nullopt, unescape_glob("*"));
+  EXPECT_EQ(std::nullopt, unescape_glob("?"));
+  EXPECT_EQ("\\", unescape_glob("\\"));
+  EXPECT_EQ("a", unescape_glob("a"));
+
+  EXPECT_EQ(std::nullopt, unescape_glob("\\??"));
+  EXPECT_EQ(std::nullopt, unescape_glob("\\?*"));
+  EXPECT_EQ("?\\", unescape_glob("\\?\\"));
+  EXPECT_EQ("?\\", unescape_glob("\\?\\\\"));
+  EXPECT_EQ("?a", unescape_glob("\\?a"));
+  EXPECT_EQ("??", unescape_glob("\\?\\?"));
+  EXPECT_EQ("?*", unescape_glob("\\?\\*"));
+
+  EXPECT_EQ(std::nullopt, unescape_glob("\\*?"));
+  EXPECT_EQ(std::nullopt, unescape_glob("\\**"));
+  EXPECT_EQ("*\\", unescape_glob("\\*\\"));
+  EXPECT_EQ("*\\", unescape_glob("\\*\\\\"));
+  EXPECT_EQ("*a", unescape_glob("\\*a"));
+  EXPECT_EQ("*?", unescape_glob("\\*\\?"));
+  EXPECT_EQ("**", unescape_glob("\\*\\*"));
+
+  EXPECT_EQ("\\option", unescape_glob("\\option"));
+  EXPECT_EQ(std::nullopt, unescape_glob("\\optio*"));
+  EXPECT_EQ(std::nullopt, unescape_glob("\\optio?"));
+  EXPECT_EQ("\\optio?", unescape_glob("\\optio\\?"));
+  EXPECT_EQ("\\optio*", unescape_glob("\\optio\\*"));
+  EXPECT_EQ("\\optio\\", unescape_glob("\\optio\\"));
+  EXPECT_EQ("\\optio\\n", unescape_glob("\\optio\\n"));
+}
+
 TEST(utils_general, get_long_version) {
   if (*MYSH_BUILD_ID) {
     std::cout << "Verifying values for the build server" << std::endl;
