@@ -40,7 +40,6 @@ function print_metadata_instance_addresses(session) {
     print("\n");
 }
 
-
 //@<> init
 testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname});
 testutil.deploySandbox(__mysql_sandbox_port2, "root", {report_host: hostname});
@@ -50,13 +49,14 @@ testutil.snapshotSandboxConf(__mysql_sandbox_port2);
 shell.connect(__sandbox_uri1);
 
 // WL#12011: AdminAPI: Refactor dba.createCluster()
-//@<> WL#12011: FR2-04 - invalid value for interactive option.
-EXPECT_THROWS_TYPE(function() { dba.createCluster('test', {interactive: "not a valid type"}) }, "Argument #2: Option 'interactive' Bool expected, but value is String", "TypeError");
 
 //@<> WL#12011: FR2-01 - interactive = true.
-testutil.expectPrompt("Confirm [y/N]:", "n");
+shell.options.useWizards=1;
 
-EXPECT_THROWS_TYPE(function() { dba.createCluster('test', {interactive: true, multiPrimary: true}) }, "Cancelled", "RuntimeError");
+testutil.expectPrompt("Confirm [y/N]:", "n");
+EXPECT_THROWS_TYPE(function() { dba.createCluster('test', {multiPrimary: true}) }, "Cancelled", "RuntimeError");
+
+shell.options.useWizards=0;
 
 EXPECT_STDOUT_CONTAINS_MULTILINE(`A new InnoDB Cluster will be created on instance '${hostname}:${__mysql_sandbox_port1}'.
 
@@ -71,6 +71,8 @@ and limitations of advanced Multi-Primary Mode.
 `);
 
 //@<> WL#12011: FR2-03 - no interactive option (default: non-interactive).
+WIPE_SHELL_LOG();
+
 var c;
 EXPECT_NO_THROWS(function() { c = dba.createCluster('test', {multiPrimary: true, force: true}); });
 
@@ -86,9 +88,12 @@ This instance reports its own address as ${hostname}:${__mysql_sandbox_port1}
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '${hostname}:${__mysql_sandbox_gr_port1}'. Use the localAddress option to override.
 
+NOTE: The 'localAddress' "${hostname}" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+NOTE: When adding more instances to the Cluster, be aware that the subnet masks dictate whether the instance's address is automatically added to the allowlist or not. Please specify the 'ipAllowlist' accordingly if needed.
 * Checking connectivity and SSL configuration...
 
-WARNING: Instance '${hostname}:${__mysql_sandbox_port1}' cannot persist Group Replication configuration since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+WARNING: Instance '${hostname}:${__mysql_sandbox_port1}' cannot persist Group Replication configuration since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally to persist the changes.
 Creating InnoDB Cluster 'test' on '${hostname}:${__mysql_sandbox_port1}'...
 
 The MySQL InnoDB Cluster is going to be setup in advanced Multi-Primary Mode. Consult its requirements and limitations in https://dev.mysql.com/doc/refman/en/group-replication-limitations.html
@@ -108,6 +113,9 @@ This instance reports its own address as ${hostname}:${__mysql_sandbox_port1}
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '${hostname}:${__mysql_sandbox_gr_port1}'. Use the localAddress option to override.
 
+NOTE: The 'localAddress' "${hostname}" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+NOTE: When adding more instances to the Cluster, be aware that the subnet masks dictate whether the instance's address is automatically added to the allowlist or not. Please specify the 'ipAllowlist' accordingly if needed.
 * Checking connectivity and SSL configuration...
 
 Creating InnoDB Cluster 'test' on '${hostname}:${__mysql_sandbox_port1}'...
@@ -141,9 +149,76 @@ At least 3 instances are needed for the cluster to be able to withstand up to
 one server failure.`);
 }
 
-c.dissolve();
+// check that some vars don't have it's default values set
+if (__version_num >= 80002) {
+    EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_verify_server_cert': default value ('false') is the expected.");
+    EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_start_on_boot': default value ('true') is the expected.");
+}
+
+//@<> Check if dba.configureInstance() only sets vars that don't have it's default values {VER(<8.0.2)}
+WIPE_SHELL_LOG();
+
+EXPECT_NO_THROWS(function(){ dba.configureInstance(); });
+
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_allow_local_disjoint_gtids_join': default value ('OFF') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_bootstrap_group': default value ('OFF') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_components_stop_timeout': default value ('31536000') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_exit_state_action': default value ('READ_ONLY') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_flow_control_applier_threshold': default value ('25000') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_flow_control_certifier_threshold': default value ('25000') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_flow_control_mode': default value ('QUOTA') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_force_members': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_group_seeds': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_member_weight': default value ('50') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_poll_spin_loops': default value ('0') is the expected.");
+if (__version_num < 80400) {
+    EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_complete_at': default value ('TRANSACTIONS_APPLIED') is the expected.");
+}
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_reconnect_interval': default value ('60') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_retry_count': default value ('10') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_ca': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_capath': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_cert': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_cipher': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_crl': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_crlpath': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_key': default value ('') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_recovery_ssl_verify_server_cert': default value ('OFF') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_start_on_boot': default value ('ON') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_transaction_size_limit': default value ('150000000') is the expected.");
+EXPECT_SHELL_LOG_CONTAINS("Ignoring 'group_replication_unreachable_majority_timeout': default value ('0') is the expected.");
+
+// some vars (group_replication_group_seeds) are persisted in other places, by different reasons, so we can't check them
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_allow_local_disjoint_gtids_join"); }, "Option 'group_replication_allow_local_disjoint_gtids_join' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_bootstrap_group"); }, "Option 'group_replication_bootstrap_group' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_components_stop_timeout"); }, "Option 'group_replication_components_stop_timeout' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_exit_state_action"); }, "Option 'group_replication_exit_state_action' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_flow_control_applier_threshold"); }, "Option 'group_replication_flow_control_applier_threshold' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_flow_control_certifier_threshold"); }, "Option 'group_replication_flow_control_certifier_threshold' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_flow_control_mode"); }, "Option 'group_replication_flow_control_mode' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_force_members"); }, "Option 'group_replication_force_members' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_member_weight"); }, "Option 'group_replication_member_weight' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_poll_spin_loops"); }, "Option 'group_replication_poll_spin_loops' does not exist in group 'mysqld'");
+if (__version_num < 80400) {
+    EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_complete_at"); }, "Option 'group_replication_recovery_complete_at' does not exist in group 'mysqld'");
+}
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_reconnect_interval"); }, "Option 'group_replication_recovery_reconnect_interval' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_retry_count"); }, "Option 'group_replication_recovery_retry_count' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_ca"); }, "Option 'group_replication_recovery_ssl_ca' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_capath"); }, "Option 'group_replication_recovery_ssl_capath' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_cert"); }, "Option 'group_replication_recovery_ssl_cert' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_cipher"); }, "Option 'group_replication_recovery_ssl_cipher' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_crl"); }, "Option 'group_replication_recovery_ssl_crl' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_crlpath"); }, "Option 'group_replication_recovery_ssl_crlpath' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_key"); }, "Option 'group_replication_recovery_ssl_key' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_recovery_ssl_verify_server_cert"); }, "Option 'group_replication_recovery_ssl_verify_server_cert' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_start_on_boot"); }, "Option 'group_replication_start_on_boot' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_transaction_size_limit"); }, "Option 'group_replication_transaction_size_limit' does not exist in group 'mysqld'");
+EXPECT_THROWS(function(){ testutil.getSandboxConf(__mysql_sandbox_port1, "group_replication_unreachable_majority_timeout"); }, "Option 'group_replication_unreachable_majority_timeout' does not exist in group 'mysqld'");
 
 //@<> Create cluster without group_replication_start_on_boot
+reset_instance(session);
+
 session.runSql("set global group_replication_start_on_boot=1");
 var start_on_boot = session.runSql("select @@group_replication_start_on_boot").fetchOne()[0];
 EXPECT_EQ(1, start_on_boot);
@@ -167,18 +242,28 @@ c.dissolve();
 //@<> check error log dumping on create if supported {VER(>=8.0.22)}
 
 // force GR start to fail by passing an invalid localAddress
-EXPECT_THROWS(function(){dba.createCluster("test", {communicationStack: "XCOM", localAddress:"0.0.0.0:1"})}, "Group Replication failed to start:");
+EXPECT_THROWS(function(){
+    dba.createCluster("test", {communicationStack: "XCOM", localAddress:"0.0.0.0:1"});
+}, "The 'localAddress' isn't compatible with the Group Replication automatically generated list of allowed IPs.");
 
-EXPECT_OUTPUT_CONTAINS("The MySQL error_log contains the following messages:");
-EXPECT_OUTPUT_CONTAINS("Plugin group_replication reported: '[GCS] There is no local IP address matching the one configured for the local node");
+EXPECT_OUTPUT_CONTAINS(`The 'localAddress' "0.0.0.0" isn't compatible with the Group Replication automatically generated list of allowed IPs.`);
+if (__os_type != 'windows') {
+    EXPECT_OUTPUT_CONTAINS("In this scenario, it's necessary to explicitly use the 'ipAllowlist' option to manually specify the list of allowed IPs.");
+}
+EXPECT_OUTPUT_CONTAINS("See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.");
 
 //@<> check error log dumping on add if supported {VER(>=8.0.22)}
 var c = dba.createCluster("test", {communicationStack: "XCOM"});
 
-EXPECT_THROWS(function(){c.addInstance(__sandbox_uri2, {localAddress:"0.0.0.0:1", recoveryMethod:"incremental"})}, "Group Replication failed to start:");
+EXPECT_THROWS(function(){
+    c.addInstance(__sandbox_uri2, {localAddress:"0.0.0.0:1", recoveryMethod:"incremental"});
+}, "The 'localAddress' isn't compatible with the Group Replication automatically generated list of allowed IPs.");
 
-EXPECT_OUTPUT_CONTAINS("The MySQL error_log contains the following messages:");
-EXPECT_OUTPUT_CONTAINS("Plugin group_replication reported: '[GCS] There is no local IP address matching the one configured for the local node");
+EXPECT_OUTPUT_CONTAINS(`The 'localAddress' "0.0.0.0" isn't compatible with the Group Replication automatically generated list of allowed IPs.`);
+if (__os_type != 'windows') {
+    EXPECT_OUTPUT_CONTAINS("In this scenario, it's necessary to explicitly use the 'ipAllowlist' option to manually specify the list of allowed IPs.");
+}
+EXPECT_OUTPUT_CONTAINS("See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.");
 
 //@<> WL#12011: Finalization.
 c.disconnect();
@@ -209,10 +294,7 @@ testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname});
 
 shell.connect(__sandbox_uri1);
 
-//@ WL#12049: Unsupported server version {VER(<5.7.24)}
-var c = dba.createCluster('test', {exitStateAction: "READ_ONLY", gtidSetIsComplete: true});
-
-//@ WL#12049: Create cluster errors using exitStateAction option {VER(>=5.7.24)}
+//@ WL#12049: Create cluster errors using exitStateAction option
 // F1.2 - The exitStateAction option shall be a string value.
 // NOTE: GR validates the value, which is an Enumerator, and accepts the values
 // `ABORT_SERVER` or `READ_ONLY`, or 1 or 0.
@@ -226,62 +308,62 @@ var c = dba.createCluster('test', {exitStateAction: "AB"});
 
 var c = dba.createCluster('test', {exitStateAction: "10"});
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (ABORT_SERVER) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (ABORT_SERVER)
 var c = dba.createCluster('test', {exitStateAction: "ABORT_SERVER"});
 
-//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (ABORT_SERVER) {VER(>=5.7.24)}
+//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (ABORT_SERVER)
 // F1.1 - If the exitStateAction option is given, the
 // group_replication_exit_state_action variable is set to the value given by the
 // user.
 EXPECT_EQ("ABORT_SERVER", get_sysvar(session, "group_replication_exit_state_action"));
 
-//@<> group_replication_view_change_uuid must not be set for Clusters running versions < 8.0.27 {VER(<8.0.27)}
+//@<> group_replication_view_change_uuid must not be set for Clusters running versions < 8.0.27 || >= 8.3.0 {VER(<8.0.27) || VER(>=8.3.0)}
 var view_change_uuid_md = session.runSql("select (attributes->>'$.group_replication_view_change_uuid') from mysql_innodb_cluster_metadata.clusters where cluster_name='newcluster'").fetchOne();
 EXPECT_EQ(null, view_change_uuid_md);
 
-//@ WL#12049: Dissolve cluster 1 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 1
 c.dissolve({force: true});
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (READ_ONLY) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (READ_ONLY)
 // NOTE: the server is in super-read-only since it was dissolved so we must
 // disable it
-var c = dba.createCluster('test', {clearReadOnly: true, exitStateAction: "READ_ONLY"});
+var c = dba.createCluster('test', {exitStateAction: "READ_ONLY"});
 
-//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (READ_ONLY) {VER(>=5.7.24)}
+//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (READ_ONLY)
 // F1.1 - If the exitStateAction option is given, the
 // group_replication_exit_state_action variable is set to the value given by the
 // user.
 EXPECT_EQ("READ_ONLY", get_sysvar(session, "group_replication_exit_state_action"));
 
-//@ WL#12049: Dissolve cluster 2 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 2
 c.dissolve({force: true});
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (1) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (1)
 // NOTE: the server is in super-read-only since it was dissolved so we must
 // disable it
-var c = dba.createCluster('test', {clearReadOnly: true, exitStateAction: "1"});
+var c = dba.createCluster('test', {exitStateAction: "1"});
 
-//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (1) {VER(>=5.7.24)}
+//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (1)
 // F1.1 - If the exitStateAction option is given, the
 // group_replication_exit_state_action variable is set to the value given by the
 // user.
 EXPECT_EQ("ABORT_SERVER", get_sysvar(session, "group_replication_exit_state_action"));
 
-//@ WL#12049: Dissolve cluster 3 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 3
 c.dissolve({force: true});
 
-//@ WL#12049: Create cluster specifying a valid value for exitStateAction (0) {VER(>=5.7.24)}
+//@ WL#12049: Create cluster specifying a valid value for exitStateAction (0)
 // NOTE: the server is in super-read-only since it was dissolved so we must
 // disable it
-var c = dba.createCluster('test', {clearReadOnly: true, exitStateAction: "0"});
+var c = dba.createCluster('test', {exitStateAction: "0"});
 
-//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (0) {VER(>=5.7.24)}
+//@<> WL#12049: Confirm group_replication_exit_state_action is set correctly (0)
 // F1.1 - If the exitStateAction option is given, the
 // group_replication_exit_state_action variable is set to the value given by the
 // user.
 EXPECT_EQ("READ_ONLY", get_sysvar(session, "group_replication_exit_state_action"));
 
-//@ WL#12049: Dissolve cluster 4 {VER(>=5.7.24)}
+//@ WL#12049: Dissolve cluster 4
 c.dissolve({force: true});
 
 // Verify if exitStateAction is persisted on >= 8.0.12
@@ -292,7 +374,7 @@ c.dissolve({force: true});
 // the target instance, if the MySQL Server instance version is >= 8.0.12.
 
 //@ WL#12049: Create cluster {VER(>=8.0.12)}
-var c = dba.createCluster('test', {clearReadOnly: true, groupName: "ca94447b-e6fc-11e7-b69d-4485005154dc", exitStateAction: "READ_ONLY"});
+var c = dba.createCluster('test', {groupName: "ca94447b-e6fc-11e7-b69d-4485005154dc", exitStateAction: "READ_ONLY"});
 
 //@<OUT> WL#12049: exitStateAction must be persisted on mysql >= 8.0.12 {VER(>=8.0.12)}
 print(get_persisted_gr_sysvars(__mysql_sandbox_port1));
@@ -347,10 +429,7 @@ testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname});
 
 shell.connect(__sandbox_uri1);
 
-//@ WL#11032: Unsupported server version {VER(<5.7.20)}
-var c = dba.createCluster('test', {memberWeight: 25});
-
-//@ WL#11032: Create cluster errors using memberWeight option {VER(>=5.7.20)}
+//@ WL#11032: Create cluster errors using memberWeight option
 // F1.2 - The memberWeight option shall be an integer value.
 var c = dba.createCluster('test', {memberWeight: ""});
 
@@ -360,44 +439,44 @@ var c = dba.createCluster('test', {memberWeight: "AB"});
 
 var c = dba.createCluster('test', {memberWeight: 10.5});
 
-//@ WL#11032: Create cluster specifying a valid value for memberWeight (25) {VER(>=5.7.20)}
+//@ WL#11032: Create cluster specifying a valid value for memberWeight (25)
 var c = dba.createCluster('test', {memberWeight: 25});
 
-//@<> WL#11032: Confirm group_replication_member_weight is set correctly (25) {VER(>=5.7.20)}
+//@<> WL#11032: Confirm group_replication_member_weight is set correctly (25)
 // F1.1 - If the memberWeight option is given, the
 // group_replication_member_weight variable is set to the value given by the
 // user.
 EXPECT_EQ(25, get_sysvar(session, "group_replication_member_weight"));
 
-//@ WL#11032: Dissolve cluster 1 {VER(>=5.7.20)}
+//@ WL#11032: Dissolve cluster 1
 c.dissolve({force: true});
 
-//@ WL#11032: Create cluster specifying a valid value for memberWeight (100) {VER(>=5.7.20)}
+//@ WL#11032: Create cluster specifying a valid value for memberWeight (100)
 // NOTE: the server is in super-read-only since it was dissolved so we must
 // disable it
-var c = dba.createCluster('test', {clearReadOnly: true, memberWeight: 100});
+var c = dba.createCluster('test', {memberWeight: 100});
 
-//@<> WL#11032: Confirm group_replication_member_weight is set correctly (100) {VER(>=5.7.20)}
+//@<> WL#11032: Confirm group_replication_member_weight is set correctly (100)
 // F1.1 - If the memberWeight option is given, the
 // group_replication_member_weight variable is set to the value given by the
 // user.
 EXPECT_EQ(100, get_sysvar(session, "group_replication_member_weight"));
 
-//@ WL#11032: Dissolve cluster 2 {VER(>=5.7.20)}
+//@ WL#11032: Dissolve cluster 2
 c.dissolve({force: true});
 
-//@ WL#11032: Create cluster specifying a valid value for memberWeight (-50) {VER(>=5.7.20)}
+//@ WL#11032: Create cluster specifying a valid value for memberWeight (-50)
 // NOTE: the server is in super-read-only since it was dissolved so we must
 // disable it
-var c = dba.createCluster('test', {clearReadOnly: true, memberWeight: -50});
+var c = dba.createCluster('test', {memberWeight: -50});
 
-//@<> WL#11032: Confirm group_replication_member_weight is set correctly (0) {VER(>=5.7.20)}
+//@<> WL#11032: Confirm group_replication_member_weight is set correctly (0)
 // F1.1 - If the memberWeight option is given, the
 // group_replication_member_weight variable is set to the value given by the
 // user.
 EXPECT_EQ(0, get_sysvar(session, "group_replication_member_weight"));
 
-//@ WL#11032: Dissolve cluster 3 {VER(>=5.7.20)}
+//@ WL#11032: Dissolve cluster 3
 c.dissolve({force: true});
 
 // Verify if memberWeight is persisted on >= 8.0.11
@@ -408,7 +487,7 @@ c.dissolve({force: true});
 // the target instance, if the MySQL Server instance version is >= 8.0.11.
 
 //@ WL#11032: Create cluster {VER(>=8.0.11)}
-var c = dba.createCluster('test', {clearReadOnly: true, groupName: "ca94447b-e6fc-11e7-b69d-4485005154dc", memberWeight: 75});
+var c = dba.createCluster('test', {groupName: "ca94447b-e6fc-11e7-b69d-4485005154dc", memberWeight: 75});
 
 //@<OUT> WL#11032: memberWeight must be persisted on mysql >= 8.0.11 {VER(>=8.0.11)}
 print(get_persisted_gr_sysvars(__mysql_sandbox_port1));
@@ -475,8 +554,6 @@ var c = dba.createCluster('test', {consistency: "10"});
 
 var c = dba.createCluster('test', {consistency: 1});
 
-var c = dba.createCluster('test', {consistency: "1", failoverConsistency: "1"});
-
 //@ WL#12067: TSF1_1 Create cluster using BEFORE_ON_PRIMARY_FAILOVER as value for consistency {VER(>=8.0.14)}
 var c = dba.createCluster('test', {consistency: "BEFORE_ON_PRIMARY_FAILOVER"});
 
@@ -491,7 +568,7 @@ c.dissolve({force: true});
 
 //@ WL#12067: TSF1_2 Create cluster using EVENTUAL as value for consistency {VER(>=8.0.14)}
 // NOTE: the server is in super-read-only since it was dissolved so we must disable it
-var c = dba.createCluster('test', {clearReadOnly:true, consistency: "EVENTUAL"});
+var c = dba.createCluster('test', {consistency: "EVENTUAL"});
 
 //@<> WL#12067: TSF1_2 Confirm group_replication_consistency is set correctly (EVENTUAL) {VER(>=8.0.14)}
 EXPECT_EQ("EVENTUAL", get_sysvar(session, "group_replication_consistency"));
@@ -503,7 +580,7 @@ EXPECT_EQ("EVENTUAL", get_sysvar(session, "group_replication_consistency", "PERS
 c.dissolve({force: true});
 
 //@ WL#12067: TSF1_1 Create cluster using 1 as value for consistency {VER(>=8.0.14)}
-var c = dba.createCluster('test', {clearReadOnly:true, consistency: "1"});
+var c = dba.createCluster('test', {consistency: "1"});
 
 //@<> WL#12067: TSF1_1 Confirm group_replication_consistency is set correctly (1) {VER(>=8.0.14)}
 EXPECT_EQ("BEFORE_ON_PRIMARY_FAILOVER", get_sysvar(session, "group_replication_consistency"));
@@ -513,7 +590,7 @@ c.dissolve({force: true});
 
 //@ WL#12067: TSF1_2 Create cluster using 0 as value for consistency {VER(>=8.0.14)}
 // NOTE: the server is in super-read-only since it was dissolved so we must disable it
-var c = dba.createCluster('test', {clearReadOnly:true, consistency: "0"});
+var c = dba.createCluster('test', {consistency: "0"});
 
 //@<> WL#12067: TSF1_2 Confirm group_replication_consistency is set correctly (0) {VER(>=8.0.14)}
 EXPECT_EQ("EVENTUAL", get_sysvar(session, "group_replication_consistency"));
@@ -523,7 +600,7 @@ c.dissolve({force: true});
 
 //@ WL#12067: TSF1_3 Create cluster using no value for consistency {VER(>=8.0.14)}
 // NOTE: the server is in super-read-only since it was dissolved so we must disable it
-var c = dba.createCluster('test', {clearReadOnly:true});
+var c = dba.createCluster('test');
 
 //@<> WL#12067: TSF1_3 Confirm without consistency group_replication_consistency is set to default (EVENTUAL) {VER(>=8.0.14)}
 EXPECT_EQ("EVENTUAL", get_sysvar(session, "group_replication_consistency"));
@@ -533,7 +610,7 @@ c.dissolve({force: true});
 
 //@ WL#12067: TSF1_7 Create cluster using evenTual as value for consistency throws no exception (case insensitive) {VER(>=8.0.14)}
 // NOTE: the server is in super-read-only since it was dissolved so we must disable it
-var c = dba.createCluster('test', {clearReadOnly:true, consistency: "EvenTual"});
+var c = dba.createCluster('test', {consistency: "EvenTual"});
 
 //@<> WL#12067: TSF1_7 Confirm group_replication_consistency is set correctly (EVENTUAL) {VER(>=8.0.14)}
 EXPECT_EQ("EVENTUAL", get_sysvar(session, "group_replication_consistency"));
@@ -543,7 +620,7 @@ c.dissolve({force: true});
 
 //@ WL#12067: TSF1_8 Create cluster using Before_ON_PriMary_FailoveR as value for consistency throws no exception (case insensitive) {VER(>=8.0.14)}
 // NOTE: the server is in super-read-only since it was dissolved so we must disable it
-var c = dba.createCluster('test', {clearReadOnly:true, consistency: "Before_ON_PriMary_FailoveR"});
+var c = dba.createCluster('test', {consistency: "Before_ON_PriMary_FailoveR"});
 
 //@<> WL#12067: TSF1_8 Confirm group_replication_consistency is set correctly (BEFORE_ON_PRIMARY_FAILOVER) {VER(>=8.0.14)}
 EXPECT_EQ("BEFORE_ON_PRIMARY_FAILOVER", get_sysvar(session, "group_replication_consistency"));
@@ -618,7 +695,7 @@ shell.connect(__sandbox_uri1);
 
 //@ WL#12050: TSF1_2 Create cluster using no value for expelTimeout, confirm it has the default value {VER(>=8.0.13)}
 // NOTE: the server is in super-read-only since it was dissolved so we must disable it
-var c = dba.createCluster('test', {clearReadOnly:true});
+var c = dba.createCluster('test');
 c.disconnect();
 
 //@<> WL#12050: TSF1_2 Confirm group_replication_member_expel_timeout is set correctly (0) {VER(>=8.0.13)}
@@ -709,7 +786,7 @@ var c = dba.createCluster('test', {autoRejoinTries: 2017});
 var c = dba.createCluster('test', {autoRejoinTries: 2016});
 session.close();
 shell.connect(__sandbox_uri2);
-var c2 = dba.createCluster('test2', {clearReadOnly: true});
+var c2 = dba.createCluster('test2');
 session.close();
 
 //@<> WL#12066: TSF1_3, TSF1_6 Validate that when calling the functions [dba.]createCluster() and [cluster.]addInstance(), the GR variable group_replication_autorejoin_tries is persisted with the value given by the user on the target instance.{VER(>=8.0.16)}
@@ -737,9 +814,16 @@ testutil.destroySandbox(__mysql_sandbox_port1);
 // Force a failure of the create_cluster function after the replication-user was created
 //@<> BUG#29308037: Create cluster using an invalid localAddress
 shell.connect(__sandbox_uri2);
-EXPECT_THROWS(function() {
-        dba.createCluster('test', {localAddress: '1a', clearReadOnly: true});
+if (__version_num < 80027) {
+    EXPECT_THROWS(function() {
+        dba.createCluster('test', {localAddress: '1a'});
+    }, "The 'localAddress' isn't compatible with the Group Replication automatically generated list of allowed IPs.");
+}
+else {
+    EXPECT_THROWS(function() {
+        dba.createCluster('test', {localAddress: '1a'});
     }, "Server address configuration error");
+}
 
 
 //@<OUT> BUG#29308037: Confirm that all replication users where removed
@@ -779,14 +863,15 @@ session.runSql("GRANT REPLICATION SLAVE ON *.* TO 'repl'@'%';");
 session.close();
 shell.connect(__sandbox_uri2);
 
-session.runSql("CHANGE MASTER TO MASTER_HOST='" + hostname + "', MASTER_PORT=" + __mysql_sandbox_port1 + ", MASTER_USER='repl', MASTER_PASSWORD='password', MASTER_AUTO_POSITION=1, MASTER_SSL=1");
-session.runSql("START SLAVE");
+session.runSql("change " + get_replication_source_keyword() + " TO " + get_replication_option_keyword() + "_HOST='" + hostname + "', " + get_replication_option_keyword() + "_PORT=" + __mysql_sandbox_port1 + ", " + get_replication_option_keyword() + "_USER='repl', " + get_replication_option_keyword() + "_PASSWORD='password', " + get_replication_option_keyword() + "_AUTO_POSITION=1, " + get_replication_option_keyword() + "_SSL=1");
+
+session.runSql("START " + get_replica_keyword());
 
 //@ Create cluster async replication (should fail)
-dba.createCluster('testAsync', {clearReadOnly: true});
+dba.createCluster('testAsync');
 
 //@<> Create cluster async replication using force option (should pass)
-EXPECT_NO_THROWS(function(){dba.createCluster('testAsync', {clearReadOnly: true, force: true});});
+EXPECT_NO_THROWS(function(){dba.createCluster('testAsync', {force: true});});
 
 //@<> BUG#29305551: Finalization
 session.close();
@@ -807,7 +892,9 @@ shell.connect(__sandbox_uri1);
 //@<> BUG#29361352: no warning or prompt for multi-primary (interactive: true, multiPrimary: false).
 
 var c;
-EXPECT_NO_THROWS(function() { c = dba.createCluster('test', {interactive: true, multiPrimary: false, force: false}); });
+shell.options.useWizards=1;
+EXPECT_NO_THROWS(function() { c = dba.createCluster('test', {multiPrimary: false, force: false}); });
+shell.options.useWizards=0;
 
 if (__version_num < 80011) {
  EXPECT_STDOUT_CONTAINS_MULTILINE(`A new InnoDB Cluster will be created on instance '${hostname}:${__mysql_sandbox_port1}'.
@@ -821,9 +908,12 @@ This instance reports its own address as ${hostname}:${__mysql_sandbox_port1}
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '${hostname}:${__mysql_sandbox_gr_port1}'. Use the localAddress option to override.
 
+NOTE: The 'localAddress' "${hostname}" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+NOTE: When adding more instances to the Cluster, be aware that the subnet masks dictate whether the instance's address is automatically added to the allowlist or not. Please specify the 'ipAllowlist' accordingly if needed.
 * Checking connectivity and SSL configuration...
 
-WARNING: Instance '${hostname}:${__mysql_sandbox_port1}' cannot persist Group Replication configuration since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+WARNING: Instance '${hostname}:${__mysql_sandbox_port1}' cannot persist Group Replication configuration since MySQL version ${__version} does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally to persist the changes.
 Creating InnoDB Cluster 'test' on '${hostname}:${__mysql_sandbox_port1}'...
 
 Adding Seed Instance...
@@ -930,14 +1020,14 @@ testutil.destroySandbox(__mysql_sandbox_port2);
 testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname, server_id: 11111});
 shell.connect(__sandbox_uri1);
 
-//@ WL#12773: FR4 - The ipWhitelist shall not change the behavior defined by FR1
+//@ WL#12773: FR4 - The ipAllowlist shall not change the behavior defined by FR1
 var result = session.runSql("SELECT COUNT(*) FROM mysql.user");
 var old_account_number = result.fetchOne()[0];
 
 if (__version_num < 80027) {
-    testutil.callMysqlsh([__sandbox_uri1, "--", "dba", "create-cluster", "test", "--ip-whitelist=192.168.2.1/15,127.0.0.1," + hostname_ip])
+    testutil.callMysqlsh([__sandbox_uri1, "--", "dba", "create-cluster", "test", "--ip-allowlist=192.168.2.1/15,127.0.0.1," + hostname_ip])
 } else {
-    testutil.callMysqlsh([__sandbox_uri1, "--", "dba", "create-cluster", "test", "--ip-whitelist=192.168.2.1/15,127.0.0.1," + hostname_ip, "--communication-stack=xcom"])
+    testutil.callMysqlsh([__sandbox_uri1, "--", "dba", "create-cluster", "test", "--ip-allowlist=192.168.2.1/15,127.0.0.1," + hostname_ip, "--communication-stack=xcom"])
 }
 print(get_all_gr_recovery_accounts(session));
 
@@ -1009,40 +1099,37 @@ print_metadata_instance_addresses(session);
 session.close();
 testutil.destroySandbox(__mysql_sandbox_port1);
 
-//@<> Initialization IPv6 addresses are supported on localAddress, groupSeeds and ipWhitelist WL#12758 {VER(>= 8.0.14)}
+//@<> Initialization IPv6 addresses are supported on localAddress and ipAllowlist WL#12758 {VER(>= 8.0.14)}
 testutil.deploySandbox(__mysql_sandbox_port1, "root");
 shell.connect(__sandbox_uri1);
 
-//@ IPv6 addresses are supported on localAddress, groupSeeds and ipWhitelist WL#12758 {VER(>= 8.0.14)}
+//@<> IPv6 addresses are supported on localAddress and ipAllowlist WL#12758 {VER(>= 8.0.14)}
 var local_address = "[::1]:" + __mysql_sandbox_gr_port1;
-var ip_white_list = "::1, 127.0.0.1";
-var group_seeds = "[::1]:" + __mysql_sandbox_gr_port1; + ", [::1]:" + __mysql_sandbox_gr_port2;
-c = dba.createCluster("cluster", {ipWhitelist:ip_white_list, groupSeeds:group_seeds, localAddress:local_address, communicationStack: "xcom"});
+var ip_allow_list = "::1, 127.0.0.1";
+EXPECT_NO_THROWS(function(){ c = dba.createCluster("cluster", {ipAllowlist:ip_allow_list, localAddress:local_address, communicationStack: "xcom"}); });
 
-//@<> If the target instance is >= 8.0.23, ipWhitelist is automatically used to set ipAllowlist {VER(>=8.0.23)}
+//@<> If the target instance is >= 8.0.23, ipAllowlist is automatically used to set ipAllowlist {VER(>=8.0.23)}
 shell.connect(__sandbox_uri1);
-EXPECT_EQ(ip_white_list, get_sysvar(session, "group_replication_ip_allowlist"));
+EXPECT_EQ(ip_allow_list, get_sysvar(session, "group_replication_ip_allowlist"));
 
-//@<> If the target instance is >= 8.0.23, ipWhitelist is automatically used to set ipAllowlist {VER(>=8.0.14) && VER(<8.0.23)}
+//@<> If the target instance is >= 8.0.23, ipAllowlist is automatically used to set ipAllowlist {VER(>=8.0.14) && VER(<8.0.23)}
 shell.connect(__sandbox_uri1);
-EXPECT_EQ(ip_white_list, get_sysvar(session, "group_replication_ip_whitelist"));
-
+EXPECT_EQ(ip_allow_list, get_sysvar(session, "group_replication_ip_whitelist"));
 EXPECT_EQ(local_address, get_sysvar(session, "group_replication_local_address"));
-EXPECT_EQ(group_seeds, get_sysvar(session, "group_replication_group_seeds"));
 
 //@<> Dissolve the cluster {VER(>=8.0)}
 c.dissolve({force: true});
 
-//@<> Verify the new option ipAllowlist that deprecates ipWhitelist sets the allowlist {VER(>=8.0.23)}
+//@<> Verify the new option ipAllowlist that deprecates ipAllowlist sets the allowlist {VER(>=8.0.23)}
 if (__version_num < 80027) {
-    c = dba.createCluster("cluster", {ipAllowlist: ip_white_list});
+    c = dba.createCluster("cluster", {ipAllowlist: ip_allow_list});
 } else {
-    c = dba.createCluster("cluster", {ipAllowlist: ip_white_list, communicationStack: "xcom"});
+    c = dba.createCluster("cluster", {ipAllowlist: ip_allow_list, communicationStack: "xcom"});
 }
 
-EXPECT_EQ(ip_white_list, get_sysvar(session, "group_replication_ip_allowlist"));
+EXPECT_EQ(ip_allow_list, get_sysvar(session, "group_replication_ip_allowlist"));
 
-//@<> Cleanup IPv6 addresses are supported on localAddress, groupSeeds and ipWhitelist WL#12758 {VER(>= 8.0.14)}
+//@<> Cleanup IPv6 addresses are supported on localAddress and ipAllowlist WL#12758 {VER(>= 8.0.14)}
 session.close();
 testutil.destroySandbox(__mysql_sandbox_port1);
 
@@ -1069,8 +1156,8 @@ shell.connect(__sandbox_uri1);
 var local_address = "[::1]:" + __mysql_sandbox_gr_port1;
 var c = dba.createCluster("cluster", {localAddress:local_address});
 
-//@ IPv6 on ipWhitelist is not supported below 8.0.14 WL#12758 {VER(< 8.0.14)}
-var c = dba.createCluster("cluster", {ipWhitelist:"::1, 127.0.0.1"});
+//@ IPv6 on ipAllowlist is not supported below 8.0.14 WL#12758 {VER(< 8.0.14)}
+var c = dba.createCluster("cluster", {ipAllowlist:"::1, 127.0.0.1"});
 
 //@<> Cleanup IPv6 addresses are not supported below 8.0.14 WL#12758 {VER(< 8.0.14)}
 session.close();
