@@ -33,7 +33,7 @@ session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'r
 
 session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, '', 'mysqlrouter', 'routerhost2', '8.0.18', '2019-01-01 11:22:33', NULL, ?, NULL, NULL)", [cluster_id]);
 session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'system', 'mysqlrouter', 'routerhost1', '8.0.18', '2019-01-01 11:22:33', '{\"ROEndpoint\": \"6481\", \"RWEndpoint\": \"6480\", \"ROXEndpoint\": \"6483\", \"RWXEndpoint\": \"6482\"}', ?, NULL, NULL)", [cluster_id]);
-session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'system', 'mysqlrouter', 'routerhost2', '8.0.18', '2019-01-01 11:22:33', '{\"ROEndpoint\": 6481, \"RWEndpoint\": 6480, \"ROXEndpoint\": 6483, \"RWXEndpoint\": 6482}', ?, NULL, NULL)", [cluster_id]);
+session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'system', 'mysqlrouter', 'routerhost2', '8.0.18', '2019-01-01 11:22:33', '{\"ROEndpoint\": 6481, \"RWEndpoint\": 6480, \"ROXEndpoint\": 6483, \"RWXEndpoint\": 6482, \"RWSplitEndpoint\": 6490}', ?, NULL, NULL)", [cluster_id]);
 session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'foobar', 'mysqlrouter', 'routerhost2', '8.0.18', '2019-01-01 11:22:33', NULL, ?, NULL, NULL)", [cluster_id]);
 
 //@<> MD2 - listRouters() - full list
@@ -50,6 +50,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -60,6 +61,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -70,6 +72,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -79,6 +82,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -89,6 +93,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -99,6 +104,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -109,6 +115,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": "6490",
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -130,6 +137,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -140,6 +148,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -150,6 +159,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -160,6 +170,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -170,6 +181,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -180,6 +192,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": "6490",
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -202,6 +215,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -212,6 +226,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -222,6 +237,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -231,6 +247,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -241,6 +258,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -251,6 +269,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -261,6 +280,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": "6490",
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -277,7 +297,6 @@ EXPECT_THROWS_TYPE(function() { cluster.removeRouterMetadata("::bla"); }, "Inval
 EXPECT_THROWS_TYPE(function() { cluster.removeRouterMetadata("foo::bla::"); }, "Invalid router instance 'foo::bla::'", "ArgumentError");
 EXPECT_THROWS_TYPE(function() { cluster.removeRouterMetadata("127.0.0.1"); }, "Invalid router instance '127.0.0.1'", "ArgumentError");
 
-
 //@<> MD2 - removeRouterMetadata()
 cluster.removeRouterMetadata("routerhost1");
 cluster.removeRouterMetadata("routerhost1::r2");
@@ -298,6 +317,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -307,6 +327,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -317,6 +338,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -327,6 +349,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -356,6 +379,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -365,6 +389,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -375,6 +400,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -407,6 +433,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "abc",
             "roXPort": "",
             "rwPort": "6480:foo",
+            "rwSplitPort": null,
             "rwXPort": "foo6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -417,6 +444,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -426,6 +454,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -436,6 +465,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -490,7 +520,7 @@ session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'r
 
 session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, '', 3, NULL)");
 session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'system', 2, '{\"ROEndpoint\": \"6481\", \"RWEndpoint\": \"6480\", \"ROXEndpoint\": \"6483\", \"RWXEndpoint\": \"6482\"}')");
-session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'system', 3, '{\"ROEndpoint\": 6481, \"RWEndpoint\": 6480, \"ROXEndpoint\": 6483, \"RWXEndpoint\": 6482}')");
+session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'system', 3, '{\"ROEndpoint\": 6481, \"RWEndpoint\": 6480, \"ROXEndpoint\": 6483, \"RWXEndpoint\": 6482, \"RWSplitEndpoint\": 6490}')");
 session.runSql("INSERT mysql_innodb_cluster_metadata.routers VALUES (DEFAULT, 'foobar', 3, NULL)");
 
 //@<> MD1 - listRouters() - full list
@@ -507,6 +537,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -517,6 +548,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "1.0.0"
@@ -527,6 +559,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -537,6 +570,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -546,6 +580,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -556,6 +591,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -566,6 +602,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -576,6 +613,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": "6490",
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -598,6 +636,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -608,6 +647,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "1.0.0"
@@ -618,6 +658,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -628,6 +669,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -638,6 +680,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -648,6 +691,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -658,6 +702,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": "6490",
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -680,6 +725,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -690,6 +736,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "1.0.0"
@@ -700,6 +747,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -710,6 +758,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -719,6 +768,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -729,6 +779,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -739,6 +790,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -749,6 +801,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": "6490",
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -785,6 +838,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "1.0.0"
@@ -795,6 +849,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "version": "8.0.19"
         },
@@ -804,6 +859,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": "6481",
             "roXPort": "6483",
             "rwPort": "6480",
+            "rwSplitPort": null,
             "rwXPort": "6482",
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -814,6 +870,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
@@ -824,6 +881,7 @@ EXPECT_STDOUT_CONTAINS_MULTILINE(`
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "<= 8.0.18"
