@@ -83,51 +83,27 @@
 |TCP port:                     <<<__mysql_sandbox_port2>>>|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
-//@ SP - getCluster() on primary with connectToPrimary: true: deprecated - auto-redirect to primary
+//@ SP - getCluster(null) on primary
 |TCP port:                     <<<__mysql_sandbox_port1>>>|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
-//@ SP - getCluster() on secondary with connectToPrimary: true: deprecated - auto-redirect to primary
+//@ SP - getCluster(null) on secondary
 |TCP port:                     <<<__mysql_sandbox_port2>>>|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
-//@ SP - getCluster() on primary with connectToPrimary: false: deprecated - auto-redirect to primary
-|TCP port:                     <<<__mysql_sandbox_port1>>>|
-|    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
-
-//@ SP - getCluster() on secondary with connectToPrimary: false: deprecated - auto-redirect to primary
-|TCP port:                     <<<__mysql_sandbox_port2>>>|
-|    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
-
-//@ SPX - getCluster() on session to primary: true: deprecated - auto-redirect to primary
+//@ SPX - getCluster() on session to primary
 |TCP port:                     <<<__mysql_sandbox_port1>>>0|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
-//@ SPX - getCluster() on session to secondary: true: deprecated - auto-redirect to primary
+//@ SPX - getCluster() on session to secondary
 |TCP port:                     <<<__mysql_sandbox_port2>>>0|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
-//@ SPX - getCluster() on session to primary: false: deprecated - auto-redirect to primary
+//@ SPX implicit - getCluster() on session to primary
 |TCP port:                     <<<__mysql_sandbox_port1>>>0|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
-//@ SPX - getCluster() on session to secondary: false: deprecated - auto-redirect to primary
-|TCP port:                     <<<__mysql_sandbox_port2>>>0|
-|    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
-
-//@ SPX implicit - getCluster() on session to primary: true: deprecated - auto-redirect to primary
-|TCP port:                     <<<__mysql_sandbox_port1>>>0|
-|    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
-
-//@ SPX implicit - getCluster() on session to secondary: true: deprecated - auto-redirect to primary
-|TCP port:                     <<<__mysql_sandbox_port2>>>0|
-|    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
-
-//@ SPX implicit - getCluster() on session to primary: false: deprecated - auto-redirect to primary
-|TCP port:                     <<<__mysql_sandbox_port1>>>0|
-|    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
-
-//@ SPX implicit - getCluster() on session to secondary: false: deprecated - auto-redirect to primary
+//@ SPX implicit - getCluster() on session to secondary
 |TCP port:                     <<<__mysql_sandbox_port2>>>0|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
@@ -143,16 +119,16 @@
 |TCP port:                     <<<__mysql_sandbox_port1>>>|
 
 //@ SP - Connect with --redirect-primary while connected to a secondary
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>)...|
 |Protocol version:             Classic 10|
 |TCP port:                     <<<__mysql_sandbox_port1>>>|
 
 //@ SP - Connect with --redirect-primary while connected to a non-cluster member (error)
 |While handling --redirect-primary:|
-|Metadata schema of an InnoDB cluster or ReplicaSet not found|
+|Metadata schema of an InnoDB Cluster or ReplicaSet not found|
 
 //@ SP - Connect with --redirect-secondary while connected to the primary
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>)...|
 |Protocol version:             Classic 10|
 |TCP port:                     <<<__mysql_sandbox_port2>>>|
 
@@ -163,7 +139,7 @@
 
 //@ SP - Connect with --redirect-secondary while connected to a non-cluster member (error)
 |While handling --redirect-secondary:|
-|Metadata schema of an InnoDB cluster or ReplicaSet not found|
+|Metadata schema of an InnoDB Cluster or ReplicaSet not found|
 
 //@ SPX - Connect with no options and ensure it will connect to the specified member
 |Protocol version:             X protocol|
@@ -179,16 +155,16 @@
 |TCP port:                     <<<__mysql_sandbox_port1>>>0|
 
 //@ SPX - Connect with --redirect-primary while connected to a secondary
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
 |Protocol version:             X protocol|
 |TCP port:                     <<<__mysql_sandbox_port1>>>0|
 
 //@ SPX - Connect with --redirect-primary while connected to a non-cluster member (error)
 |While handling --redirect-primary:|
-|Metadata schema of an InnoDB cluster or ReplicaSet not found|
+|Metadata schema of an InnoDB Cluster or ReplicaSet not found|
 
 //@ SPX - Connect with --redirect-secondary while connected to the primary
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
 |Protocol version:             X protocol|
 |TCP port:                     <<<__mysql_sandbox_port2>>>0|
 
@@ -199,7 +175,7 @@
 
 //@ SPX - Connect with --redirect-secondary while connected to a non-cluster member (error)
 |While handling --redirect-secondary:|
-|Metadata schema of an InnoDB cluster or ReplicaSet not found|
+|Metadata schema of an InnoDB Cluster or ReplicaSet not found|
 
 //@ SPX implicit - Connect with no options and ensure it will connect to the specified member
 |Protocol version:             X protocol|
@@ -215,16 +191,16 @@
 |TCP port:                     <<<__mysql_sandbox_port1>>>0|
 
 //@ SPX implicit - Connect with --redirect-primary while connected to a secondary
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
 |Protocol version:             X protocol|
 |TCP port:                     <<<__mysql_sandbox_port1>>>0|
 
 //@ SPX implicit - Connect with --redirect-primary while connected to a non-cluster member (error)
 |While handling --redirect-primary:|
-|Metadata schema of an InnoDB cluster or ReplicaSet not found|
+|Metadata schema of an InnoDB Cluster or ReplicaSet not found|
 
 //@ SPX implicit - Connect with --redirect-secondary while connected to the primary
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
 |Protocol version:             X protocol|
 |TCP port:                     <<<__mysql_sandbox_port2>>>0|
 
@@ -235,7 +211,7 @@
 
 //@ SPX implicit - Connect with --redirect-secondary while connected to a non-cluster member (error)
 |While handling --redirect-secondary:|
-|Metadata schema of an InnoDB cluster or ReplicaSet not found|
+|Metadata schema of an InnoDB Cluster or ReplicaSet not found|
 
 //@ SP - Connect with --cluster 1
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
@@ -247,34 +223,31 @@
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SP - Connect with --cluster on a non-cluster member + cmd (error)
-|Option --cluster requires a session to a member of an InnoDB cluster.|
+|Option --cluster requires a session to a member of an InnoDB Cluster.|
 |ERROR: MYSQLSH 51300: This function is not available through a session to a standalone instance|
 
 //@ SP - Connect with --cluster on a non-cluster member interactive (error)
-|Option --cluster requires a session to a member of an InnoDB cluster.|
+|Option --cluster requires a session to a member of an InnoDB Cluster.|
 |ERROR: MYSQLSH 51300: This function is not available through a session to a standalone instance|
 
 //@ SP - Connect with --cluster on a non-cluster member (error)
-|Option --cluster requires a session to a member of an InnoDB cluster.|
+|Option --cluster requires a session to a member of an InnoDB Cluster.|
 |ERROR: MYSQLSH 51300: This function is not available through a session to a standalone instance|
 
 //@ SP - Connect with --replicaset, expect error {VER(>8.0.0)}
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SP - Connect with --replicaset, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SP - Connect with --cluster + --redirect-primary 1
 |NOTE: --redirect-primary ignored because target is already a PRIMARY|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SP - Connect with --cluster + --redirect-primary 2
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>)...|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SP - Connect with --cluster + --redirect-secondary 1
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>)...|
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SP - Connect with --cluster + --redirect-secondary 2
@@ -286,33 +259,21 @@
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SP - Connect with --replicaset + --redirect-primary 1, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SP - Connect with --replicaset + --redirect-primary 2, expect error {VER(>8.0.0)}
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>)...|
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SP - Connect with --replicaset + --redirect-primary 2, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SP - Connect with --replicaset + --redirect-secondary 1, expect error {VER(>8.0.0)}
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>)...|
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SP - Connect with --replicaset + --redirect-secondary 1, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SP - Connect with --replicaset + --redirect-secondary 2, expect error {VER(>8.0.0)}
 |NOTE: --redirect-secondary ignored because target is already a SECONDARY|
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SP - Connect with --replicaset + --redirect-secondary 2, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SPX - Connect with --cluster 1
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
@@ -323,7 +284,7 @@
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX - Connect with --cluster on a non-cluster member (error)
-|Option --cluster requires a session to a member of an InnoDB cluster.|
+|Option --cluster requires a session to a member of an InnoDB Cluster.|
 |ERROR: MYSQLSH 51300: This function is not available through a session to a standalone instance|
 
 //@ SPX - Connect with --cluster + --redirect-primary 1
@@ -331,11 +292,11 @@
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX - Connect with --cluster + --redirect-primary 2
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX - Connect with --cluster + --redirect-secondary 1
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX - Connect with --cluster + --redirect-secondary 2
@@ -343,21 +304,15 @@
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX - Connect with --replicaset + --redirect-primary 2, expect error {VER(>8.0.0)}
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_x_port1>>>)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_x_port1>>>)...|
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SPX - Connect with --replicaset + --redirect-primary 2, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SPX - Connect with --replicaset + --redirect-secondary 1, expect error {VER(>8.0.0)}
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_x_port2>>>)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_x_port2>>>)...|
 |Option --replicaset requires a session to a member of an InnoDB ReplicaSet.|
 |This function is not available through a session to an instance already in an InnoDB Cluster|
 
-//@ SPX - Connect with --replicaset + --redirect-secondary 1, expect error {VER(<8.0.0)}
-|Unsupported server version: This AdminAPI operation requires MySQL version 8.0 or newer, but target is |
-
 //@ SPX implicit - Connect with --cluster 1
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
@@ -368,7 +323,7 @@
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX implicit - Connect with --cluster on a non-cluster member (error)
-|Option --cluster requires a session to a member of an InnoDB cluster.|
+|Option --cluster requires a session to a member of an InnoDB Cluster.|
 |ERROR: MYSQLSH 51300: This function is not available through a session to a standalone instance|
 
 //@ SPX implicit - Connect with --cluster + --redirect-primary 1
@@ -376,11 +331,11 @@
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX implicit - Connect with --cluster + --redirect-primary 2
-|Reconnecting to the PRIMARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
+|Reconnecting to the PRIMARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port1>>>0)...|
 |    "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX implicit - Connect with --cluster + --redirect-secondary 1
-|Reconnecting to the SECONDARY instance of an InnoDB cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
+|Reconnecting to the SECONDARY instance of an InnoDB Cluster (<<<hostname>>>:<<<__mysql_sandbox_port2>>>0)...|
 |"groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"|
 
 //@ SPX implicit - Connect with --cluster + --redirect-secondary 2
