@@ -10,12 +10,9 @@ group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -28,34 +25,24 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 |<Cluster:C>|
 
 //@<OUT> FR1-TS-01 check persisted variables {VER(>=8.0.12)}
-group_replication_autorejoin_tries = <<<__default_gr_auto_rejoin_tries>>>
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-group_replication_exit_state_action = READ_ONLY
+?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
-group_replication_group_seeds = 
-?{VER(>=8.0.23)}
-group_replication_ip_allowlist = AUTOMATIC
-?{}
-?{VER(<8.0.23)}
-group_replication_ip_whitelist = AUTOMATIC
-?{}
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-group_replication_member_weight = 50
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
 group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 {
@@ -102,7 +89,7 @@ NOTE: Group Replication will communicate with other members using '<<<hostname>>
 
 * Checking connectivity and SSL configuration...
 
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' will not load the persisted cluster configuration upon reboot since 'persisted-globals-load' is set to 'OFF'. Please use the dba.configureLocalInstance() command locally to persist the changes or set 'persisted-globals-load' to 'ON' on the configuration file.
+WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' will not load the persisted cluster configuration upon reboot since 'persisted-globals-load' is set to 'OFF'. Please set 'persisted-globals-load' to 'ON' on the configuration file.
 Creating InnoDB Cluster 'C' on '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'...
 
 Adding Seed Instance...
@@ -116,7 +103,7 @@ one server failure.
 ||
 
 //@ FR1-TS-04/05 SETUP {VER(>=8.0.12)}
-|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.|
+|The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB Cluster.|
 |Cluster successfully created. Use Cluster.addInstance() to add MySQL instances.|
 
 //@<OUT> FR1-TS-04/05 {VER(>=8.0.12)}
@@ -134,20 +121,13 @@ group_replication_local_address = localhost:<<<__local_address_1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
-WARNING: The interactive option is deprecated and will be removed in a future release.
-
-WARNING: This function is deprecated and will be removed in a future release of MySQL Shell, use dba.configureInstance() instead.
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' belongs to an InnoDB cluster.
-Calling this function on a cluster member is only required for MySQL versions 8.0.4 or earlier.
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' belongs to an InnoDB Cluster.
 
 //@ FR1-TS-04/05 TEARDOWN {VER(>=8.0.12)}
 ||
@@ -167,9 +147,12 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>'. Use the localAddress option to override.
 
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+NOTE: When adding more instances to the Cluster, be aware that the subnet masks dictate whether the instance's address is automatically added to the allowlist or not. Please specify the 'ipAllowlist' accordingly if needed.
 * Checking connectivity and SSL configuration...
 
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist Group Replication configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist Group Replication configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally, using the 'mycnfPath' option, to persist the changes.
 Creating InnoDB Cluster 'ClusterName' on '<<<hostname>>>:<<<__mysql_sandbox_port1>>>'...
 
 Adding Seed Instance...
@@ -194,12 +177,10 @@ group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
 group_replication_single_primary_mode = OFF
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -213,34 +194,26 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 |<Cluster:ClusterName>|
 
 //@<OUT> FR1-TS-7 check persisted variables {VER(>=8.0.12)}
-group_replication_autorejoin_tries = <<<__default_gr_auto_rejoin_tries>>>
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
+?{}
 group_replication_enforce_update_everywhere_checks = ON
-group_replication_exit_state_action = READ_ONLY
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
-group_replication_group_seeds = 
-?{VER(>=8.0.23)}
-group_replication_ip_allowlist = AUTOMATIC
-?{}
-?{VER(<8.0.23)}
-group_replication_ip_whitelist = AUTOMATIC
-?{}
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-group_replication_member_weight = 50
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
 group_replication_single_primary_mode = OFF
 group_replication_ssl_mode = REQUIRED
 group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 {
@@ -273,25 +246,18 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ||
 
 //@<OUT> FR2-TS-1 check persisted variables on instance 1 {VER(>=8.0.12)}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -387,7 +353,7 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 |A new instance will be added to the InnoDB Cluster. Depending on the amount of|
 |data on the cluster this might take from a few seconds to several hours.|
 ||
-|WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' will not load the persisted cluster configuration upon reboot since 'persisted-globals-load' is set to 'OFF'. Please use the dba.configureLocalInstance() command locally to persist the changes or set 'persisted-globals-load' to 'ON' on the configuration file.|
+|WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' will not load the persisted cluster configuration upon reboot since 'persisted-globals-load' is set to 'OFF'. Please set 'persisted-globals-load' to 'ON' on the configuration file.|
 |Adding instance to the cluster...|
 ||
 |Monitoring recovery process of the new cluster member. Press ^C to stop monitoring and let it continue in background.|
@@ -431,20 +397,7 @@ The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' was successfully added
     "groupInformationSourceMember": "<<<hostname>>>:<<<__mysql_sandbox_port1>>>"
 }
 
-//@ FR2-TS-3 TEARDOWN {VER(>=8.0.12)}
-||
-
-//@ FR2-TS-4 SETUP {VER(>=8.0.12)}
-||
-
 //@<OUT> FR2-TS-4 Check that persisted variables match the ones passed on the arguments to create cluster and addInstance {VER(>=8.0.12)}
-?{VER(>=8.0.27)}
-group_replication_communication_stack = XCOM
-?{}
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = localhost:<<<__local_address_2>>>
 ?{VER(>=8.0.23)}
@@ -457,22 +410,17 @@ group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xco
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
-?{VER(>=8.0.27)}
-group_replication_communication_stack = XCOM
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
 ?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xcom>>>
@@ -483,17 +431,9 @@ group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = localhost:<<<__local_address_2>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -505,10 +445,6 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ||
 
 //@<OUT> FR2-TS-5 {VER(>=8.0.12)}
-?{VER(>=8.0.27)}
-group_replication_communication_stack = XCOM
-?{}
-group_replication_enforce_update_everywhere_checks = OFF
 ?{VER(<8.0.16)}
 group_replication_exit_state_action = READ_ONLY
 ?{}
@@ -518,20 +454,18 @@ group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xco
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
-?{VER(>=8.0.27)}
-group_replication_communication_stack = XCOM
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
 ?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
+?{}
 ?{VER(<8.0.16)}
 group_replication_exit_state_action = READ_ONLY
 ?{}
@@ -544,57 +478,13 @@ group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,
 group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
 ?{}
 group_replication_local_address = localhost:<<<__local_address_3>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
-WARNING: The interactive option is deprecated and will be removed in a future release.
 
-WARNING: The clearReadOnly option is deprecated and will be removed in a future release.
-
-WARNING: This function is deprecated and will be removed in a future release of MySQL Shell, use dba.configureInstance() instead.
-The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' belongs to an InnoDB cluster.
-Calling this function on a cluster member is only required for MySQL versions 8.0.4 or earlier.
-
-?{VER(>=8.0.27)}
-group_replication_communication_stack = XCOM
-?{}
-group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
-group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
-group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1_xcom>>>
-?{VER(>=8.0.23)}
-group_replication_ip_allowlist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
-?{}
-?{VER(<8.0.23)}
-group_replication_ip_whitelist = 255.255.255.255/32,127.0.0.1,<<<hostname_ip>>>,<<<hostname>>>
-?{}
-group_replication_local_address = localhost:<<<__local_address_3>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
-group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
-group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
-group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
-?{}
+The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' belongs to an InnoDB Cluster.
 
 //@ FR2-TS-5 TEARDOWN {VER(>=8.0.12)}
 ||
@@ -603,13 +493,13 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ||
 
 //@<OUT> FR2-TS-6 Warning is displayed on addInstance {VER(<8.0.12)}
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' cannot persist Group Replication configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' cannot persist Group Replication configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally, using the 'mycnfPath' option, to persist the changes.
 
 //@<OUT> FR2-TS-6 Warning is displayed on addInstance {VER(<8.0.12)}
 {{State recovery already finished for 'localhost:<<<__mysql_sandbox_port2>>>'|Incremental state recovery is now in progress.}}
 
 //@<OUT> FR2-TS-6 Warning is displayed on addInstance {VER(<8.0.12)}
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally, using the 'mycnfPath' option, to persist the changes.
 The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' was successfully added to the cluster.
 
 //@ FR2-TS-6 TEARDOWN {VER(<8.0.12)}
@@ -623,46 +513,36 @@ The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' was successfully added
 group_replication_communication_stack = MYSQL
 ?{}
 group_replication_enforce_update_everywhere_checks = ON
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
 group_replication_single_primary_mode = OFF
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
-group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = ON
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
 ?{}
+?{VER(<8.4.0)}
+group_replication_consistency = EVENTUAL
+?{}
+group_replication_enforce_update_everywhere_checks = ON
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
 group_replication_single_primary_mode = OFF
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 (MISSING)
@@ -740,25 +620,18 @@ ONLINE
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -769,72 +642,51 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>,<<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>,<<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>,<<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 (MISSING)
@@ -935,47 +787,35 @@ group_replication_bootstrap_group = OFF
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
-group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
 ?{}
+?{VER(<8.4.0)}
+group_replication_consistency = EVENTUAL
+?{}
+group_replication_enforce_update_everywhere_checks = OFF
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds =
 group_replication_local_address =
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
 group_replication_start_on_boot = OFF
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds =
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -989,25 +829,18 @@ group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>,<<<hostname>>>:<<<__mysql_sandbox_gr_port2>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 The instance will be removed from the InnoDB Cluster.
@@ -1023,25 +856,18 @@ The instance 'localhost:<<<__mysql_sandbox_port2>>>' was successfully removed fr
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
+?{}
+?{VER(<8.4.0)}
 group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
 ?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -1049,47 +875,35 @@ group_replication_bootstrap_group = OFF
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
-group_replication_consistency = EVENTUAL
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
+?{VER(>=8.4.0)}
+group_replication_consistency = BEFORE_ON_PRIMARY_FAILOVER
 ?{}
+?{VER(<8.4.0)}
+group_replication_consistency = EVENTUAL
+?{}
+group_replication_enforce_update_everywhere_checks = OFF
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds =
 group_replication_local_address =
-group_replication_member_expel_timeout = <<<__default_gr_expel_timeout>>>
-?{VER(>=8.0.31)}
-group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
-?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
 group_replication_start_on_boot = OFF
-group_replication_transaction_size_limit = 150000000
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
 ?{VER(>=8.0.27)}
 group_replication_communication_stack = MYSQL
 ?{}
-group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds = <<<hostname>>>:<<<__mysql_sandbox_gr_port3>>>
 group_replication_local_address = <<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
-group_replication_start_on_boot = ON
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
@@ -1107,8 +921,8 @@ The instance will be removed from the InnoDB Cluster.
 
 * Instance 'localhost:<<<__mysql_sandbox_port2>>>' is attempting to leave the cluster...
 WARNING: On instance 'localhost:<<<__mysql_sandbox_port2>>>' configuration cannot be persisted since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please set the 'group_replication_start_on_boot' variable to 'OFF' in the server configuration file, otherwise it might rejoin the cluster upon restart.
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
-WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
+WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally, using the 'mycnfPath' option, to persist the changes.
+WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port3>>>' cannot persist configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureInstance() command locally, using the 'mycnfPath' option, to persist the changes.
 
 The instance 'localhost:<<<__mysql_sandbox_port2>>>' was successfully removed from the cluster.
 
@@ -1160,21 +974,16 @@ group_replication_bootstrap_group = OFF
 group_replication_communication_stack = MYSQL
 ?{}
 group_replication_enforce_update_everywhere_checks = OFF
-?{VER(<8.0.16)}
-group_replication_exit_state_action = READ_ONLY
-?{}
 group_replication_group_name = ca94447b-e6fc-11e7-b69d-4485005154dc
 group_replication_group_seeds =
 group_replication_local_address =
 ?{VER(>=8.0.31)}
 group_replication_paxos_single_leader = <<<__default_gr_paxos_single_leader>>>
 ?{}
-group_replication_recovery_ssl_verify_server_cert = OFF
 group_replication_recovery_use_ssl = ON
-group_replication_single_primary_mode = ON
 group_replication_ssl_mode = REQUIRED
 group_replication_start_on_boot = OFF
-?{VER(>=8.0.25)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
