@@ -8,10 +8,12 @@ ca_path = testutil.sslCreateCa("myca", "/CN=Test_CA");
 // needed to create sandbox folders
 testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname});
 testutil.deploySandbox(__mysql_sandbox_port2, "root", {report_host: hostname});
+testutil.deploySandbox(__mysql_sandbox_port3, "root", {report_host: hostname});
 
 // create server certificates
 cert1_path = testutil.sslCreateCert("server", "myca", `/CN=${hostname}`, __mysql_sandbox_port1);
 cert2_path = testutil.sslCreateCert("server", "myca", `/CN=${hostname}`, __mysql_sandbox_port2);
+cert3_path = testutil.sslCreateCert("server", "myca", `/CN=${hostname}`, __mysql_sandbox_port3);
 
 function update_conf(port, ca_path, cert_path) {
     testutil.changeSandboxConf(port, "ssl_ca", ca_path);
@@ -80,8 +82,11 @@ function check_apis(sslMode, authType) {
         EXPECT_NO_THROWS(function(){ rset.addInstance(__sandbox_uri2); });
     }
 
+    options = rset.options();
+    check_option(options.replicaSet.globalOptions, "replicationSslMode", sslMode);
+
     // rejoin
-    session2.runSql("STOP SLAVE SQL_THREAD");
+    session2.runSql("STOP " + get_replica_keyword() + " SQL_THREAD");
     EXPECT_NO_THROWS(function(){ rset.rejoinInstance(__sandbox_uri2); });
 
     // setPrimaryInstance
@@ -106,9 +111,11 @@ function check_apis(sslMode, authType) {
 //restart the servers with proper SSL support
 update_conf(__mysql_sandbox_port1, ca_path, cert1_path);
 update_conf(__mysql_sandbox_port2, ca_path, cert2_path);
+update_conf(__mysql_sandbox_port3, ca_path, cert3_path);
 
 var session1 = mysql.getSession(__sandbox_uri1);
 var session2 = mysql.getSession(__sandbox_uri2);
+var session3 = mysql.getSession(__sandbox_uri3);
 
 //@<> FR2 create replica set (just password)
 shell.connect(__sandbox_uri1);
@@ -139,12 +146,14 @@ EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2); });
 
 // FR16
 status = rset.status();
-EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"], "TLS_AES_256_GCM_SHA384 TLSv1.3");
+EXPECT_TRUE(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"].match(/TLS_.+ TLSv.+/));
+EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"], "REQUIRED");
 
 check_users(session, true, false, false);
 
 // FR14
 options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
 check_option(options.replicaSet.globalOptions, "memberAuthType", "PASSWORD");
 check_option(options.replicaSet.globalOptions, "certIssuer", "");
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port1}`], "certSubject", "");
@@ -173,6 +182,7 @@ EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2, { certSubject: "/
 check_users(session, true, false, false);
 
 options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
 check_option(options.replicaSet.globalOptions, "memberAuthType", "PASSWORD");
 check_option(options.replicaSet.globalOptions, "certIssuer", "/CN=fooIssuer");
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port1}`], "certSubject", "/CN=fooSubject");
@@ -187,7 +197,7 @@ shell.connect(__sandbox_uri1);
 
 // FR2.1 cannot mix 'memberAuthType' (with value other than "password") with 'adoptFromAR'
 EXPECT_THROWS(function() {
-    dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "CERT_ISSUER", certIssuer: "/CN=Test_CA", adoptFromAR: true });
+    dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "CERT_ISSUER", adoptFromAR: true });
 }, "Cannot set 'memberAuthType' to a value other than 'PASSWORD' if 'adoptFromAR' is set to true.");
 
 var rset;
@@ -211,12 +221,14 @@ EXPECT_OUTPUT_CONTAINS("* Checking connectivity and SSL configuration...");
 
 // FR16
 status = rset.status();
-EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"], "TLS_AES_256_GCM_SHA384 TLSv1.3");
+EXPECT_TRUE(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"].match(/TLS_.+ TLSv.+/));
+EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"], "REQUIRED");
 
 check_users(session, false, true, false);
 
 // FR14
 options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
 check_option(options.replicaSet.globalOptions, "memberAuthType", "CERT_ISSUER");
 check_option(options.replicaSet.globalOptions, "certIssuer", "/CN=Test_CA");
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port1}`], "certSubject", "");
@@ -246,11 +258,13 @@ EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2, { certSubject: "/
 EXPECT_OUTPUT_CONTAINS("* Checking connectivity and SSL configuration...");
 
 status = rset.status();
-EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"], "TLS_AES_256_GCM_SHA384 TLSv1.3");
+EXPECT_TRUE(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"].match(/TLS_.+ TLSv.+/));
+EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"], "REQUIRED");
 
 check_users(session, false, true, false);
 
 options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
 check_option(options.replicaSet.globalOptions, "memberAuthType", "CERT_ISSUER");
 check_option(options.replicaSet.globalOptions, "certIssuer", "/CN=Test_CA");
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port1}`], "certSubject", "/CN=foo");
@@ -278,7 +292,7 @@ shell.connect(__sandbox_uri1);
 
 // FR2.1 cannot mix 'memberAuthType' (with value other than "password") with 'adoptFromAR'
 EXPECT_THROWS(function() {
-    dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "CERT_ISSUER_PASSWORD", certIssuer: "/CN=Test_CA", adoptFromAR: true });
+    dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "CERT_ISSUER_PASSWORD", adoptFromAR: true });
 }, "Cannot set 'memberAuthType' to a value other than 'PASSWORD' if 'adoptFromAR' is set to true.");
 
 var rset;
@@ -296,12 +310,14 @@ EXPECT_OUTPUT_CONTAINS("* Checking connectivity and SSL configuration...");
 
 // FR16
 status = rset.status();
-EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"], "TLS_AES_256_GCM_SHA384 TLSv1.3");
+EXPECT_TRUE(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"].match(/TLS_.+ TLSv.+/));
+EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"], "REQUIRED");
 
 check_users(session, true, true, false);
 
 // FR14
 options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
 check_option(options.replicaSet.globalOptions, "memberAuthType", "CERT_ISSUER_PASSWORD");
 check_option(options.replicaSet.globalOptions, "certIssuer", "/CN=Test_CA");
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port1}`], "certSubject", "");
@@ -316,7 +332,7 @@ shell.connect(__sandbox_uri1);
 
 // FR2.1 cannot mix 'memberAuthType' (with value other than "password") with 'adoptFromAR'
 EXPECT_THROWS(function() {
-    dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "CERT_SUBJECT_PASSWORD", certIssuer: "/CN=Test_CA", certSubject: `/CN=${hostname}`, adoptFromAR: true });
+    dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "CERT_SUBJECT_PASSWORD", adoptFromAR: true });
 }, "Cannot set 'memberAuthType' to a value other than 'PASSWORD' if 'adoptFromAR' is set to true.");
 
 var rset;
@@ -339,20 +355,45 @@ EXPECT_OUTPUT_CONTAINS("* Checking connectivity and SSL configuration...");
 
 // FR16
 status = rset.status();
-EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"], "TLS_AES_256_GCM_SHA384 TLSv1.3");
+EXPECT_TRUE(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"].match(/TLS_.+ TLSv.+/));
+EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"], "REQUIRED");
 
 check_users(session, true, true, true);
 
 // FR14
 options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
 check_option(options.replicaSet.globalOptions, "memberAuthType", "CERT_SUBJECT_PASSWORD");
 check_option(options.replicaSet.globalOptions, "certIssuer", "/CN=Test_CA");
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port1}`], "certSubject", `/CN=${hostname}`);
 check_option(options.replicaSet.topology[`${hostname}:${__mysql_sandbox_port2}`], "certSubject", `/CN=${hostname}`);
 
+//@<> Check options when adopting an existing replica set
+
+dba.dropMetadataSchema({force: true});
+
+EXPECT_THROWS(function() {
+    dba.createReplicaSet("rset", { replicationSslMode: "REQUIRED", adoptFromAR: true });
+}, "Cannot use the options 'replicationSslMode', 'certIssuer', or 'certSubject' if 'adoptFromAR' is set to true.");
+EXPECT_THROWS(function() {
+    dba.createReplicaSet("rset", { certIssuer: "foo", adoptFromAR: true });
+}, "Cannot use the options 'replicationSslMode', 'certIssuer', or 'certSubject' if 'adoptFromAR' is set to true.");
+EXPECT_THROWS(function() {
+    dba.createReplicaSet("rset", { certSubject: "bar", adoptFromAR: true });
+}, "Cannot use the options 'replicationSslMode', 'certIssuer', or 'certSubject' if 'adoptFromAR' is set to true.");
+EXPECT_THROWS(function() {
+    dba.createReplicaSet("rset", { certIssuer: "foo", certSubject: "bar", adoptFromAR: true });
+}, "Cannot use the options 'replicationSslMode', 'certIssuer', or 'certSubject' if 'adoptFromAR' is set to true.");
+
+var rset;
+EXPECT_NO_THROWS(function() { rset = dba.createReplicaSet("rset", { gtidSetIsComplete: 1, memberAuthType: "PASSWORD", adoptFromAR: true }); });
+
+EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri3, { certSubject: `/CN=${hostname}` }); });
+
 // cleanup replica set
 reset_instance(session1);
 reset_instance(session2);
+reset_instance(session3);
 
 //@<> FR2 create replica set (issuer + subject) with clone
 shell.connect(__sandbox_uri1);
@@ -383,9 +424,13 @@ EXPECT_NO_THROWS(function() { rset = dba.createReplicaSet("rset", { gtidSetIsCom
 EXPECT_EQ("DISABLED", session.runSql("SELECT attributes->>'$.opt_replicationSslMode' FROM mysql_innodb_cluster_metadata.clusters WHERE (cluster_name = 'rset')").fetchOne()[0]);
 EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2); });
 
+options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "DISABLED");
+
 // FR16
 status = rset.status();
 EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"], null);
+EXPECT_EQ(status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"], "DISABLED");
 
 reset_instance(session1);
 reset_instance(session2);
@@ -394,8 +439,12 @@ EXPECT_NO_THROWS(function() { rset = dba.createReplicaSet("rset", { gtidSetIsCom
 EXPECT_EQ("REQUIRED", session.runSql("SELECT attributes->>'$.opt_replicationSslMode' FROM mysql_innodb_cluster_metadata.clusters WHERE (cluster_name = 'rset')").fetchOne()[0]);
 EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2); });
 
+options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
+
 status = rset.status();
 EXPECT_CONTAINS("TLS_AES_", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"]);
+EXPECT_EQ("REQUIRED", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"]);
 
 reset_instance(session1);
 reset_instance(session2);
@@ -404,8 +453,12 @@ EXPECT_NO_THROWS(function() { rset = dba.createReplicaSet("rset", { gtidSetIsCom
 EXPECT_EQ("REQUIRED", session.runSql("SELECT attributes->>'$.opt_replicationSslMode' FROM mysql_innodb_cluster_metadata.clusters WHERE (cluster_name = 'rset')").fetchOne()[0]);
 EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2); });
 
+options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "REQUIRED");
+
 status = rset.status();
 EXPECT_CONTAINS("TLS_AES_", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"]);
+EXPECT_EQ("REQUIRED", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"]);
 
 reset_instance(session1);
 reset_instance(session2);
@@ -414,8 +467,12 @@ EXPECT_NO_THROWS(function() { rset = dba.createReplicaSet("rset", { gtidSetIsCom
 EXPECT_EQ("VERIFY_CA", session.runSql("SELECT attributes->>'$.opt_replicationSslMode' FROM mysql_innodb_cluster_metadata.clusters WHERE (cluster_name = 'rset')").fetchOne()[0]);
 EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2); });
 
+options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "VERIFY_CA");
+
 status = rset.status();
 EXPECT_CONTAINS("TLS_AES_", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"]);
+EXPECT_EQ("VERIFY_CA", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"]);
 
 reset_instance(session1);
 reset_instance(session2);
@@ -424,8 +481,12 @@ EXPECT_NO_THROWS(function() { rset = dba.createReplicaSet("rset", { gtidSetIsCom
 EXPECT_EQ("VERIFY_IDENTITY", session.runSql("SELECT attributes->>'$.opt_replicationSslMode' FROM mysql_innodb_cluster_metadata.clusters WHERE (cluster_name = 'rset')").fetchOne()[0]);
 EXPECT_NO_THROWS(function() { rset.addInstance(__sandbox_uri2); });
 
+options = rset.options();
+check_option(options.replicaSet.globalOptions, "replicationSslMode", "VERIFY_IDENTITY");
+
 status = rset.status();
 EXPECT_CONTAINS("TLS_AES_", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSsl"]);
+EXPECT_EQ("VERIFY_IDENTITY", status["replicaSet"]["topology"][`${hostname}:${__mysql_sandbox_port2}`]["replication"]["replicationSslMode"]);
 
 //@<> teste some APIs
 
@@ -463,6 +524,8 @@ EXPECT_OUTPUT_CONTAINS(`ERROR: Authentication error during connection check. Ple
 //@<> Cleanup
 session1.close();
 session2.close();
+session3.close();
 
 testutil.destroySandbox(__mysql_sandbox_port1);
 testutil.destroySandbox(__mysql_sandbox_port2);
+testutil.destroySandbox(__mysql_sandbox_port3);
