@@ -84,7 +84,7 @@
 //@# do stuff in the old primary to simulate split-brain
 |                    "receiverStatus": "ON", |
 |                    "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event", |
-|                    "replicationLag": null|
+|                    "replicationLag": "applier_queue_applied"|
 |                }, |
 |                "status": "ONLINE"|
 |            }|
@@ -128,7 +128,7 @@
 |                    <<<(__version_num<80023)?'"applierWorkerThreads": 4':''>>>|
 |                    "receiverStatus": "ON", |
 |                    "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event", |
-|                    "replicationLag": null|
+|                    "replicationLag": "applier_queue_applied"|
 |                }, |
 |                "status": "ONLINE"|
 |            }|
@@ -170,7 +170,7 @@
 |"status": "INVALIDATED"|
 
 //@# rejoinInstance() the invalidated PRIMARY
-|The instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' rejoined the replicaset and is replicating from <<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>.|
+|The instance '<<<hostname_ip>>>:<<<__mysql_sandbox_port3>>>' rejoined the replicaset and is replicating from '<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>'.|
 |"primary": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>",|
 |"address": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>",|
 |"status": "ONLINE"|
@@ -231,7 +231,7 @@
                 "address": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>",
                 "fenced": false,
                 "instanceErrors": [
-                    "WARNING: Instance was INVALIDATED and must be removed from the replicaset.",
+                    "WARNING: Instance was INVALIDATED and must be rejoined or removed from the replicaset.",
                     "ERROR: Instance is NOT a PRIMARY but super_read_only option is OFF. Accidental updates to this instance are possible and will cause inconsistencies in the replicaset."
                 ],
                 "instanceRole": null,
@@ -243,7 +243,7 @@
                 "address": "<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>",
                 "fenced": true,
                 "instanceErrors": [
-                    "WARNING: Instance was INVALIDATED and must be removed from the replicaset."
+                    "WARNING: Instance was INVALIDATED and must be rejoined or removed from the replicaset."
                 ],
                 "instanceRole": null,
                 "mode": null,
@@ -252,8 +252,9 @@
                     "applierThreadState": <<<(__version_num<80023)?'"Slave has read all relay log; waiting for more updates",':'"Waiting for an event from Coordinator",\n                    "applierWorkerThreads": 4,'>>>
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
-                    "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationLag": "applier_queue_applied",
+                    "replicationSsl": null,
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "INVALIDATED",
                 "transactionSetConsistencyStatus": "OK"
@@ -281,7 +282,7 @@
                 "address": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>",
                 "fenced": false,
                 "instanceErrors": [
-                    "WARNING: Instance was INVALIDATED and must be removed from the replicaset.",
+                    "WARNING: Instance was INVALIDATED and must be rejoined or removed from the replicaset.",
                     "ERROR: Instance is NOT a PRIMARY but super_read_only option is OFF. Accidental updates to this instance are possible and will cause inconsistencies in the replicaset."
                 ],
                 "instanceRole": null,
@@ -293,7 +294,7 @@
                 "address": "<<<hostname_ip>>>:<<<__mysql_sandbox_port2>>>",
                 "fenced": true,
                 "instanceErrors": [
-                    "WARNING: Instance was INVALIDATED and must be removed from the replicaset."
+                    "WARNING: Instance was INVALIDATED and must be rejoined or removed from the replicaset."
                 ],
                 "instanceRole": null,
                 "mode": null,
@@ -302,8 +303,9 @@
                     "applierThreadState": <<<(__version_num<80023)?'"Slave has read all relay log; waiting for more updates",':'"Waiting for an event from Coordinator",\n                    "applierWorkerThreads": 4,'>>>
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
-                    "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationLag": "applier_queue_applied",
+                    "replicationSsl": null,
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "INVALIDATED",
                 "transactionSetConsistencyStatus": "OK"
@@ -361,8 +363,9 @@
                     "applierThreadState": <<<(__version_num<80023)?'"Slave has read all relay log; waiting for more updates",':'"Waiting for an event from Coordinator",\n                    "applierWorkerThreads": 4,'>>>
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
-                    "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationLag": "applier_queue_applied",
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             },
@@ -375,8 +378,9 @@
                     "applierThreadState": <<<(__version_num<80023)?'"Slave has read all relay log; waiting for more updates",':'"Waiting for an event from Coordinator",\n                    "applierWorkerThreads": 4,'>>>
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
-                    "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationLag": "applier_queue_applied",
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             },
