@@ -42,7 +42,7 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
-?{VER(>=8.0.27)}
+?{VER(>=8.0.27) && VER(<8.3.0)}
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 | Variable                               | Current Value | Required Value | Note                                             |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
@@ -52,6 +52,15 @@ NOTE: Some configuration options need to be fixed:
 | server_id                              | 1             | <unique ID>    | Update read-only variable and restart the server |
 +----------------------------------------+---------------+----------------+--------------------------------------------------+
 ?{}
+?{VER(>=8.3.0)}
++--------------------------+---------------+----------------+--------------------------------------------------+
+| Variable                 | Current Value | Required Value | Note                                             |
++--------------------------+---------------+----------------+--------------------------------------------------+
+| enforce_gtid_consistency | OFF           | ON             | Update read-only variable and restart the server |
+| gtid_mode                | OFF           | ON             | Update read-only variable and restart the server |
+| server_id                | 1             | <unique ID>    | Update read-only variable and restart the server |
++--------------------------+---------------+----------------+--------------------------------------------------+
+?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 
@@ -59,7 +68,7 @@ Creating user admin@%.
 Account admin@% was successfully created.
 
 Configuring instance...
-?{(VER(>=8.0.35) && VER(<8.1.0)) || VER(>=8.2.0)}
+?{(VER(>=8.0.35) && VER(<8.1.0)) || (VER(>=8.2.0) && VER(<8.3.0))}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
@@ -78,12 +87,11 @@ Assuming full account name 'admin'@'%' for admin
 applierWorkerThreads will be set to the default value of 4.
 ?{}
 
-The instance '<<<__address2>>>' is valid to be used in an InnoDB ReplicaSet.
-
 Creating user admin@%.
 Account admin@% was successfully created.
 
-The instance '<<<__address2>>>' is already ready to be used in an InnoDB ReplicaSet.
+
+The instance '<<<__address2>>>' is valid for InnoDB ReplicaSet usage.
 ?{VER(>=8.0.23)}
 
 Successfully enabled parallel appliers.
@@ -145,7 +153,7 @@ This instance reports its own address as 127.0.0.1:<<<__mysql_sandbox_port3>>>
 
 * Checking transaction state of the instance...
 
-NOTE: The target instance '<<<__address3>>>' has not been pre-provisioned (GTID set is empty). The Shell is unable to decide whether replication can completely recover its state.
+NOTE: The target instance '<<<__address3>>>' has not been pre-provisioned (GTID set is empty).
 
 Incremental state recovery selected through the recoveryMethod option
 
@@ -187,7 +195,7 @@ The current PRIMARY is 127.0.0.1:<<<__mysql_sandbox_port1>>>.
 
 * Updating metadata
 
-* Acquiring locks in replicaset instances
+* Acquiring locks in ReplicaSet instances
 ** Pre-synchronizing SECONDARIES
 ** Acquiring global lock at PRIMARY
 ** Acquiring global lock at SECONDARIES
@@ -199,9 +207,9 @@ The current PRIMARY is 127.0.0.1:<<<__mysql_sandbox_port1>>>.
 127.0.0.1:<<<__mysql_sandbox_port3>>> was promoted to PRIMARY.
 
 //@<OUT> forcePrimaryInstance (prepare)
-WARNING: Unable to connect to the PRIMARY of the ReplicaSet myrs: MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])
-Cluster change operations will not be possible unless the PRIMARY can be reached.
-If the PRIMARY is unavailable, you must either repair it or perform a forced failover.
+WARNING: Unable to connect to the PRIMARY of the ReplicaSet 'myrs': MYSQLSH 51118: Could not open connection to '127.0.0.1:<<<__mysql_sandbox_port3>>>': Can't connect to MySQL server on '<<<libmysql_host_description('127.0.0.1', __mysql_sandbox_port3)>>>' ([[*]])
+ReplicaSet change operations will not be possible unless the PRIMARY can be reached.
+If the PRIMARY is unavailable, you must either repair it or perform a failover.
 See \help forcePrimaryInstance for more information.
 {
     "replicaSet": {
@@ -261,11 +269,11 @@ Incremental state recovery was selected because it seems to be safely usable.
 
 
 * Updating the Metadata...
-The instance '<<<__address3>>>' rejoined the replicaset and is replicating from 127.0.0.1:<<<__mysql_sandbox_port1>>>.
+The instance '<<<__address3>>>' rejoined the replicaset and is replicating from '127.0.0.1:<<<__mysql_sandbox_port1>>>'.
 
 //@# rejoinInstance (clone) {VER(>=8.0.17)}
 |NOTE: <<<__address3>>> is being cloned from <<<__address2>>>|
-|The instance '<<<__address3>>>' rejoined the replicaset and is replicating from 127.0.0.1:<<<__mysql_sandbox_port1>>>.|
+|The instance '<<<__address3>>>' rejoined the replicaset and is replicating from '127.0.0.1:<<<__mysql_sandbox_port1>>>'.|
 
 //@<OUT> listRouters
 {
@@ -277,6 +285,7 @@ The instance '<<<__address3>>>' rejoined the replicaset and is replicating from
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -287,6 +296,7 @@ The instance '<<<__address3>>>' rejoined the replicaset and is replicating from
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -304,6 +314,7 @@ The instance '<<<__address3>>>' rejoined the replicaset and is replicating from
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -323,10 +334,10 @@ A new replicaset with the topology visible from '<<<__address1>>>' will be creat
 Discovered topology:
 - 127.0.0.1:<<<__mysql_sandbox_port1>>>: uuid=[[*]] read_only=no
 - 127.0.0.1:<<<__mysql_sandbox_port2>>>: uuid=[[*]] read_only=yes
-    - replicates from 127.0.0.1:<<<__mysql_sandbox_port1>>>
+    - replicates from '127.0.0.1:<<<__mysql_sandbox_port1>>>'
 <<<(__version_num<80023)?'	source="127.0.0.1:"' + __mysql_sandbox_port1 + '" channel= status=ON receiver=ON applier=ON':'	source="127.0.0.1:' + __mysql_sandbox_port1 + '" channel= status=ON receiver=ON coordinator=ON applier0=ON applier1=ON applier2=ON applier3=ON'>>>
 - 127.0.0.1:<<<__mysql_sandbox_port3>>>: uuid=[[*]] read_only=yes
-    - replicates from 127.0.0.1:<<<__mysql_sandbox_port1>>>
+    - replicates from '127.0.0.1:<<<__mysql_sandbox_port1>>>'
 <<<(__version_num<80023)?'	source="127.0.0.1:"' + __mysql_sandbox_port1 + '" channel= status=ON receiver=ON applier=ON':'	source="127.0.0.1:' + __mysql_sandbox_port1 + '" channel= status=ON receiver=ON coordinator=ON applier0=ON applier1=ON applier2=ON applier3=ON'>>>
 
 * Checking configuration of discovered instances...
@@ -377,8 +388,9 @@ true
                     "applierThreadState": <<<(__version_num<80023)?'"Slave has read all relay log; waiting for more updates",':'"Waiting for an event from Coordinator",\n                    "applierWorkerThreads": 4,'>>>
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
-                    "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationLag": "applier_queue_applied",
+                    "replicationSsl": "[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             },
@@ -391,8 +403,9 @@ true
                     "applierThreadState": <<<(__version_num<80023)?'"Slave has read all relay log; waiting for more updates",':'"Waiting for an event from Coordinator",\n                    "applierWorkerThreads": 4,'>>>
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
-                    "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationLag": "applier_queue_applied",
+                    "replicationSsl": "[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
