@@ -71,6 +71,8 @@ EXPECT_OUTPUT_NOT_CONTAINS("ERROR");
 EXPECT_THROWS(function(){cs.setPrimaryCluster("cluster3");}, "ClusterSet.setPrimaryCluster: The cluster with the name 'cluster3' does not exist.");
 
 //@<> Switch primary 1/1 (dryRun)
+shell.options["dba.logSql"] = 2;
+
 cs.setPrimaryCluster("cluster2", {dryRun:1});
 
 CHECK_PRIMARY_CLUSTER([__sandbox_uri1], c1);
@@ -80,6 +82,12 @@ CHECK_CLUSTER_SET(session);
 EXPECT_OUTPUT_NOT_CONTAINS("WARNING");
 EXPECT_OUTPUT_NOT_CONTAINS("ERROR");
 
+EXPECT_OUTPUT_CONTAINS("* Acquiring locks in ClusterSet instances");
+
+EXPECT_SHELL_LOG_NOT_CONTAINS("FLUSH TABLES WITH READ LOCK");
+
+shell.options["dba.logSql"] = 0;
+
 //@<> Switch primary 1/1
 cs.setPrimaryCluster("cluster2");
 
@@ -126,7 +134,9 @@ CHECK_CLUSTER_SET(session);
 
 // promoting cluster2 should be OK
 EXPECT_NO_THROWS(function() { cs.setPrimaryCluster("cluster2"); } );
-EXPECT_OUTPUT_CONTAINS("* Reconciling 1 internally generated GTIDs");
+if (__version_num < 80300) {
+  EXPECT_OUTPUT_CONTAINS("* Reconciling 1 internally generated GTIDs");
+}
 
 testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port1);
 
@@ -218,7 +228,7 @@ CHECK_REPLICA_CLUSTER([__sandbox_uri4], c1, c2);
 CHECK_REPLICA_CLUSTER([__sandbox_uri5], c1, c3);
 CHECK_CLUSTER_SET(session);
 
-session5.runSql("show slave status");
+session5.runSql("show " + get_replica_keyword() + " status");
 
 //@<> Switch primary 3/1/1
 
@@ -384,7 +394,7 @@ EXPECT_OUTPUT_NOT_CONTAINS("ERROR");
 var logs = testutil.readGeneralLog(__mysql_sandbox_port1, ts1);
 var logs = genlog_filter_reads(logs, /^SELECT.*FROM|SHOW|SET (SESSION|@|lock_wait)|SELECT (@@|COALESCE|GTID_EXECUTED|GTID_PURGED|GTID_SUB|group_replication_get_)/i);
 var logs = logs.map(function(x){return x["sql"];});
-EXPECT_EQ(["FLUSH TABLES WITH READ LOCK", "UNLOCK TABLES"], logs);
+EXPECT_EQ([], logs);
 var logs = testutil.readGeneralLog(__mysql_sandbox_port2, ts2);
 var logs = genlog_filter_reads(logs, /^SELECT.*FROM|SHOW|SET (SESSION|@|lock_wait)|SELECT (@@|COALESCE|GTID_EXECUTED|GTID_PURGED|GTID_SUB|group_replication_get_)/i);
 var logs = logs.map(function(x){return x["sql"];});
@@ -518,15 +528,18 @@ CHECK_PRIMARY_CLUSTER([__sandbox_uri5], c3);
 testutil.destroySandbox(__mysql_sandbox_port4);
 testutil.destroySandbox(__mysql_sandbox_port6);
 
-testutil.deploySandbox(__mysql_sandbox_port4, "root", {report_host:hostname});
-testutil.deploySandbox(__mysql_sandbox_port6, "root", {report_host:hostname});
+// Change the server_id otherwise the check for IDs will complain
+testutil.deploySandbox(__mysql_sandbox_port4, "root", {report_host:hostname, server_id:"1111"});
+testutil.deploySandbox(__mysql_sandbox_port6, "root", {report_host:hostname, server_id:"2222"});
 
 c4 = cs.createReplicaCluster(__sandbox_uri6, "cluster4", {manualStartOnBoot:1, recoveryMethod: "clone"});
 c4.addInstance(__sandbox_uri4, {recoveryMethod: "clone"});
 
+shell.connect(__sandbox_uri4);
 session4 = mysql.getSession(__sandbox_uri4);
 session6 = mysql.getSession(__sandbox_uri6);
 
+testutil.waitMemberTransactions(__mysql_sandbox_port6, __mysql_sandbox_port5);
 CHECK_REPLICA_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], c3, c1);
 CHECK_INVALIDATED_CLUSTER([], c3, c2);
 CHECK_PRIMARY_CLUSTER([__sandbox_uri5], c3);
