@@ -305,7 +305,7 @@ session.runSql("SET GLOBAL local_infile=1");
 //@<> Try to load the dump with sql_require_primary_key enabled (should fail)
 if(__version_num>80013) {
   session.runSql("set @@global.sql_require_primary_key=ON;");
-  EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump");}, "Util.loadDump: While 'Scanning metadata': sql_require_primary_key enabled at destination server");
+  EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump");}, "Util.loadDump: sql_require_primary_key enabled at destination server");
   EXPECT_STDOUT_CONTAINS_MULTILINE(`ERROR: The sql_require_primary_key option is enabled at the destination server and one or more tables without a Primary Key were found in the dump:
 schema \`all_features\`: \`findextable3\`, \`findextable\`
 schema \`xtest\`: \`t_bigint\`, \`t_bit\`, \`t_char\`, \`t_date\`, \`t_decimal1\`, \`t_decimal2\`, \`t_decimal3\`, \`t_double\`, \`t_enum\`, \`t_float\`, \`t_geom_all\`, \`t_geom\`, \`t_int\`, \`t_integer\`, \`t_json\`, \`t_lchar\`, \`t_lob\`, \`t_mediumint\`, \`t_numeric1\`, \`t_numeric2\`, \`t_real\`, \`t_set\`, \`t_smallint\`, \`t_tinyint\`
@@ -362,11 +362,11 @@ WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump");
 
 EXPECT_STDOUT_MATCHES(/Loading DDL and Data from '.*ldtest\/dump' using 4 threads\./);
-EXPECT_STDOUT_CONTAINS("Executing common preamble SQL");
+EXPECT_SHELL_LOG_CONTAINS("Executing common preamble SQL");
 EXPECT_SHELL_LOG_CONTAINS("Executing DDL script for schema");
 EXPECT_SHELL_LOG_CONTAINS("Executing DDL script for `xtest`.`t_tinyint`");
 EXPECT_SHELL_LOG_CONTAINS("Executing triggers SQL for `sakila`.`payment`");
-EXPECT_STDOUT_CONTAINS("Executing common postamble SQL");
+EXPECT_SHELL_LOG_CONTAINS("Executing common postamble SQL");
 EXPECT_STDOUT_CONTAINS("0 warnings were reported during the load.");
 
 // users not loaded, so don't compare accounts list
@@ -410,7 +410,7 @@ EXPECT_OUTPUT_CONTAINS("Resetting GTID_PURGED to dumped gtid set");
 
 wipe_instance(session);
 util.loadDump(__tmp_dir+"/ldtest/dump", {loadUsers: false, loadDdl: false, loadData: false, loadIndexes: false, skipBinlog: true, updateGtidSet: "replace"})
-EXPECT_OUTPUT_CONTAINS("GTID_PURGED already updated");
+EXPECT_OUTPUT_CONTAINS("GTID_PURGED already updated, skipping");
 
 testutil.rmfile(__tmp_dir+"/ldtest/dump/load-progress*");
 wipe_instance(session);
@@ -435,19 +435,19 @@ EXPECT_DUMP_LOADED_IGNORE_ACCOUNTS(session);
 EXPECT_OUTPUT_CONTAINS("using 4 threads");
 
 // ensure all 4 threads did something
-EXPECT_SHELL_LOG_CONTAINS("[Worker000] Executing DDL script for `")
-EXPECT_SHELL_LOG_CONTAINS("[Worker001] Executing DDL script for `")
-EXPECT_SHELL_LOG_CONTAINS("[Worker002] Executing DDL script for `")
-EXPECT_SHELL_LOG_CONTAINS("[Worker003] Executing DDL script for `")
+EXPECT_SHELL_LOG_CONTAINS("[Worker000]: Executing DDL script for `")
+EXPECT_SHELL_LOG_CONTAINS("[Worker001]: Executing DDL script for `")
+EXPECT_SHELL_LOG_CONTAINS("[Worker002]: Executing DDL script for `")
+EXPECT_SHELL_LOG_CONTAINS("[Worker003]: Executing DDL script for `")
 
-EXPECT_SHELL_LOG_CONTAINS("[Worker000] sakila@")
-EXPECT_SHELL_LOG_CONTAINS("[Worker001] sakila@")
-EXPECT_SHELL_LOG_CONTAINS("[Worker002] sakila@")
-EXPECT_SHELL_LOG_CONTAINS("[Worker003] sakila@")
+EXPECT_SHELL_LOG_CONTAINS("[Worker000]: sakila@")
+EXPECT_SHELL_LOG_CONTAINS("[Worker001]: sakila@")
+EXPECT_SHELL_LOG_CONTAINS("[Worker002]: sakila@")
+EXPECT_SHELL_LOG_CONTAINS("[Worker003]: sakila@")
 
 // schema and view DDL should not be executed in workers
-EXPECT_SHELL_LOG_NOT_CONTAINS("] Executing DDL script for schema")
-EXPECT_SHELL_LOG_NOT_CONTAINS("] Executing DDL script for view")
+EXPECT_SHELL_LOG_NOT_CONTAINS("]: Executing DDL script for schema")
+EXPECT_SHELL_LOG_NOT_CONTAINS("]: Executing DDL script for view")
 
 // ensure views got created through placeholders
 EXPECT_SHELL_LOG_CONTAINS("Executing DDL script for `sakila`.`actor_info` (placeholder for view)");
@@ -617,7 +617,7 @@ session.runSql("CREATE FUNCTION mysqlaas_compat.func2 () RETURNS INT NO SQL SQL
 session.runSql("CREATE PROCEDURE mysqlaas_compat.proc2 () NO SQL SQL SECURITY DEFINER BEGIN END;");
 session.runSql("CREATE EVENT mysqlaas_compat.event2 ON SCHEDULE EVERY 1 DAY DO BEGIN END;");
 
-EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump", {dryRun: 1});}, "Util.loadDump: While 'Scanning metadata': Duplicate objects found in destination database");
+EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump", {dryRun: 1});}, "Util.loadDump: While 'Checking for pre-existing objects': Duplicate objects found in destination database");
 
 //@<> load dump where some objects already exist, but exclude them from the load
 util.loadDump(__tmp_dir+"/ldtest/dump", {dryRun: 1, excludeSchemas: ["sakila", "mysqlaas_compat"]});
@@ -724,15 +724,15 @@ session.runSql(`create table init_test.init_test (a int)`);
 
 util.loadDump(__tmp_dir+"/ldtest/dump", {sessionInitSql:["set @cid=connection_id()", `insert into init_test.init_test values (@cid)`] });
 
-// ensure sessionInitSql was executed (4 threads + 1 main thread)
-EXPECT_EQ(5, session.runSql(`select * from init_test.init_test`).fetchAll().length);
+// ensure sessionInitSql was executed (4 threads + 1 main thread at least)
+EXPECT_GE(session.runSql(`select * from init_test.init_test`).fetchAll().length, 5);
 
 session.runSql("truncate init_test.init_test");
 
 util.loadDump(__tmp_dir+"/ldtest/dump", {sessionInitSql:["set @cid=connection_id()", `insert into init_test.init_test values (@cid)`] });
 
 // ensure sessionInitSql was executed even if no data loaded (4 threads + 1 main thread)
-EXPECT_EQ(5, session.runSql(`select * from init_test.init_test`).fetchAll().length);
+EXPECT_GE(session.runSql(`select * from init_test.init_test`).fetchAll().length, 5);
 
 
 wipe_instance(session);
@@ -747,7 +747,7 @@ session.runSql("set global max_connections=3");
 // This will throw either Too many connections or Aborted
 EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump", {threads: 8});}, "Util.loadDump: ");
 
-EXPECT_OUTPUT_CONTAINS("] Error opening connection to MySQL: MySQL Error 1040 (HY000): Too many connections");
+EXPECT_OUTPUT_CONTAINS("]: Error opening connection to MySQL: MySQL Error 1040 (HY000): Too many connections");
 
 testutil.rmfile(__tmp_dir+"/ldtest/dump/load-progress*");
 wipe_instance(session);
@@ -772,7 +772,7 @@ wipe_instance(session);
 //@<> try to load using an account with missing privs
 var grants_and_errors = [];
 
-grants_and_errors.push({ schema: "sakila", grant: "grant all on sakila.* to user@localhost with grant option", error: "ERROR: Error processing schema `sakila`: Access denied; you need (at least one of) the SUPER " });
+grants_and_errors.push({ schema: "sakila", grant: "grant all on sakila.* to user@localhost with grant option", error: "ERROR: Error processing schema `sakila`: Access denied; you need (at least one of) the " });
 grants_and_errors.push({ schema: "xtest", grant: "grant select,insert,update on xtest.* to user@localhost with grant option", error: "ERROR: Error processing schema `xtest`: Access denied for user 'user'@'localhost' to database 'xtest'" });
 grants_and_errors.push({ schema: "mysqlaas_compat", grant: "grant create,insert on mysqlaas_compat.* to user@localhost with grant option", error: "Error processing schema `mysqlaas_compat`: Access denied for user 'user'@'localhost' to database 'mysqlaas_compat'" });
 
@@ -836,7 +836,7 @@ util.loadDump(__tmp_dir+"/ldtest/dump");
 //@<> load again using a different progress file should assume a fresh load
 // in practice this means the load will fail because of duplicate objects from the previous attempt
 // TSFR12_2
-EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump", {progressFile: __tmp_dir+"/progress", dryRun: 1});}, "Util.loadDump: While 'Scanning metadata': Duplicate objects found in destination database");
+EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump", {progressFile: __tmp_dir+"/progress", dryRun: 1});}, "Util.loadDump: While 'Checking for pre-existing objects': Duplicate objects found in destination database");
 
 EXPECT_STDOUT_NOT_CONTAINS("Load progress file detected.");
 
@@ -960,7 +960,7 @@ util.loadDump(__tmp_dir+"/ldtest/dump-big");
 
 //@<> try loading an already loaded dump after resetting progress (will fail because of duplicate objects)
 WIPE_SHELL_LOG();
-EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump-big", {resetProgress: 1});}, "Util.loadDump: While 'Scanning metadata': Duplicate objects found in destination database");
+EXPECT_THROWS(function () {util.loadDump(__tmp_dir+"/ldtest/dump-big", {resetProgress: 1});}, "Util.loadDump: While 'Checking for pre-existing objects': Duplicate objects found in destination database");
 
 EXPECT_SHELL_LOG_NOT_CONTAINS("test@primer-dataset-id@1.tsv.zst: Records:");
 EXPECT_OUTPUT_CONTAINS("ERROR: Schema `sakila` already contains a view named ");
@@ -1050,13 +1050,18 @@ session.runSql("ANALYZE TABLE sakila.payment UPDATE HISTOGRAM ON rental_id, cust
 util.dumpSchemas(["sakila"], __tmp_dir+"/ldtest/dump-sakila");
 wipe_instance(session);
 
+//@<> BUG#36197620 - summary should contain more details regarding all executed stages
+analyze_tables_summary = "tables were analyzed in ";
+
 //@<> Load everything with no analyze, indexes deferred
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {analyzeTables: "off", deferTableIndexes:"all"});
 EXPECT_SHELL_LOG_CONTAINS("(indexes removed for deferred creation)");
-EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for `sakila`.`store`");
-EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for `sakila`.`inventory`");
-EXPECT_SHELL_LOG_CONTAINS("Recreating FOREIGN KEY constraints for schema `sakila`");
+EXPECT_SHELL_LOG_CONTAINS("Building indexes for `sakila`.`store`");
+EXPECT_SHELL_LOG_CONTAINS("Building indexes for `sakila`.`inventory`");
+EXPECT_SHELL_LOG_CONTAINS("Restoring FOREIGN KEY constraints for schema `sakila`");
+
+EXPECT_OUTPUT_NOT_CONTAINS(analyze_tables_summary);
 
 //@<> Analyze only
 WIPE_SHELL_LOG();
@@ -1082,6 +1087,8 @@ if(__version_num>80000) {
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`film`");
 }
 
+EXPECT_OUTPUT_CONTAINS(`16 ${analyze_tables_summary}`);
+
 //@<> Load everything without deferring indexes and analyze only for histograms
 wipe_instance(session);
 testutil.rmfile(__tmp_dir+"/ldtest/dump-sakila/load-progress*");
@@ -1089,15 +1096,19 @@ WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {analyzeTables: "histogram", deferTableIndexes: "off"});
 
 EXPECT_SHELL_LOG_NOT_CONTAINS("indexes removed for deferred creation");
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating indexes for");
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating FOREIGN KEY constraints");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Building indexes for");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Restoring FOREIGN KEY constraints");
 
 if(__version_num>80000) {
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`film`");
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`rental`");
   EXPECT_SHELL_LOG_CONTAINS("Updating histogram for table `sakila`.`payment`");
+
+  EXPECT_OUTPUT_CONTAINS(`3 ${analyze_tables_summary}`);
 } else {
   EXPECT_OUTPUT_CONTAINS("WARNING: Histogram creation enabled but MySQL Server "+__version+" does not support it.");
+
+  EXPECT_OUTPUT_NOT_CONTAINS(analyze_tables_summary);
 }
 
 //@<> Load everything with fulltext index deferment (the default)
@@ -1107,10 +1118,10 @@ WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila");
 
 EXPECT_SHELL_LOG_CONTAINS("Executing DDL script for `sakila`.`film_text` (indexes removed for deferred creation)")
-EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for `sakila`.`film_text`");
+EXPECT_SHELL_LOG_CONTAINS("Building indexes for `sakila`.`film_text`");
 EXPECT_SHELL_LOG_CONTAINS("Executing DDL script for `sakila`.`city`");
 EXPECT_SHELL_LOG_NOT_CONTAINS("Executing DDL script for `sakila`.`city` (indexes removed for deferred creation)");
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating FOREIGN KEY constraints");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Restoring FOREIGN KEY constraints");
 
 //@<> Load DDL first (indexes recreated), then data
 wipe_instance(session);
@@ -1118,14 +1129,14 @@ testutil.rmfile(__tmp_dir+"/ldtest/dump-sakila/load-progress*");
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {loadData: false, deferTableIndexes: "all", loadIndexes: true});
 EXPECT_SHELL_LOG_CONTAINS("indexes removed for deferred creation");
-EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for");
-EXPECT_SHELL_LOG_CONTAINS("Recreating FOREIGN KEY constraints");
+EXPECT_SHELL_LOG_CONTAINS("Building indexes for");
+EXPECT_SHELL_LOG_CONTAINS("Restoring FOREIGN KEY constraints");
 
 testutil.wipeAllOutput();
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {loadDdl: false, deferTableIndexes: "all", loadIndexes: true});
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating indexes for");
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating FOREIGN KEY constraints");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Building indexes for");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Restoring FOREIGN KEY constraints");
 
 //@<> Load DDL first then data with indexes recreation
 wipe_instance(session);
@@ -1133,13 +1144,13 @@ testutil.rmfile(__tmp_dir+"/ldtest/dump-sakila/load-progress*");
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {loadData: false, deferTableIndexes: "all", loadIndexes: false});
 EXPECT_SHELL_LOG_CONTAINS("indexes removed for deferred creation");
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating indexes for");
-EXPECT_SHELL_LOG_NOT_CONTAINS("Recreating FOREIGN KEY constraints");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Building indexes for");
+EXPECT_SHELL_LOG_NOT_CONTAINS("Restoring FOREIGN KEY constraints");
 
 WIPE_SHELL_LOG();
 util.loadDump(__tmp_dir+"/ldtest/dump-sakila", {loadDdl: false, deferTableIndexes: "all", loadIndexes: true});
-EXPECT_SHELL_LOG_CONTAINS("Recreating indexes for");
-EXPECT_SHELL_LOG_CONTAINS("Recreating FOREIGN KEY constraints");
+EXPECT_SHELL_LOG_CONTAINS("Building indexes for");
+EXPECT_SHELL_LOG_CONTAINS("Restoring FOREIGN KEY constraints");
 
 //@<> Ensure tables with no PK are truncated before reloading during a resume
 session.runSql("set global local_infile=1");
@@ -1273,7 +1284,7 @@ check_worker_distribution(16, ntables, __tmp_dir+"/ldtest/dump2/load-progress."+
 testutil.rmfile(__tmp_dir+"/ldtest/dump2/load-progress*");
 wipe_instance(session);
 
-//@<> Load dump with GR running
+//@<> Load dump with GR running {VER(>=8.0.0)}
 
 testutil.rmfile(__tmp_dir+"/ldtest/dump/load-progress*");
 wipe_instance(session);
@@ -1310,6 +1321,8 @@ wipe_instance(session);
 
 //@<> Try to load via xproto (should auto-switch to classic and work)
 
+testutil.rmfile(__tmp_dir+"/ldtest/dump/load-progress*");
+
 shell.connect("mysqlx://root:root@127.0.0.1:"+__mysql_sandbox_x_port1);
 
 util.loadDump(__tmp_dir+"/ldtest/dump", {dryRun: 1});
