@@ -174,6 +174,14 @@ DESCRIPTION
         at the PERFORMANCE_SCHEMA connection attributes tables.
       - local-infile: Enable/disable LOAD DATA LOCAL INFILE.
       - net-buffer-length: The buffer size for TCP/IP and socket communication.
+      - plugin-authentication-kerberos-client-mode: (Windows) Allows defining
+        the kerberos client mode (SSPI, GSSAPI) when using kerberos
+        authentication.
+      - oci-config-file: Allows defining the OCI configuration file for OCI
+        authentication.
+      - authentication-oci-client-config-profile: Allows defining the OCI
+        profile used from the configuration for client side OCI authentication.
+      - client-interactive: Enable/disable interactive mode for the session.
 
       When these options are defined in a URI, their values must be URL
       encoded.
@@ -185,9 +193,7 @@ DESCRIPTION
       - uri: a URI string.
       - scheme: the protocol to be used on the connection.
       - user: the MySQL user name to be used on the connection.
-      - dbUser: alias for user.
       - password: the password to be used on the connection.
-      - dbPassword: same as password.
       - host: the hostname or IP address to be used on the connection.
       - port: the port to be used in a TCP connection.
       - socket: the socket file name to be used on a connection through unix
@@ -203,9 +209,6 @@ DESCRIPTION
       - ssh-config-file: the SSH configuration file, default is the value of
         shell.options['ssh.configFile']
 
-      ATTENTION: The dbUser and dbPassword options are will be removed in a
-                 future release.
-
       ATTENTION: The connection options have precedence over options specified
                  in the connection options uri
 
@@ -342,12 +345,6 @@ PROPERTIES
       execution_time
             Same as get_execution_time
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -362,12 +359,6 @@ FUNCTIONS
             Retrieves a string value indicating the execution time of the
             executed operation.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
@@ -522,13 +513,6 @@ FUNCTIONS
             Sets number of documents to skip on the resultset when a limit has
             been defined.
 
-      skip(numberOfDocs)
-            Sets number of documents to skip on the resultset when a limit has
-            been defined.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the offset() function instead.
-
       sort(...)
             Sets the sorting criteria to be used on the DocResult.
 
@@ -546,13 +530,6 @@ FUNCTIONS
             Appends a value into an array attribute in documents of a
             collection.
 
-      array_delete(docPath)
-            Deletes the value at a specific position in an array attribute in
-            documents of a collection.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the unset() function instead.
-
       array_insert(docPath, value)
             Inserts a value into a specific position in an array attribute in
             documents of a collection.
@@ -572,13 +549,6 @@ FUNCTIONS
             Sets a limit for the documents to be updated by the operations
             added to the handler.
 
-      merge(document)
-            Adds attributes taken from a document into the documents in a
-            collection.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the patch() function instead.
-
       modify(searchCondition)
             Sets the search condition to identify the Documents to be updated
             on the owner Collection.
@@ -676,12 +646,6 @@ PROPERTIES
       execution_time
             Same as get_execution_time
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -703,12 +667,6 @@ FUNCTIONS
             Retrieves a string value indicating the execution time of the
             executed operation.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
@@ -736,12 +694,6 @@ DESCRIPTION
       - Transaction handling functions
 
 PROPERTIES
-      affected_item_count
-            Same as get_affected_item_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the affected_items_count property instead.
-
       affected_items_count
             Same as get_affected_items_count
 
@@ -754,12 +706,6 @@ PROPERTIES
       generated_ids
             Same as get_generated_ids.
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -767,12 +713,6 @@ PROPERTIES
             Same as get_warnings_count
 
 FUNCTIONS
-      get_affected_item_count()
-            The the number of affected items for the last operation.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_affected_items_count function instead.
-
       get_affected_items_count()
             The the number of affected items for the last operation.
 
@@ -786,12 +726,6 @@ FUNCTIONS
       get_generated_ids()
             Returns the list of document ids generated on the server.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
@@ -825,12 +759,6 @@ PROPERTIES
       execution_time
             Same as get_execution_time
 
-      warning_count
-            Same as get_warning_count
-
-            ATTENTION: This property will be removed in a future release, use
-                       the warnings_count property instead.
-
       warnings
             Same as get_warnings
 
@@ -864,12 +792,6 @@ FUNCTIONS
             Retrieves a string value indicating the execution time of the
             executed operation.
 
-      get_warning_count()
-            The number of warnings produced by the last statement execution.
-
-            ATTENTION: This function will be removed in a future release, use
-                       the get_warnings_count function instead.
-
       get_warnings()
             Retrieves the warnings generated by the executed operation.
 
