@@ -693,8 +693,9 @@ EXPECT_EQ(object.__setattr__, shlist.__setattr__)
 SETUP("__setitem__", range(11))
 
 ## exceptions
-# can only assign an iterable
-TEST(slice(2, 7), 7)
+# can only assign an iterable, Python 3.13+ reports must assign iterable to extended slice instead
+if sys.hexversion < 0x030d0000:
+    TEST(slice(2, 7), 7)
 # must assign iterable to extended slice
 TEST(slice(2, 7, 2), 7)
 # attempt to assign sequence of size %zd to extended slice of size %zd
@@ -750,7 +751,7 @@ TEST()
 
 #@<> __subclasshook__
 # __subclasshook__ comes from the object class
-EXPECT_EQ(NotImplemented, shlist.__subclasshook__())
+EXPECT_EQ(NotImplemented, shlist.__subclasshook__(None))
 
 #@<> append
 SETUP("append")
