@@ -87,6 +87,23 @@ shell.log("info", b"test\xed\xf0")
 outpath = run_collect(__sandbox_uri1, None)
 EXPECT_FILE_CONTENTS(outpath, "mysqlsh.log", b"test\xed\xf0")
 
+#@<> ensure query works with tables with more than one blob (or similar) columns
+
+session1.run_sql("create table test.t1 (col1 int, col2 blob, col3 blob);")
+session1.run_sql("create unique index idx1 on test.t1 (col1);")
+
+session1.run_sql("create table test.t2 (col1 int, col2 blob(10), col3 blob(10));")
+session1.run_sql("create unique index idx2 on test.t2 (col1);")
+
+session1.run_sql("create table test.t3 (col1 int, col2 blob(10));")
+session1.run_sql("create unique index idx3 on test.t3 (col1);")
+
+outpath = run_collect(__sandbox_uri1, None, schemaStats=1)
+
+EXPECT_FILE_CONTENTS(outpath, "schema_top_biggest_tables.yaml", b'[\\"col2:blob\\", \\"col3:blob\\"]')
+EXPECT_FILE_CONTENTS(outpath, "schema_top_biggest_tables.yaml", b'[\\"col2:tinyblob\\", \\"col3:tinyblob\\"]')
+EXPECT_FILE_CONTENTS(outpath, "schema_top_biggest_tables.yaml", b'[\\"col2:tinyblob\\"]')
+
 #@<> BUG#34048754 - 'path' set to an empty string should result in an error - all
 # TSFR_1_3_3
 def check(outpath):
@@ -151,26 +168,26 @@ outpath = run_collect_hl(hostname_uri, None, {"delay":{}})
 EXPECT_STDOUT_CONTAINS("'delay' is expected to be an integer")
 
 #@<> bogus value for options TSFR_1_1_3, TSFR_9_0_3, TSFR_9_0_4
-args = [hostname_uri, "--passwords-from-stdin", "-e", "util.debug.collectDiagnostics('x', false)"]
+args = [hostname_uri, "--passwords-from-stdin", "--js", "-e", "util.debug.collectDiagnostics('x', false)"]
 testutil.call_mysqlsh(args, "\n", ["MYSQLSH_TERM_COLOR_MODE=nocolor"])
 
 EXPECT_STDOUT_CONTAINS("Argument #2 is expected to be a map")
 RESET()
 
-args = [hostname_uri, "--passwords-from-stdin", "-e", "util.debug.collectHighLoadDiagnostics('x', false)"]
+args = [hostname_uri, "--passwords-from-stdin", "--js", "-e", "util.debug.collectHighLoadDiagnostics('x', false)"]
 testutil.call_mysqlsh(args, "\n", ["MYSQLSH_TERM_COLOR_MODE=nocolor"])
 
 EXPECT_STDOUT_CONTAINS("Argument #2 is expected to be a map")
 RESET()
 
-args = [hostname_uri, "--passwords-from-stdin", "-e", "util.debug.collectSlowQueryDiagnostics('x', 'x', false)"]
+args = [hostname_uri, "--passwords-from-stdin", "--js", "-e", "util.debug.collectSlowQueryDiagnostics('x', 'x', false)"]
 testutil.call_mysqlsh(args, "\n", ["MYSQLSH_TERM_COLOR_MODE=nocolor"])
 
 EXPECT_STDOUT_CONTAINS("Argument #3 is expected to be a map")
 
 RESET()
 
-args = [hostname_uri, "--passwords-from-stdin", "-e", "util.debug.collectSlowQueryDiagnostics('x', {}, false)"]
+args = [hostname_uri, "--passwords-from-stdin", "--js", "-e", "util.debug.collectSlowQueryDiagnostics('x', {}, false)"]
 testutil.call_mysqlsh(args, "\n", ["MYSQLSH_TERM_COLOR_MODE=nocolor"])
 
 EXPECT_STDOUT_CONTAINS("Argument #2 is expected to be a string")
@@ -540,6 +557,14 @@ outpath = run_collect_sq(__sandbox_uri1, None, "")
 EXPECT_STDOUT_CONTAINS("debug.collectSlowQueryDiagnostics: 'query' must contain the query to be analyzed")
 EXPECT_NO_FILE(outpath)
 
+#@<> Binary logs disabled and through x protocol
+# Should auto-reconnect using the classic protocol
+testutil.remove_from_sandbox_conf(__mysql_sandbox_port5, "log_bin");
+testutil.change_sandbox_conf(__mysql_sandbox_port5, "skip_log_bin", "ON");
+testutil.restart_sandbox(__mysql_sandbox_port5);
+
+CHECK_ALL(check, uri=f"mysqlx://root:root@localhost:{__mysql_sandbox_port5}0")
+
 #@<> Cleanup
 session1.close()
 
