@@ -14,10 +14,6 @@
 |All expected functions are available|
 |No additional functions are available|
 
-//@ CollectionModify: valid operations after modify and merge
-|All expected functions are available|
-|No additional functions are available|
-
 //@ CollectionModify: valid operations after modify and patch
 |All expected functions are available|
 |No additional functions are available|
@@ -30,10 +26,6 @@
 |All expected functions are available|
 |No additional functions are available|
 
-//@ CollectionModify: valid operations after modify and arrayDelete
-|All expected functions are available|
-|No additional functions are available|
-
 //@ CollectionModify: valid operations after sort
 |All expected functions are available|
 |No additional functions are available|
@@ -76,10 +68,6 @@
 ||CollectionModify.unset: Invalid document path
 ||CollectionModify.unset: Invalid document path
 
-//@# CollectionModify: Error conditions on merge
-||CollectionModify.merge: Invalid number of arguments, expected 1 but got 0
-||CollectionModify.merge: Argument expected to be a JSON object
-
 //@# CollectionModify: Error conditions on patch
 ||CollectionModify.patch: Invalid number of arguments, expected 1 but got 0
 ||CollectionModify.patch: Argument expected to be a JSON object
@@ -100,14 +88,6 @@
 ||CollectionModify.arrayAppend: Invalid document path
 ||CollectionModify.arrayAppend: Unsupported value received: <Session:
 
-//@# CollectionModify: Error conditions on arrayDelete
-||CollectionModify.arrayDelete: Invalid number of arguments, expected 1 but got
-||CollectionModify.arrayDelete: Argument #1 is expected to be a string
-||CollectionModify.arrayDelete: Invalid document path
-||CollectionModify.arrayDelete: Invalid document path
-||CollectionModify.arrayDelete: Invalid document path
-||CollectionModify.arrayDelete: An array document path must be specified
-
 //@# CollectionModify: Error conditions on sort
 ||CollectionModify.sort: Invalid number of arguments, expected at least 1 but got 0
 ||CollectionModify.sort: Argument #1 is expected to be a string or an array of strings
@@ -170,32 +150,15 @@
 |Brian's first girlfriend: lois|
 |Brian's second girlfriend: jane|
 
-//@ CollectionModify: unset for merge
-|Unset Affected Rows: 1|
-
-//@ CollectionModify: Merge Execution
-|Merge Affected Rows: 1|
-
-|Brian's last_name: black|
-|Brian's age: 15|
-|Brian's alias: bri|
-|Brian's first girlfriend: martha|
-|Brian's second girlfriend: karen|
-
 //@ CollectionModify: arrayAppend Execution
 |Array Append Affected Rows: 1|
-|Brian's girlfriends: 3|
-|Brian's last: cloe|
+|Brian's hobbies: 4|
+|Brian's last: running|
 
 //@ CollectionModify: arrayInsert Execution
 |Array Insert Affected Rows: 1|
-|Brian's girlfriends: 4|
-|Brian's second: samantha|
-
-//@ CollectionModify: arrayDelete Execution
-|Array Delete Affected Rows: 1|
-|Brian's girlfriends: 3|
-|Brian's third: cloe|
+|Brian's hobbies: 5|
+|Brian's second: cycling|
 
 //@ CollectionModify: sorting and limit Execution
 |Affected Rows: 2|
@@ -218,12 +181,6 @@
 |gender|
 |name|
 
-//@ CollectionModify: sorting and limit Execution - 4
-|~sample|
-|age|
-|gender|
-|name|
-
 //@<OUT> CollectionModify: Patch initial documents
 {
     "_id": "5C514FF38144957BE71111C04E0D1249",
