@@ -81,11 +81,15 @@ class Testutils : public mysqlsh::Extensible_object {
   Undefined importData(String uri, String path, String defaultSchema,
                        String importCharset);
   String waitMemberState(Integer port, String[] states);
+  String waitReadReplicaState(Integer port, String[] states);
   Boolean waitMemberTransactions(Integer destPort, Integer sourcePort = 0);
   Undefined waitForDelayedGRStart(Integer port, String rootpass,
                                   Integer timeout = 60);
   Integer waitForReplConnectionError(
       Integer port, String channel = "group_replication_recovery");
+  Undefined Testutils::waitReplicationChannelState(Integer port,
+                                                   String channelName,
+                                                   String[] states);
   Undefined expectPrompt(String prompt, String answer, Dictionary options);
   Undefined expectPassword(String prompt, String password, Dictionary options);
   Undefined assertNoPrompts();
@@ -145,10 +149,13 @@ class Testutils : public mysqlsh::Extensible_object {
   None dump_data(str uri, str path, list schemaList);
   None import_data(str uri, str path, str defaultSchema, str defaultCharset);
   str wait_member_state(int port, str[] states);
+  str wait_read_replica_state(int port, str[] states);
   bool wait_member_transactions(int destPort, int sourcePort = 0);
   None wait_for_delayed_gr_start(int port, str rootpass, int timeout = 60);
   int wait_for_repl_connection_error(
       int port, str channel = "group_replication_recovery");
+  None Testutils::wait_replication_channel_state(int port, str channel_name,
+                                                 str[] states);
   None expect_prompt(str prompt, str answer, dict options);
   None expect_password(str prompt, str password, dict options);
   None assert_no_prompts();
@@ -298,6 +305,8 @@ class Testutils : public mysqlsh::Extensible_object {
   std::string wait_member_state(int member_port, const std::string &states,
                                 bool direct_connection);
 
+  std::string wait_read_replica_state(int rr_port, const std::string &states);
+
   bool wait_member_transactions(int dest_port, int source_port);
 
   void inject_gtid_set(int dest_port, const std::string &gtid_set);
